use Test::More;
use Lingua::EN::Inflexion;

ok noun(q{suggesta})->is_plural  => q{is_plural: 'suggesta'};
ok noun(q{actinias})->is_plural  => q{is_plural: 'actinias'};
ok noun(q{gigolos})->is_plural  => q{is_plural: 'gigolos'};
ok noun(q{pseudostomata})->is_plural  => q{is_plural: 'pseudostomata'};
ok noun(q{infos})->is_plural  => q{is_plural: 'infos'};
ok noun(q{pox})->is_plural  => q{is_plural: 'pox'};
ok noun(q{aggros})->is_plural  => q{is_plural: 'aggros'};
ok noun(q{lomenta})->is_plural  => q{is_plural: 'lomenta'};
ok noun(q{vagi})->is_plural  => q{is_plural: 'vagi'};
ok noun(q{nebulas})->is_plural  => q{is_plural: 'nebulas'};
ok noun(q{hemangeiomata})->is_plural  => q{is_plural: 'hemangeiomata'};
ok noun(q{plecos})->is_plural  => q{is_plural: 'plecos'};
ok noun(q{dittos})->is_plural  => q{is_plural: 'dittos'};
ok noun(q{epilimnia})->is_plural  => q{is_plural: 'epilimnia'};
ok noun(q{salivaria})->is_plural  => q{is_plural: 'salivaria'};
ok noun(q{lomata})->is_plural  => q{is_plural: 'lomata'};
ok noun(q{Portuguese})->is_plural  => q{is_plural: 'Portuguese'};
ok noun(q{fibrae})->is_plural  => q{is_plural: 'fibrae'};
ok noun(q{Galla})->is_plural  => q{is_plural: 'Galla'};
ok noun(q{Quitos})->is_plural  => q{is_plural: 'Quitos'};
ok noun(q{seraphs})->is_plural  => q{is_plural: 'seraphs'};
ok noun(q{tetrahedra})->is_plural  => q{is_plural: 'tetrahedra'};
ok noun(q{dolphinaria})->is_plural  => q{is_plural: 'dolphinaria'};
ok noun(q{wharfs})->is_plural  => q{is_plural: 'wharfs'};
ok noun(q{somas})->is_plural  => q{is_plural: 'somas'};
ok noun(q{cannabises})->is_plural  => q{is_plural: 'cannabises'};
ok noun(q{proseuchae})->is_plural  => q{is_plural: 'proseuchae'};
ok noun(q{teeth})->is_plural  => q{is_plural: 'teeth'};
ok noun(q{ghettos})->is_plural  => q{is_plural: 'ghettos'};
ok noun(q{ossicula})->is_plural  => q{is_plural: 'ossicula'};
ok noun(q{trockenbeerenauslesen})->is_plural  => q{is_plural: 'trockenbeerenauslesen'};
ok noun(q{antifixes})->is_plural  => q{is_plural: 'antifixes'};
ok noun(q{nodi})->is_plural  => q{is_plural: 'nodi'};
ok noun(q{ischia})->is_plural  => q{is_plural: 'ischia'};
ok noun(q{tenorini})->is_plural  => q{is_plural: 'tenorini'};
ok noun(q{bimbos})->is_plural  => q{is_plural: 'bimbos'};
ok noun(q{interaxes})->is_plural  => q{is_plural: 'interaxes'};
ok noun(q{advisoes})->is_plural  => q{is_plural: 'advisoes'};
ok noun(q{serums})->is_plural  => q{is_plural: 'serums'};
ok noun(q{syrtes})->is_plural  => q{is_plural: 'syrtes'};
ok noun(q{saffi})->is_plural  => q{is_plural: 'saffi'};
ok noun(q{felsenmeere})->is_plural  => q{is_plural: 'felsenmeere'};
ok noun(q{equisetums})->is_plural  => q{is_plural: 'equisetums'};
ok noun(q{prosulae})->is_plural  => q{is_plural: 'prosulae'};
ok noun(q{jambeaux})->is_plural  => q{is_plural: 'jambeaux'};
ok noun(q{debris})->is_plural  => q{is_plural: 'debris'};
ok noun(q{competentes})->is_plural  => q{is_plural: 'competentes'};
ok noun(q{serir})->is_plural  => q{is_plural: 'serir'};
ok noun(q{jazzes})->is_plural  => q{is_plural: 'jazzes'};
ok noun(q{ellipses})->is_plural  => q{is_plural: 'ellipses'};
ok noun(q{octohedra})->is_plural  => q{is_plural: 'octohedra'};
ok noun(q{caules})->is_plural  => q{is_plural: 'caules'};
ok noun(q{aecidia})->is_plural  => q{is_plural: 'aecidia'};
ok noun(q{optima})->is_plural  => q{is_plural: 'optima'};
ok noun(q{schismata})->is_plural  => q{is_plural: 'schismata'};
ok noun(q{tropaeolums})->is_plural  => q{is_plural: 'tropaeolums'};
ok noun(q{herrings})->is_plural  => q{is_plural: 'herrings'};
ok noun(q{four-star generals})->is_plural  => q{is_plural: 'four-star generals'};
ok noun(q{frizzes})->is_plural  => q{is_plural: 'frizzes'};
ok noun(q{sinuses})->is_plural  => q{is_plural: 'sinuses'};
ok noun(q{Tocharese})->is_plural  => q{is_plural: 'Tocharese'};
ok noun(q{anlages})->is_plural  => q{is_plural: 'anlages'};
ok noun(q{holothurias})->is_plural  => q{is_plural: 'holothurias'};
ok noun(q{photos})->is_plural  => q{is_plural: 'photos'};
ok noun(q{octopi})->is_plural  => q{is_plural: 'octopi'};
ok noun(q{vesiculae})->is_plural  => q{is_plural: 'vesiculae'};
ok noun(q{Javanese})->is_plural  => q{is_plural: 'Javanese'};
ok noun(q{terremare})->is_plural  => q{is_plural: 'terremare'};
ok noun(q{Bahamans})->is_plural  => q{is_plural: 'Bahamans'};
ok noun(q{tuberculomata})->is_plural  => q{is_plural: 'tuberculomata'};
ok noun(q{aurei})->is_plural  => q{is_plural: 'aurei'};
ok noun(q{furfures})->is_plural  => q{is_plural: 'furfures'};
ok noun(q{syntagmas})->is_plural  => q{is_plural: 'syntagmas'};
ok noun(q{alluvia})->is_plural  => q{is_plural: 'alluvia'};
ok noun(q{sistrums})->is_plural  => q{is_plural: 'sistrums'};
ok noun(q{symposiums})->is_plural  => q{is_plural: 'symposiums'};
ok noun(q{lixivia})->is_plural  => q{is_plural: 'lixivia'};
ok noun(q{menservants})->is_plural  => q{is_plural: 'menservants'};
ok noun(q{provisoes})->is_plural  => q{is_plural: 'provisoes'};
ok noun(q{Yunnanese})->is_plural  => q{is_plural: 'Yunnanese'};
ok noun(q{clepsydras})->is_plural  => q{is_plural: 'clepsydras'};
ok noun(q{tarantate})->is_plural  => q{is_plural: 'tarantate'};
ok noun(q{paha})->is_plural  => q{is_plural: 'paha'};
ok noun(q{men-servants})->is_plural  => q{is_plural: 'men-servants'};
ok noun(q{pteromata})->is_plural  => q{is_plural: 'pteromata'};
ok noun(q{ricordi})->is_plural  => q{is_plural: 'ricordi'};
ok noun(q{proceedings})->is_plural  => q{is_plural: 'proceedings'};
ok noun(q{tracheae})->is_plural  => q{is_plural: 'tracheae'};
ok noun(q{monos})->is_plural  => q{is_plural: 'monos'};
ok noun(q{sets-off})->is_plural  => q{is_plural: 'sets-off'};
ok noun(q{arrhae})->is_plural  => q{is_plural: 'arrhae'};
ok noun(q{Guaiaberos})->is_plural  => q{is_plural: 'Guaiaberos'};
ok noun(q{Auslesen})->is_plural  => q{is_plural: 'Auslesen'};
ok noun(q{poes})->is_plural  => q{is_plural: 'poes'};
ok noun(q{Sonamans})->is_plural  => q{is_plural: 'Sonamans'};
ok noun(q{occiputs})->is_plural  => q{is_plural: 'occiputs'};
ok noun(q{motoscafi})->is_plural  => q{is_plural: 'motoscafi'};
ok noun(q{genera})->is_plural  => q{is_plural: 'genera'};
ok noun(q{kernoi})->is_plural  => q{is_plural: 'kernoi'};
ok noun(q{vincula})->is_plural  => q{is_plural: 'vincula'};
ok noun(q{Aragonese})->is_plural  => q{is_plural: 'Aragonese'};
ok noun(q{five star generals})->is_plural  => q{is_plural: 'five star generals'};
ok noun(q{axopodia})->is_plural  => q{is_plural: 'axopodia'};
ok noun(q{loggias})->is_plural  => q{is_plural: 'loggias'};
ok noun(q{sezessionen})->is_plural  => q{is_plural: 'sezessionen'};
ok noun(q{leptomonas})->is_plural  => q{is_plural: 'leptomonas'};
ok noun(q{scandala magnatum})->is_plural  => q{is_plural: 'scandala magnatum'};
ok noun(q{karrenfelds})->is_plural  => q{is_plural: 'karrenfelds'};
ok noun(q{interambulacra})->is_plural  => q{is_plural: 'interambulacra'};
ok noun(q{internodia})->is_plural  => q{is_plural: 'internodia'};
ok noun(q{parapleura})->is_plural  => q{is_plural: 'parapleura'};
ok noun(q{themata})->is_plural  => q{is_plural: 'themata'};
ok noun(q{contadine})->is_plural  => q{is_plural: 'contadine'};
ok noun(q{abortoria})->is_plural  => q{is_plural: 'abortoria'};
ok noun(q{karakias})->is_plural  => q{is_plural: 'karakias'};
ok noun(q{semata})->is_plural  => q{is_plural: 'semata'};
ok noun(q{crustae})->is_plural  => q{is_plural: 'crustae'};
ok noun(q{whosoever})->is_plural  => q{is_plural: 'whosoever'};
ok noun(q{cocos})->is_plural  => q{is_plural: 'cocos'};
ok noun(q{gyros})->is_plural  => q{is_plural: 'gyros'};
ok noun(q{mausoleums})->is_plural  => q{is_plural: 'mausoleums'};
ok noun(q{rad})->is_plural  => q{is_plural: 'rad'};
ok noun(q{placebos})->is_plural  => q{is_plural: 'placebos'};
ok noun(q{arcosolia})->is_plural  => q{is_plural: 'arcosolia'};
ok noun(q{bronchi})->is_plural  => q{is_plural: 'bronchi'};
ok noun(q{ronds de jambes})->is_plural  => q{is_plural: 'ronds de jambes'};
ok noun(q{grabens})->is_plural  => q{is_plural: 'grabens'};
ok noun(q{felones-de-se})->is_plural  => q{is_plural: 'felones-de-se'};
ok noun(q{Whitmanese})->is_plural  => q{is_plural: 'Whitmanese'};
ok noun(q{meningiomata})->is_plural  => q{is_plural: 'meningiomata'};
ok noun(q{tongs})->is_plural  => q{is_plural: 'tongs'};
ok noun(q{vivaria})->is_plural  => q{is_plural: 'vivaria'};
ok noun(q{amici curiae})->is_plural  => q{is_plural: 'amici curiae'};
ok noun(q{one-star generals})->is_plural  => q{is_plural: 'one-star generals'};
ok noun(q{theirs})->is_plural  => q{is_plural: 'theirs'};
ok noun(q{Antananarivos})->is_plural  => q{is_plural: 'Antananarivos'};
ok noun(q{men-midwives})->is_plural  => q{is_plural: 'men-midwives'};
ok noun(q{loci})->is_plural  => q{is_plural: 'loci'};
ok noun(q{crania})->is_plural  => q{is_plural: 'crania'};
ok noun(q{postulata})->is_plural  => q{is_plural: 'postulata'};
ok noun(q{suggestiones falsi})->is_plural  => q{is_plural: 'suggestiones falsi'};
ok noun(q{clostridia})->is_plural  => q{is_plural: 'clostridia'};
ok noun(q{caryatids})->is_plural  => q{is_plural: 'caryatids'};
ok noun(q{prolabia})->is_plural  => q{is_plural: 'prolabia'};
ok noun(q{octopodes})->is_plural  => q{is_plural: 'octopodes'};
ok noun(q{zoaria})->is_plural  => q{is_plural: 'zoaria'};
ok noun(q{interregnums})->is_plural  => q{is_plural: 'interregnums'};
ok noun(q{diplomas})->is_plural  => q{is_plural: 'diplomas'};
ok noun(q{chapeaux})->is_plural  => q{is_plural: 'chapeaux'};
ok noun(q{whatsoever})->is_plural  => q{is_plural: 'whatsoever'};
ok noun(q{wandervogel})->is_plural  => q{is_plural: 'wandervogel'};
ok noun(q{capataces})->is_plural  => q{is_plural: 'capataces'};
ok noun(q{volcanos})->is_plural  => q{is_plural: 'volcanos'};
ok noun(q{Romanies})->is_plural  => q{is_plural: 'Romanies'};
ok noun(q{pizzas})->is_plural  => q{is_plural: 'pizzas'};
ok noun(q{Congolese})->is_plural  => q{is_plural: 'Congolese'};
ok noun(q{Nepalese})->is_plural  => q{is_plural: 'Nepalese'};
ok noun(q{diastemata})->is_plural  => q{is_plural: 'diastemata'};
ok noun(q{prytan})->is_plural  => q{is_plural: 'prytan'};
ok noun(q{umbilicuses})->is_plural  => q{is_plural: 'umbilicuses'};
ok noun(q{braccia})->is_plural  => q{is_plural: 'braccia'};
ok noun(q{chordae})->is_plural  => q{is_plural: 'chordae'};
ok noun(q{hydraulica})->is_plural  => q{is_plural: 'hydraulica'};
ok noun(q{wildebeest})->is_plural  => q{is_plural: 'wildebeest'};
ok noun(q{viscera})->is_plural  => q{is_plural: 'viscera'};
ok noun(q{bass})->is_plural  => q{is_plural: 'bass'};
ok noun(q{feiseanna})->is_plural  => q{is_plural: 'feiseanna'};
ok noun(q{yours})->is_plural  => q{is_plural: 'yours'};
ok noun(q{belle epoques})->is_plural  => q{is_plural: 'belle epoques'};
ok noun(q{stephania})->is_plural  => q{is_plural: 'stephania'};
ok noun(q{thymi})->is_plural  => q{is_plural: 'thymi'};
ok noun(q{phalloi})->is_plural  => q{is_plural: 'phalloi'};
ok noun(q{intermedia})->is_plural  => q{is_plural: 'intermedia'};
ok noun(q{phenomena})->is_plural  => q{is_plural: 'phenomena'};
ok noun(q{profluvia})->is_plural  => q{is_plural: 'profluvia'};
ok noun(q{pensieri})->is_plural  => q{is_plural: 'pensieri'};
ok noun(q{antefixa})->is_plural  => q{is_plural: 'antefixa'};
ok noun(q{phyllobranchiae})->is_plural  => q{is_plural: 'phyllobranchiae'};
ok noun(q{deliriums})->is_plural  => q{is_plural: 'deliriums'};
ok noun(q{quartzes})->is_plural  => q{is_plural: 'quartzes'};
ok noun(q{isidia})->is_plural  => q{is_plural: 'isidia'};
ok noun(q{cistophorori})->is_plural  => q{is_plural: 'cistophorori'};
ok noun(q{synechiae})->is_plural  => q{is_plural: 'synechiae'};
ok noun(q{terga})->is_plural  => q{is_plural: 'terga'};
ok noun(q{chlamydias})->is_plural  => q{is_plural: 'chlamydias'};
ok noun(q{septenarii})->is_plural  => q{is_plural: 'septenarii'};
ok noun(q{nouvelle pauvre})->is_plural  => q{is_plural: 'nouvelle pauvre'};
ok noun(q{enigmata})->is_plural  => q{is_plural: 'enigmata'};
ok noun(q{otos})->is_plural  => q{is_plural: 'otos'};
ok noun(q{pedalos})->is_plural  => q{is_plural: 'pedalos'};
ok noun(q{blastemata})->is_plural  => q{is_plural: 'blastemata'};
ok noun(q{bechuana})->is_plural  => q{is_plural: 'bechuana'};
ok noun(q{papillae})->is_plural  => q{is_plural: 'papillae'};
ok noun(q{stabilimenta})->is_plural  => q{is_plural: 'stabilimenta'};
ok noun(q{plether})->is_plural  => q{is_plural: 'plether'};
ok noun(q{granite})->is_plural  => q{is_plural: 'granite'};
ok noun(q{uredia})->is_plural  => q{is_plural: 'uredia'};
ok noun(q{lives})->is_plural  => q{is_plural: 'lives'};
ok noun(q{kouroi})->is_plural  => q{is_plural: 'kouroi'};
ok noun(q{fasciculi})->is_plural  => q{is_plural: 'fasciculi'};
ok noun(q{beeves})->is_plural  => q{is_plural: 'beeves'};
ok noun(q{solfeggios})->is_plural  => q{is_plural: 'solfeggios'};
ok noun(q{yo yos})->is_plural  => q{is_plural: 'yo yos'};
ok noun(q{erotes})->is_plural  => q{is_plural: 'erotes'};
ok noun(q{florae})->is_plural  => q{is_plural: 'florae'};
ok noun(q{Kongolese})->is_plural  => q{is_plural: 'Kongolese'};
ok noun(q{dilettanti})->is_plural  => q{is_plural: 'dilettanti'};
ok noun(q{verticilli})->is_plural  => q{is_plural: 'verticilli'};
ok noun(q{amoebae})->is_plural  => q{is_plural: 'amoebae'};
ok noun(q{intercalaria})->is_plural  => q{is_plural: 'intercalaria'};
ok noun(q{fiascos})->is_plural  => q{is_plural: 'fiascos'};
ok noun(q{aciculae})->is_plural  => q{is_plural: 'aciculae'};
ok noun(q{yeses})->is_plural  => q{is_plural: 'yeses'};
ok noun(q{pedia})->is_plural  => q{is_plural: 'pedia'};
ok noun(q{enemata})->is_plural  => q{is_plural: 'enemata'};
ok noun(q{line outs})->is_plural  => q{is_plural: 'line outs'};
ok noun(q{stromodea})->is_plural  => q{is_plural: 'stromodea'};
ok noun(q{neurinomata})->is_plural  => q{is_plural: 'neurinomata'};
ok noun(q{Sudanese})->is_plural  => q{is_plural: 'Sudanese'};
ok noun(q{anti serums})->is_plural  => q{is_plural: 'anti serums'};
ok noun(q{gemmae})->is_plural  => q{is_plural: 'gemmae'};
ok noun(q{radiuses})->is_plural  => q{is_plural: 'radiuses'};
ok noun(q{secundiparas})->is_plural  => q{is_plural: 'secundiparas'};
ok noun(q{zemiroth})->is_plural  => q{is_plural: 'zemiroth'};
ok noun(q{pipkrakes})->is_plural  => q{is_plural: 'pipkrakes'};
ok noun(q{Roma})->is_plural  => q{is_plural: 'Roma'};
ok noun(q{umbrae})->is_plural  => q{is_plural: 'umbrae'};
ok noun(q{miliolae})->is_plural  => q{is_plural: 'miliolae'};
ok noun(q{stipulas})->is_plural  => q{is_plural: 'stipulas'};
ok noun(q{maculae})->is_plural  => q{is_plural: 'maculae'};
ok noun(q{decennia})->is_plural  => q{is_plural: 'decennia'};
ok noun(q{prokarya})->is_plural  => q{is_plural: 'prokarya'};
ok noun(q{uredinia})->is_plural  => q{is_plural: 'uredinia'};
ok noun(q{sambos})->is_plural  => q{is_plural: 'sambos'};
ok noun(q{set-outs})->is_plural  => q{is_plural: 'set-outs'};
ok noun(q{aculei})->is_plural  => q{is_plural: 'aculei'};
ok noun(q{two star generals})->is_plural  => q{is_plural: 'two star generals'};
ok noun(q{falsettos})->is_plural  => q{is_plural: 'falsettos'};
ok noun(q{bruschette})->is_plural  => q{is_plural: 'bruschette'};
ok noun(q{casinos})->is_plural  => q{is_plural: 'casinos'};
ok noun(q{indicia})->is_plural  => q{is_plural: 'indicia'};
ok noun(q{gminy})->is_plural  => q{is_plural: 'gminy'};
ok noun(q{rioni})->is_plural  => q{is_plural: 'rioni'};
ok noun(q{sputa})->is_plural  => q{is_plural: 'sputa'};
ok noun(q{neumas})->is_plural  => q{is_plural: 'neumas'};
ok noun(q{corps generals})->is_plural  => q{is_plural: 'corps generals'};
ok noun(q{bream})->is_plural  => q{is_plural: 'bream'};
ok noun(q{basilicae})->is_plural  => q{is_plural: 'basilicae'};
ok noun(q{indusia})->is_plural  => q{is_plural: 'indusia'};
ok noun(q{simulacra})->is_plural  => q{is_plural: 'simulacra'};
ok noun(q{bureaux})->is_plural  => q{is_plural: 'bureaux'};
ok noun(q{epitheliomata})->is_plural  => q{is_plural: 'epitheliomata'};
ok noun(q{tolkachi})->is_plural  => q{is_plural: 'tolkachi'};
ok noun(q{nebenkerne})->is_plural  => q{is_plural: 'nebenkerne'};
ok noun(q{shifta})->is_plural  => q{is_plural: 'shifta'};
ok noun(q{heroa})->is_plural  => q{is_plural: 'heroa'};
ok noun(q{trattorie})->is_plural  => q{is_plural: 'trattorie'};
ok noun(q{scioli})->is_plural  => q{is_plural: 'scioli'};
ok noun(q{star-fish})->is_plural  => q{is_plural: 'star-fish'};
ok noun(q{goes})->is_plural  => q{is_plural: 'goes'};
ok noun(q{testes})->is_plural  => q{is_plural: 'testes'};
ok noun(q{razzes})->is_plural  => q{is_plural: 'razzes'};
ok noun(q{demos})->is_plural  => q{is_plural: 'demos'};
ok noun(q{grouse})->is_plural  => q{is_plural: 'grouse'};
ok noun(q{fibrillae})->is_plural  => q{is_plural: 'fibrillae'};
ok noun(q{franc-archers})->is_plural  => q{is_plural: 'franc-archers'};
ok noun(q{didymes})->is_plural  => q{is_plural: 'didymes'};
ok noun(q{ephemerae})->is_plural  => q{is_plural: 'ephemerae'};
ok noun(q{tetracola})->is_plural  => q{is_plural: 'tetracola'};
ok noun(q{conversaziones})->is_plural  => q{is_plural: 'conversaziones'};
ok noun(q{tractatrices})->is_plural  => q{is_plural: 'tractatrices'};
ok noun(q{Orlandos})->is_plural  => q{is_plural: 'Orlandos'};
ok noun(q{errata})->is_plural  => q{is_plural: 'errata'};
ok noun(q{hippocampi})->is_plural  => q{is_plural: 'hippocampi'};
ok noun(q{tetrahedrons})->is_plural  => q{is_plural: 'tetrahedrons'};
ok noun(q{vertexes})->is_plural  => q{is_plural: 'vertexes'};
ok noun(q{pogos})->is_plural  => q{is_plural: 'pogos'};
ok noun(q{Wenchowese})->is_plural  => q{is_plural: 'Wenchowese'};
ok noun(q{Torinese})->is_plural  => q{is_plural: 'Torinese'};
ok noun(q{prosecutrices})->is_plural  => q{is_plural: 'prosecutrices'};
ok noun(q{neuromata})->is_plural  => q{is_plural: 'neuromata'};
ok noun(q{mumps})->is_plural  => q{is_plural: 'mumps'};
ok noun(q{cassones})->is_plural  => q{is_plural: 'cassones'};
ok noun(q{kiokos})->is_plural  => q{is_plural: 'kiokos'};
ok noun(q{minyanim})->is_plural  => q{is_plural: 'minyanim'};
ok noun(q{-oxen})->is_plural  => q{is_plural: '-oxen'};
ok noun(q{sumos})->is_plural  => q{is_plural: 'sumos'};
ok noun(q{trout})->is_plural  => q{is_plural: 'trout'};
ok noun(q{scazontes})->is_plural  => q{is_plural: 'scazontes'};
ok noun(q{substrata})->is_plural  => q{is_plural: 'substrata'};
ok noun(q{startsy})->is_plural  => q{is_plural: 'startsy'};
ok noun(q{vorspiele})->is_plural  => q{is_plural: 'vorspiele'};
ok noun(q{medusas})->is_plural  => q{is_plural: 'medusas'};
ok noun(q{sustentacula})->is_plural  => q{is_plural: 'sustentacula'};
ok noun(q{spectrums})->is_plural  => q{is_plural: 'spectrums'};
ok noun(q{fungi})->is_plural  => q{is_plural: 'fungi'};
ok noun(q{stomatia})->is_plural  => q{is_plural: 'stomatia'};
ok noun(q{precognita})->is_plural  => q{is_plural: 'precognita'};
ok noun(q{sforzatos})->is_plural  => q{is_plural: 'sforzatos'};
ok noun(q{feculae})->is_plural  => q{is_plural: 'feculae'};
ok noun(q{enconiums})->is_plural  => q{is_plural: 'enconiums'};
ok noun(q{cyclopses})->is_plural  => q{is_plural: 'cyclopses'};
ok noun(q{nauplii})->is_plural  => q{is_plural: 'nauplii'};
ok noun(q{macaronies})->is_plural  => q{is_plural: 'macaronies'};
ok noun(q{scuta})->is_plural  => q{is_plural: 'scuta'};
ok noun(q{lyssae})->is_plural  => q{is_plural: 'lyssae'};
ok noun(q{innings})->is_plural  => q{is_plural: 'innings'};
ok noun(q{addendums})->is_plural  => q{is_plural: 'addendums'};
ok noun(q{pinaces})->is_plural  => q{is_plural: 'pinaces'};
ok noun(q{stilettoes})->is_plural  => q{is_plural: 'stilettoes'};
ok noun(q{secundigravidas})->is_plural  => q{is_plural: 'secundigravidas'};
ok noun(q{condos})->is_plural  => q{is_plural: 'condos'};
ok noun(q{Veronese})->is_plural  => q{is_plural: 'Veronese'};
ok noun(q{imagines})->is_plural  => q{is_plural: 'imagines'};
ok noun(q{zoosporangia})->is_plural  => q{is_plural: 'zoosporangia'};
ok noun(q{tori})->is_plural  => q{is_plural: 'tori'};
ok noun(q{jeux})->is_plural  => q{is_plural: 'jeux'};
ok noun(q{turves})->is_plural  => q{is_plural: 'turves'};
ok noun(q{supernovae})->is_plural  => q{is_plural: 'supernovae'};
ok noun(q{Sarawakese})->is_plural  => q{is_plural: 'Sarawakese'};
ok noun(q{ramuli})->is_plural  => q{is_plural: 'ramuli'};
ok noun(q{ispravniki})->is_plural  => q{is_plural: 'ispravniki'};
ok noun(q{antennas})->is_plural  => q{is_plural: 'antennas'};
ok noun(q{canzonette})->is_plural  => q{is_plural: 'canzonette'};
ok noun(q{bijoux})->is_plural  => q{is_plural: 'bijoux'};
ok noun(q{ranunculi})->is_plural  => q{is_plural: 'ranunculi'};
ok noun(q{gliosarcomata})->is_plural  => q{is_plural: 'gliosarcomata'};
ok noun(q{hyperbolas})->is_plural  => q{is_plural: 'hyperbolas'};
ok noun(q{sertularias})->is_plural  => q{is_plural: 'sertularias'};
ok noun(q{pineta})->is_plural  => q{is_plural: 'pineta'};
ok noun(q{wadis})->is_plural  => q{is_plural: 'wadis'};
ok noun(q{nimbuses})->is_plural  => q{is_plural: 'nimbuses'};
ok noun(q{antisera})->is_plural  => q{is_plural: 'antisera'};
ok noun(q{waldos})->is_plural  => q{is_plural: 'waldos'};
ok noun(q{Carlylese})->is_plural  => q{is_plural: 'Carlylese'};
ok noun(q{bons vivants})->is_plural  => q{is_plural: 'bons vivants'};
ok noun(q{calathi})->is_plural  => q{is_plural: 'calathi'};
ok noun(q{prospectus})->is_plural  => q{is_plural: 'prospectus'};
ok noun(q{lacunaria})->is_plural  => q{is_plural: 'lacunaria'};
ok noun(q{manubria})->is_plural  => q{is_plural: 'manubria'};
ok noun(q{sileni})->is_plural  => q{is_plural: 'sileni'};
ok noun(q{exes})->is_plural  => q{is_plural: 'exes'};
ok noun(q{Sapporos})->is_plural  => q{is_plural: 'Sapporos'};
ok noun(q{men})->is_plural  => q{is_plural: 'men'};
ok noun(q{meningiomas})->is_plural  => q{is_plural: 'meningiomas'};
ok noun(q{deer})->is_plural  => q{is_plural: 'deer'};
ok noun(q{Bhutanese})->is_plural  => q{is_plural: 'Bhutanese'};
ok noun(q{Guianese})->is_plural  => q{is_plural: 'Guianese'};
ok noun(q{tractrices})->is_plural  => q{is_plural: 'tractrices'};
ok noun(q{mukim})->is_plural  => q{is_plural: 'mukim'};
ok noun(q{strata})->is_plural  => q{is_plural: 'strata'};
ok noun(q{lemures})->is_plural  => q{is_plural: 'lemures'};
ok noun(q{magnetos})->is_plural  => q{is_plural: 'magnetos'};
ok noun(q{autos de fes})->is_plural  => q{is_plural: 'autos de fes'};
ok noun(q{coeliae})->is_plural  => q{is_plural: 'coeliae'};
ok noun(q{zite})->is_plural  => q{is_plural: 'zite'};
ok noun(q{stalactitae})->is_plural  => q{is_plural: 'stalactitae'};
ok noun(q{adyta})->is_plural  => q{is_plural: 'adyta'};
ok noun(q{scyphi})->is_plural  => q{is_plural: 'scyphi'};
ok noun(q{trapezohedra})->is_plural  => q{is_plural: 'trapezohedra'};
ok noun(q{roe})->is_plural  => q{is_plural: 'roe'};
ok noun(q{studia generali})->is_plural  => q{is_plural: 'studia generali'};
ok noun(q{sarcomas})->is_plural  => q{is_plural: 'sarcomas'};
ok noun(q{microcephali})->is_plural  => q{is_plural: 'microcephali'};
ok noun(q{burros})->is_plural  => q{is_plural: 'burros'};
ok noun(q{taxa})->is_plural  => q{is_plural: 'taxa'};
ok noun(q{shochetim})->is_plural  => q{is_plural: 'shochetim'};
ok noun(q{globigerinae})->is_plural  => q{is_plural: 'globigerinae'};
ok noun(q{torsos})->is_plural  => q{is_plural: 'torsos'};
ok noun(q{ignoramus})->is_plural  => q{is_plural: 'ignoramus'};
ok noun(q{pollinaria})->is_plural  => q{is_plural: 'pollinaria'};
ok noun(q{sertulariae})->is_plural  => q{is_plural: 'sertulariae'};
ok noun(q{pulsella})->is_plural  => q{is_plural: 'pulsella'};
ok noun(q{deliria})->is_plural  => q{is_plural: 'deliria'};
ok noun(q{ganglia})->is_plural  => q{is_plural: 'ganglia'};
ok noun(q{mortadelle})->is_plural  => q{is_plural: 'mortadelle'};
ok noun(q{frena})->is_plural  => q{is_plural: 'frena'};
ok noun(q{vestigia})->is_plural  => q{is_plural: 'vestigia'};
ok noun(q{paraglossae})->is_plural  => q{is_plural: 'paraglossae'};
ok noun(q{scari})->is_plural  => q{is_plural: 'scari'};
ok noun(q{psychos})->is_plural  => q{is_plural: 'psychos'};
ok noun(q{syncytia})->is_plural  => q{is_plural: 'syncytia'};
ok noun(q{daises})->is_plural  => q{is_plural: 'daises'};
ok noun(q{ethoses})->is_plural  => q{is_plural: 'ethoses'};
ok noun(q{lacunae})->is_plural  => q{is_plural: 'lacunae'};
ok noun(q{styli})->is_plural  => q{is_plural: 'styli'};
ok noun(q{indigenae})->is_plural  => q{is_plural: 'indigenae'};
ok noun(q{white staves})->is_plural  => q{is_plural: 'white staves'};
ok noun(q{lice})->is_plural  => q{is_plural: 'lice'};
ok noun(q{ispravniks})->is_plural  => q{is_plural: 'ispravniks'};
ok noun(q{prototypa})->is_plural  => q{is_plural: 'prototypa'};
ok noun(q{genae})->is_plural  => q{is_plural: 'genae'};
ok noun(q{Modenese})->is_plural  => q{is_plural: 'Modenese'};
ok noun(q{thrasones})->is_plural  => q{is_plural: 'thrasones'};
ok noun(q{gametangia})->is_plural  => q{is_plural: 'gametangia'};
ok noun(q{violoncellos})->is_plural  => q{is_plural: 'violoncellos'};
ok noun(q{autobahns})->is_plural  => q{is_plural: 'autobahns'};
ok noun(q{Timorese})->is_plural  => q{is_plural: 'Timorese'};
ok noun(q{oxymora})->is_plural  => q{is_plural: 'oxymora'};
ok noun(q{premiers danseurs})->is_plural  => q{is_plural: 'premiers danseurs'};
ok noun(q{serirs})->is_plural  => q{is_plural: 'serirs'};
ok noun(q{stasima})->is_plural  => q{is_plural: 'stasima'};
ok noun(q{ocelli})->is_plural  => q{is_plural: 'ocelli'};
ok noun(q{wreaths})->is_plural  => q{is_plural: 'wreaths'};
ok noun(q{syphilomata})->is_plural  => q{is_plural: 'syphilomata'};
ok noun(q{nachtlokale})->is_plural  => q{is_plural: 'nachtlokale'};
ok noun(q{hertz})->is_plural  => q{is_plural: 'hertz'};
ok noun(q{timpanos})->is_plural  => q{is_plural: 'timpanos'};
ok noun(q{vivariums})->is_plural  => q{is_plural: 'vivariums'};
ok noun(q{penicilli})->is_plural  => q{is_plural: 'penicilli'};
ok noun(q{funghi porchini})->is_plural  => q{is_plural: 'funghi porchini'};
ok noun(q{pharmakoi})->is_plural  => q{is_plural: 'pharmakoi'};
ok noun(q{sensilla})->is_plural  => q{is_plural: 'sensilla'};
ok noun(q{unci})->is_plural  => q{is_plural: 'unci'};
ok noun(q{poria})->is_plural  => q{is_plural: 'poria'};
ok noun(q{fermatas})->is_plural  => q{is_plural: 'fermatas'};
ok noun(q{cornua})->is_plural  => q{is_plural: 'cornua'};
ok noun(q{scaleni})->is_plural  => q{is_plural: 'scaleni'};
ok noun(q{buffalo})->is_plural  => q{is_plural: 'buffalo'};
ok noun(q{Oslos})->is_plural  => q{is_plural: 'Oslos'};
ok noun(q{Maputos})->is_plural  => q{is_plural: 'Maputos'};
ok noun(q{Hararese})->is_plural  => q{is_plural: 'Hararese'};
ok noun(q{usneae})->is_plural  => q{is_plural: 'usneae'};
ok noun(q{primordia})->is_plural  => q{is_plural: 'primordia'};
ok noun(q{septa})->is_plural  => q{is_plural: 'septa'};
ok noun(q{termini})->is_plural  => q{is_plural: 'termini'};
ok noun(q{francs-archers})->is_plural  => q{is_plural: 'francs-archers'};
ok noun(q{lowlifes})->is_plural  => q{is_plural: 'lowlifes'};
ok noun(q{cysticerci})->is_plural  => q{is_plural: 'cysticerci'};
ok noun(q{mimosas})->is_plural  => q{is_plural: 'mimosas'};
ok noun(q{vermicellos})->is_plural  => q{is_plural: 'vermicellos'};
ok noun(q{scutella})->is_plural  => q{is_plural: 'scutella'};
ok noun(q{Lesothos})->is_plural  => q{is_plural: 'Lesothos'};
ok noun(q{caudices})->is_plural  => q{is_plural: 'caudices'};
ok noun(q{albinos})->is_plural  => q{is_plural: 'albinos'};
ok noun(q{valuten})->is_plural  => q{is_plural: 'valuten'};
ok noun(q{ligamenta})->is_plural  => q{is_plural: 'ligamenta'};
ok noun(q{udarniki})->is_plural  => q{is_plural: 'udarniki'};
ok noun(q{porrones})->is_plural  => q{is_plural: 'porrones'};
ok noun(q{kimonos})->is_plural  => q{is_plural: 'kimonos'};
ok noun(q{pos})->is_plural  => q{is_plural: 'pos'};
ok noun(q{porrons})->is_plural  => q{is_plural: 'porrons'};
ok noun(q{formulae})->is_plural  => q{is_plural: 'formulae'};
ok noun(q{gringos})->is_plural  => q{is_plural: 'gringos'};
ok noun(q{Japanese})->is_plural  => q{is_plural: 'Japanese'};
ok noun(q{ephelides})->is_plural  => q{is_plural: 'ephelides'};
ok noun(q{melastomas})->is_plural  => q{is_plural: 'melastomas'};
ok noun(q{Gallas})->is_plural  => q{is_plural: 'Gallas'};
ok noun(q{mews})->is_plural  => q{is_plural: 'mews'};
ok noun(q{municipia})->is_plural  => q{is_plural: 'municipia'};
ok noun(q{moscardini})->is_plural  => q{is_plural: 'moscardini'};
ok noun(q{portiforia})->is_plural  => q{is_plural: 'portiforia'};
ok noun(q{starfish})->is_plural  => q{is_plural: 'starfish'};
ok noun(q{Esperantos})->is_plural  => q{is_plural: 'Esperantos'};
ok noun(q{zyga})->is_plural  => q{is_plural: 'zyga'};
ok noun(q{capi})->is_plural  => q{is_plural: 'capi'};
ok noun(q{cumuli})->is_plural  => q{is_plural: 'cumuli'};
ok noun(q{maestri})->is_plural  => q{is_plural: 'maestri'};
ok noun(q{propositi})->is_plural  => q{is_plural: 'propositi'};
ok noun(q{shad})->is_plural  => q{is_plural: 'shad'};
ok noun(q{adieux})->is_plural  => q{is_plural: 'adieux'};
ok noun(q{pennies})->is_plural  => q{is_plural: 'pennies'};
ok noun(q{blouses})->is_plural  => q{is_plural: 'blouses'};
ok noun(q{sporodochia})->is_plural  => q{is_plural: 'sporodochia'};
ok noun(q{algae})->is_plural  => q{is_plural: 'algae'};
ok noun(q{toxoplasmata})->is_plural  => q{is_plural: 'toxoplasmata'};
ok noun(q{pneumothoraxes})->is_plural  => q{is_plural: 'pneumothoraxes'};
ok noun(q{maestros})->is_plural  => q{is_plural: 'maestros'};
ok noun(q{villi})->is_plural  => q{is_plural: 'villi'};
ok noun(q{pina coladas})->is_plural  => q{is_plural: 'pina coladas'};
ok noun(q{synthroni})->is_plural  => q{is_plural: 'synthroni'};
ok noun(q{Nipponese})->is_plural  => q{is_plural: 'Nipponese'};
ok noun(q{oboli})->is_plural  => q{is_plural: 'oboli'};
ok noun(q{milieux interieurs})->is_plural  => q{is_plural: 'milieux interieurs'};
ok noun(q{apsides})->is_plural  => q{is_plural: 'apsides'};
ok noun(q{alluviums})->is_plural  => q{is_plural: 'alluviums'};
ok noun(q{Santiagos})->is_plural  => q{is_plural: 'Santiagos'};
ok noun(q{propodia})->is_plural  => q{is_plural: 'propodia'};
ok noun(q{individuums})->is_plural  => q{is_plural: 'individuums'};
ok noun(q{femurs})->is_plural  => q{is_plural: 'femurs'};
ok noun(q{fabliaux})->is_plural  => q{is_plural: 'fabliaux'};
ok noun(q{pecias})->is_plural  => q{is_plural: 'pecias'};
ok noun(q{impetuses})->is_plural  => q{is_plural: 'impetuses'};
ok noun(q{embryos})->is_plural  => q{is_plural: 'embryos'};
ok noun(q{streptothrices})->is_plural  => q{is_plural: 'streptothrices'};
ok noun(q{corgwn})->is_plural  => q{is_plural: 'corgwn'};
ok noun(q{pirrites})->is_plural  => q{is_plural: 'pirrites'};
ok noun(q{pinas coladas})->is_plural  => q{is_plural: 'pinas coladas'};
ok noun(q{bateaux})->is_plural  => q{is_plural: 'bateaux'};
ok noun(q{dreikanter})->is_plural  => q{is_plural: 'dreikanter'};
ok noun(q{sedes})->is_plural  => q{is_plural: 'sedes'};
ok noun(q{Paramaribos})->is_plural  => q{is_plural: 'Paramaribos'};
ok noun(q{osmateria})->is_plural  => q{is_plural: 'osmateria'};
ok noun(q{tessellas})->is_plural  => q{is_plural: 'tessellas'};
ok noun(q{Chicagos})->is_plural  => q{is_plural: 'Chicagos'};
ok noun(q{flys})->is_plural  => q{is_plural: 'flys'};
ok noun(q{virii})->is_plural  => q{is_plural: 'virii'};
ok noun(q{tenderfoots})->is_plural  => q{is_plural: 'tenderfoots'};
ok noun(q{protonemata})->is_plural  => q{is_plural: 'protonemata'};
ok noun(q{pycnides})->is_plural  => q{is_plural: 'pycnides'};
ok noun(q{novae})->is_plural  => q{is_plural: 'novae'};
ok noun(q{pithoi})->is_plural  => q{is_plural: 'pithoi'};
ok noun(q{eucalypti})->is_plural  => q{is_plural: 'eucalypti'};
ok noun(q{focuses})->is_plural  => q{is_plural: 'focuses'};
ok noun(q{vilas})->is_plural  => q{is_plural: 'vilas'};
ok noun(q{gutti})->is_plural  => q{is_plural: 'gutti'};
ok noun(q{uomini})->is_plural  => q{is_plural: 'uomini'};
ok noun(q{euporista})->is_plural  => q{is_plural: 'euporista'};
ok noun(q{avisos})->is_plural  => q{is_plural: 'avisos'};
ok noun(q{stemmata})->is_plural  => q{is_plural: 'stemmata'};
ok noun(q{breaks away})->is_plural  => q{is_plural: 'breaks away'};
ok noun(q{cathismata})->is_plural  => q{is_plural: 'cathismata'};
ok noun(q{scapulae})->is_plural  => q{is_plural: 'scapulae'};
ok noun(q{hetaerae})->is_plural  => q{is_plural: 'hetaerae'};
ok noun(q{sori})->is_plural  => q{is_plural: 'sori'};
ok noun(q{radices})->is_plural  => q{is_plural: 'radices'};
ok noun(q{wanderjahre})->is_plural  => q{is_plural: 'wanderjahre'};
ok noun(q{arves})->is_plural  => q{is_plural: 'arves'};
ok noun(q{chateaux})->is_plural  => q{is_plural: 'chateaux'};
ok noun(q{tepidaria})->is_plural  => q{is_plural: 'tepidaria'};
ok noun(q{cystomata})->is_plural  => q{is_plural: 'cystomata'};
ok noun(q{moduli})->is_plural  => q{is_plural: 'moduli'};
ok noun(q{jalapenos})->is_plural  => q{is_plural: 'jalapenos'};
ok noun(q{Otomi})->is_plural  => q{is_plural: 'Otomi'};
ok noun(q{inukshuit})->is_plural  => q{is_plural: 'inukshuit'};
ok noun(q{orthocerata})->is_plural  => q{is_plural: 'orthocerata'};
ok noun(q{Tenggerese})->is_plural  => q{is_plural: 'Tenggerese'};
ok noun(q{procoeliae})->is_plural  => q{is_plural: 'procoeliae'};
ok noun(q{subsellia})->is_plural  => q{is_plural: 'subsellia'};
ok noun(q{granulae})->is_plural  => q{is_plural: 'granulae'};
ok noun(q{memos})->is_plural  => q{is_plural: 'memos'};
ok noun(q{pycnidia})->is_plural  => q{is_plural: 'pycnidia'};
ok noun(q{boluses})->is_plural  => q{is_plural: 'boluses'};
ok noun(q{mycoplasmas})->is_plural  => q{is_plural: 'mycoplasmas'};
ok noun(q{alto-relievos})->is_plural  => q{is_plural: 'alto-relievos'};
ok noun(q{rostrums})->is_plural  => q{is_plural: 'rostrums'};
ok noun(q{pali})->is_plural  => q{is_plural: 'pali'};
ok noun(q{Tokyos})->is_plural  => q{is_plural: 'Tokyos'};
ok noun(q{chaetae})->is_plural  => q{is_plural: 'chaetae'};
ok noun(q{plasmolytica})->is_plural  => q{is_plural: 'plasmolytica'};
ok noun(q{cochitos})->is_plural  => q{is_plural: 'cochitos'};
ok noun(q{efreeti})->is_plural  => q{is_plural: 'efreeti'};
ok noun(q{spari})->is_plural  => q{is_plural: 'spari'};
ok noun(q{rhododendra})->is_plural  => q{is_plural: 'rhododendra'};
ok noun(q{rem})->is_plural  => q{is_plural: 'rem'};
ok noun(q{6-star generals})->is_plural  => q{is_plural: '6-star generals'};
ok noun(q{Singhalese})->is_plural  => q{is_plural: 'Singhalese'};
ok noun(q{caffe ristretti})->is_plural  => q{is_plural: 'caffe ristretti'};
ok noun(q{hoofs})->is_plural  => q{is_plural: 'hoofs'};
ok noun(q{afriti})->is_plural  => q{is_plural: 'afriti'};
ok noun(q{reductiones})->is_plural  => q{is_plural: 'reductiones'};
ok noun(q{parietes})->is_plural  => q{is_plural: 'parietes'};
ok noun(q{bases})->is_plural  => q{is_plural: 'bases'};
ok noun(q{falces})->is_plural  => q{is_plural: 'falces'};
ok noun(q{Andamanese})->is_plural  => q{is_plural: 'Andamanese'};
ok noun(q{maquereaux})->is_plural  => q{is_plural: 'maquereaux'};
ok noun(q{incubuses})->is_plural  => q{is_plural: 'incubuses'};
ok noun(q{vomicas})->is_plural  => q{is_plural: 'vomicas'};
ok noun(q{Avignonese})->is_plural  => q{is_plural: 'Avignonese'};
ok noun(q{xiphopagi})->is_plural  => q{is_plural: 'xiphopagi'};
ok noun(q{perikarya})->is_plural  => q{is_plural: 'perikarya'};
ok noun(q{propylons})->is_plural  => q{is_plural: 'propylons'};
ok noun(q{Macanese})->is_plural  => q{is_plural: 'Macanese'};
ok noun(q{unciae})->is_plural  => q{is_plural: 'unciae'};
ok noun(q{tete a tetes})->is_plural  => q{is_plural: 'tete a tetes'};
ok noun(q{aides-de-camp})->is_plural  => q{is_plural: 'aides-de-camp'};
ok noun(q{Burmans})->is_plural  => q{is_plural: 'Burmans'};
ok noun(q{idola})->is_plural  => q{is_plural: 'idola'};
ok noun(q{tarantati})->is_plural  => q{is_plural: 'tarantati'};
ok noun(q{retia})->is_plural  => q{is_plural: 'retia'};
ok noun(q{angustiae})->is_plural  => q{is_plural: 'angustiae'};
ok noun(q{enigmas})->is_plural  => q{is_plural: 'enigmas'};
ok noun(q{lobuli})->is_plural  => q{is_plural: 'lobuli'};
ok noun(q{sforzati})->is_plural  => q{is_plural: 'sforzati'};
ok noun(q{kylixes})->is_plural  => q{is_plural: 'kylixes'};
ok noun(q{archegonia})->is_plural  => q{is_plural: 'archegonia'};
ok noun(q{consortia})->is_plural  => q{is_plural: 'consortia'};
ok noun(q{humans})->is_plural  => q{is_plural: 'humans'};
ok noun(q{tete-a-tetes})->is_plural  => q{is_plural: 'tete-a-tetes'};
ok noun(q{stolones})->is_plural  => q{is_plural: 'stolones'};
ok noun(q{naumachiae})->is_plural  => q{is_plural: 'naumachiae'};
ok noun(q{noumena})->is_plural  => q{is_plural: 'noumena'};
ok noun(q{oxen})->is_plural  => q{is_plural: 'oxen'};
ok noun(q{spermaria})->is_plural  => q{is_plural: 'spermaria'};
ok noun(q{addenda})->is_plural  => q{is_plural: 'addenda'};
ok noun(q{clitorises})->is_plural  => q{is_plural: 'clitorises'};
ok noun(q{afreets})->is_plural  => q{is_plural: 'afreets'};
ok noun(q{plesiosauri})->is_plural  => q{is_plural: 'plesiosauri'};
ok noun(q{terzetti})->is_plural  => q{is_plural: 'terzetti'};
ok noun(q{scorias})->is_plural  => q{is_plural: 'scorias'};
ok noun(q{vaginas})->is_plural  => q{is_plural: 'vaginas'};
ok noun(q{metros})->is_plural  => q{is_plural: 'metros'};
ok noun(q{putti})->is_plural  => q{is_plural: 'putti'};
ok noun(q{enconia})->is_plural  => q{is_plural: 'enconia'};
ok noun(q{amphipneusta})->is_plural  => q{is_plural: 'amphipneusta'};
ok noun(q{angiomata})->is_plural  => q{is_plural: 'angiomata'};
ok noun(q{moratoria})->is_plural  => q{is_plural: 'moratoria'};
ok noun(q{Parduscos})->is_plural  => q{is_plural: 'Parduscos'};
ok noun(q{jacobuses})->is_plural  => q{is_plural: 'jacobuses'};
ok noun(q{spadixes})->is_plural  => q{is_plural: 'spadixes'};
ok noun(q{pastorales})->is_plural  => q{is_plural: 'pastorales'};
ok noun(q{paradors})->is_plural  => q{is_plural: 'paradors'};
ok noun(q{tablina})->is_plural  => q{is_plural: 'tablina'};
ok noun(q{Annamese})->is_plural  => q{is_plural: 'Annamese'};
ok noun(q{minutias})->is_plural  => q{is_plural: 'minutias'};
ok noun(q{pycnia})->is_plural  => q{is_plural: 'pycnia'};
ok noun(q{zooecia})->is_plural  => q{is_plural: 'zooecia'};
ok noun(q{salvos})->is_plural  => q{is_plural: 'salvos'};
ok noun(q{oaths})->is_plural  => q{is_plural: 'oaths'};
ok noun(q{spectra})->is_plural  => q{is_plural: 'spectra'};
ok noun(q{legomena})->is_plural  => q{is_plural: 'legomena'};
ok noun(q{cabalette})->is_plural  => q{is_plural: 'cabalette'};
ok noun(q{loa})->is_plural  => q{is_plural: 'loa'};
ok noun(q{intertrigos})->is_plural  => q{is_plural: 'intertrigos'};
ok noun(q{phocae})->is_plural  => q{is_plural: 'phocae'};
ok noun(q{ascidia})->is_plural  => q{is_plural: 'ascidia'};
ok noun(q{sanatoriums})->is_plural  => q{is_plural: 'sanatoriums'};
ok noun(q{recti})->is_plural  => q{is_plural: 'recti'};
ok noun(q{puirt a beul})->is_plural  => q{is_plural: 'puirt a beul'};
ok noun(q{malagmata})->is_plural  => q{is_plural: 'malagmata'};
ok noun(q{separatrices})->is_plural  => q{is_plural: 'separatrices'};
ok noun(q{serpulae})->is_plural  => q{is_plural: 'serpulae'};
ok noun(q{2-star generals})->is_plural  => q{is_plural: '2-star generals'};
ok noun(q{Malabarese})->is_plural  => q{is_plural: 'Malabarese'};
ok noun(q{toxica})->is_plural  => q{is_plural: 'toxica'};
ok noun(q{anti-sera})->is_plural  => q{is_plural: 'anti-sera'};
ok noun(q{tropides})->is_plural  => q{is_plural: 'tropides'};
ok noun(q{autostrade})->is_plural  => q{is_plural: 'autostrade'};
ok noun(q{secantes})->is_plural  => q{is_plural: 'secantes'};
ok noun(q{promeropes})->is_plural  => q{is_plural: 'promeropes'};
ok noun(q{gladioluses})->is_plural  => q{is_plural: 'gladioluses'};
ok noun(q{casus belli})->is_plural  => q{is_plural: 'casus belli'};
ok noun(q{ports de bras})->is_plural  => q{is_plural: 'ports de bras'};
ok noun(q{tubuli})->is_plural  => q{is_plural: 'tubuli'};
ok noun(q{maries})->is_plural  => q{is_plural: 'maries'};
ok noun(q{brachiopoda})->is_plural  => q{is_plural: 'brachiopoda'};
ok noun(q{syntagmata})->is_plural  => q{is_plural: 'syntagmata'};
ok noun(q{hyphae})->is_plural  => q{is_plural: 'hyphae'};
ok noun(q{holothuriae})->is_plural  => q{is_plural: 'holothuriae'};
ok noun(q{mukims})->is_plural  => q{is_plural: 'mukims'};
ok noun(q{halluces})->is_plural  => q{is_plural: 'halluces'};
ok noun(q{furiosos})->is_plural  => q{is_plural: 'furiosos'};
ok noun(q{maximums})->is_plural  => q{is_plural: 'maximums'};
ok noun(q{grissini})->is_plural  => q{is_plural: 'grissini'};
ok noun(q{grani})->is_plural  => q{is_plural: 'grani'};
ok noun(q{millennia})->is_plural  => q{is_plural: 'millennia'};
ok noun(q{bravos})->is_plural  => q{is_plural: 'bravos'};
ok noun(q{star fishes})->is_plural  => q{is_plural: 'star fishes'};
ok noun(q{gonangia})->is_plural  => q{is_plural: 'gonangia'};
ok noun(q{pommes de terre})->is_plural  => q{is_plural: 'pommes de terre'};
ok noun(q{magnificos})->is_plural  => q{is_plural: 'magnificos'};
ok noun(q{avocados})->is_plural  => q{is_plural: 'avocados'};
ok noun(q{bratwurste})->is_plural  => q{is_plural: 'bratwurste'};
ok noun(q{scapi})->is_plural  => q{is_plural: 'scapi'};
ok noun(q{intaglios})->is_plural  => q{is_plural: 'intaglios'};
ok noun(q{pantos})->is_plural  => q{is_plural: 'pantos'};
ok noun(q{sacrums})->is_plural  => q{is_plural: 'sacrums'};
ok noun(q{porticos})->is_plural  => q{is_plural: 'porticos'};
ok noun(q{ritardandos})->is_plural  => q{is_plural: 'ritardandos'};
ok noun(q{statuses})->is_plural  => q{is_plural: 'statuses'};
ok noun(q{sequelae})->is_plural  => q{is_plural: 'sequelae'};
ok noun(q{Yokohamans})->is_plural  => q{is_plural: 'Yokohamans'};
ok noun(q{kylikes})->is_plural  => q{is_plural: 'kylikes'};
ok noun(q{polythecia})->is_plural  => q{is_plural: 'polythecia'};
ok noun(q{nouvelle riche})->is_plural  => q{is_plural: 'nouvelle riche'};
ok noun(q{prepennae})->is_plural  => q{is_plural: 'prepennae'};
ok noun(q{allegros})->is_plural  => q{is_plural: 'allegros'};
ok noun(q{phylums})->is_plural  => q{is_plural: 'phylums'};
ok noun(q{cementomata})->is_plural  => q{is_plural: 'cementomata'};
ok noun(q{melismata})->is_plural  => q{is_plural: 'melismata'};
ok noun(q{nonentia})->is_plural  => q{is_plural: 'nonentia'};
ok noun(q{emblememata})->is_plural  => q{is_plural: 'emblememata'};
ok noun(q{ovaria})->is_plural  => q{is_plural: 'ovaria'};
ok noun(q{sedilia})->is_plural  => q{is_plural: 'sedilia'};
ok noun(q{volcanelli})->is_plural  => q{is_plural: 'volcanelli'};
ok noun(q{tempietti})->is_plural  => q{is_plural: 'tempietti'};
ok noun(q{ale wives})->is_plural  => q{is_plural: 'ale wives'};
ok noun(q{prothalli})->is_plural  => q{is_plural: 'prothalli'};
ok noun(q{mycoplasmata})->is_plural  => q{is_plural: 'mycoplasmata'};
ok noun(q{porcini})->is_plural  => q{is_plural: 'porcini'};
ok noun(q{ambuscadoes})->is_plural  => q{is_plural: 'ambuscadoes'};
ok noun(q{cacti})->is_plural  => q{is_plural: 'cacti'};
ok noun(q{propylaea})->is_plural  => q{is_plural: 'propylaea'};
ok noun(q{bongoes})->is_plural  => q{is_plural: 'bongoes'};
ok noun(q{Cassinese})->is_plural  => q{is_plural: 'Cassinese'};
ok noun(q{bassos})->is_plural  => q{is_plural: 'bassos'};
ok noun(q{cynocephali})->is_plural  => q{is_plural: 'cynocephali'};
ok noun(q{monades})->is_plural  => q{is_plural: 'monades'};
ok noun(q{Togos})->is_plural  => q{is_plural: 'Togos'};
ok noun(q{haemangiomas})->is_plural  => q{is_plural: 'haemangiomas'};
ok noun(q{contretemps})->is_plural  => q{is_plural: 'contretemps'};
ok noun(q{zadrugas})->is_plural  => q{is_plural: 'zadrugas'};
ok noun(q{loxes})->is_plural  => q{is_plural: 'loxes'};
ok noun(q{hydras})->is_plural  => q{is_plural: 'hydras'};
ok noun(q{franc archers})->is_plural  => q{is_plural: 'franc archers'};
ok noun(q{entera})->is_plural  => q{is_plural: 'entera'};
ok noun(q{gumbos})->is_plural  => q{is_plural: 'gumbos'};
ok noun(q{latexes})->is_plural  => q{is_plural: 'latexes'};
ok noun(q{spasmi})->is_plural  => q{is_plural: 'spasmi'};
ok noun(q{avicularia})->is_plural  => q{is_plural: 'avicularia'};
ok noun(q{zucchini})->is_plural  => q{is_plural: 'zucchini'};
ok noun(q{quinquennia})->is_plural  => q{is_plural: 'quinquennia'};
ok noun(q{nautiluses})->is_plural  => q{is_plural: 'nautiluses'};
ok noun(q{atmas})->is_plural  => q{is_plural: 'atmas'};
ok noun(q{plasmodia})->is_plural  => q{is_plural: 'plasmodia'};
ok noun(q{linos})->is_plural  => q{is_plural: 'linos'};
ok noun(q{xiphoplastra})->is_plural  => q{is_plural: 'xiphoplastra'};
ok noun(q{kioko})->is_plural  => q{is_plural: 'kioko'};
ok noun(q{foramina})->is_plural  => q{is_plural: 'foramina'};
ok noun(q{Limans})->is_plural  => q{is_plural: 'Limans'};
ok noun(q{hemerae})->is_plural  => q{is_plural: 'hemerae'};
ok noun(q{rhombohedrons})->is_plural  => q{is_plural: 'rhombohedrons'};
ok noun(q{obeli})->is_plural  => q{is_plural: 'obeli'};
ok noun(q{contadini})->is_plural  => q{is_plural: 'contadini'};
ok noun(q{haddock})->is_plural  => q{is_plural: 'haddock'};
ok noun(q{Lorrainese})->is_plural  => q{is_plural: 'Lorrainese'};
ok noun(q{Plutos})->is_plural  => q{is_plural: 'Plutos'};
ok noun(q{synaxaria})->is_plural  => q{is_plural: 'synaxaria'};
ok noun(q{comatulae})->is_plural  => q{is_plural: 'comatulae'};
ok noun(q{variae lectiones})->is_plural  => q{is_plural: 'variae lectiones'};
ok noun(q{5-star generals})->is_plural  => q{is_plural: '5-star generals'};
ok noun(q{Romans})->is_plural  => q{is_plural: 'Romans'};
ok noun(q{stoai})->is_plural  => q{is_plural: 'stoai'};
ok noun(q{fora})->is_plural  => q{is_plural: 'fora'};
ok noun(q{megatheria})->is_plural  => q{is_plural: 'megatheria'};
ok noun(q{hetmans})->is_plural  => q{is_plural: 'hetmans'};
ok noun(q{haptera})->is_plural  => q{is_plural: 'haptera'};
ok noun(q{erfs})->is_plural  => q{is_plural: 'erfs'};
ok noun(q{maths})->is_plural  => q{is_plural: 'maths'};
ok noun(q{ballistas})->is_plural  => q{is_plural: 'ballistas'};
ok noun(q{coronas})->is_plural  => q{is_plural: 'coronas'};
ok noun(q{tetrasporangia})->is_plural  => q{is_plural: 'tetrasporangia'};
ok noun(q{spathae})->is_plural  => q{is_plural: 'spathae'};
ok noun(q{fundamenta divisionis})->is_plural  => q{is_plural: 'fundamenta divisionis'};
ok noun(q{pilleis})->is_plural  => q{is_plural: 'pilleis'};
ok noun(q{harmans})->is_plural  => q{is_plural: 'harmans'};
ok noun(q{Nentsi})->is_plural  => q{is_plural: 'Nentsi'};
ok noun(q{Kakapos})->is_plural  => q{is_plural: 'Kakapos'};
ok noun(q{fricandeaux})->is_plural  => q{is_plural: 'fricandeaux'};
ok noun(q{mixolimnia})->is_plural  => q{is_plural: 'mixolimnia'};
ok noun(q{rostra})->is_plural  => q{is_plural: 'rostra'};
ok noun(q{equinoctia})->is_plural  => q{is_plural: 'equinoctia'};
ok noun(q{galla})->is_plural  => q{is_plural: 'galla'};
ok noun(q{kantharoi})->is_plural  => q{is_plural: 'kantharoi'};
ok noun(q{psydracia})->is_plural  => q{is_plural: 'psydracia'};
ok noun(q{retinacula})->is_plural  => q{is_plural: 'retinacula'};
ok noun(q{crafts childer})->is_plural  => q{is_plural: 'crafts childer'};
ok noun(q{silices})->is_plural  => q{is_plural: 'silices'};
ok noun(q{monsignori})->is_plural  => q{is_plural: 'monsignori'};
ok noun(q{leishmaniae})->is_plural  => q{is_plural: 'leishmaniae'};
ok noun(q{caffe ristrettos})->is_plural  => q{is_plural: 'caffe ristrettos'};
ok noun(q{utriculariae})->is_plural  => q{is_plural: 'utriculariae'};
ok noun(q{salpas})->is_plural  => q{is_plural: 'salpas'};
ok noun(q{trichidia})->is_plural  => q{is_plural: 'trichidia'};
ok noun(q{brigadier generals})->is_plural  => q{is_plural: 'brigadier generals'};
ok noun(q{Nenets})->is_plural  => q{is_plural: 'Nenets'};
ok noun(q{remexes})->is_plural  => q{is_plural: 'remexes'};
ok noun(q{genii})->is_plural  => q{is_plural: 'genii'};
ok noun(q{glutaei})->is_plural  => q{is_plural: 'glutaei'};
ok noun(q{paragangliomata})->is_plural  => q{is_plural: 'paragangliomata'};
ok noun(q{interradii})->is_plural  => q{is_plural: 'interradii'};
ok noun(q{medulloblastomata})->is_plural  => q{is_plural: 'medulloblastomata'};
ok noun(q{squadristi})->is_plural  => q{is_plural: 'squadristi'};
ok noun(q{stomachs})->is_plural  => q{is_plural: 'stomachs'};
ok noun(q{cornetti})->is_plural  => q{is_plural: 'cornetti'};
ok noun(q{lipomata})->is_plural  => q{is_plural: 'lipomata'};
ok noun(q{sera})->is_plural  => q{is_plural: 'sera'};
ok noun(q{rond de jambes})->is_plural  => q{is_plural: 'rond de jambes'};
ok noun(q{unios})->is_plural  => q{is_plural: 'unios'};
ok noun(q{hemangiomata})->is_plural  => q{is_plural: 'hemangiomata'};
ok noun(q{secreta})->is_plural  => q{is_plural: 'secreta'};
ok noun(q{figuranti})->is_plural  => q{is_plural: 'figuranti'};
ok noun(q{zitelle})->is_plural  => q{is_plural: 'zitelle'};
ok noun(q{monimolimnia})->is_plural  => q{is_plural: 'monimolimnia'};
ok noun(q{epididymises})->is_plural  => q{is_plural: 'epididymises'};
ok noun(q{nautili})->is_plural  => q{is_plural: 'nautili'};
ok noun(q{euros})->is_plural  => q{is_plural: 'euros'};
ok noun(q{blini})->is_plural  => q{is_plural: 'blini'};
ok noun(q{ephemerides})->is_plural  => q{is_plural: 'ephemerides'};
ok noun(q{marquises})->is_plural  => q{is_plural: 'marquises'};
ok noun(q{teniae})->is_plural  => q{is_plural: 'teniae'};
ok noun(q{ambones})->is_plural  => q{is_plural: 'ambones'};
ok noun(q{yarramen})->is_plural  => q{is_plural: 'yarramen'};
ok noun(q{Marys})->is_plural  => q{is_plural: 'Marys'};
ok noun(q{hamadryades})->is_plural  => q{is_plural: 'hamadryades'};
ok noun(q{phalanxes})->is_plural  => q{is_plural: 'phalanxes'};
ok noun(q{viali})->is_plural  => q{is_plural: 'viali'};
ok noun(q{niellos})->is_plural  => q{is_plural: 'niellos'};
ok noun(q{calzoni})->is_plural  => q{is_plural: 'calzoni'};
ok noun(q{man-milliners})->is_plural  => q{is_plural: 'man-milliners'};
ok noun(q{muzzes})->is_plural  => q{is_plural: 'muzzes'};
ok noun(q{mezuzoth})->is_plural  => q{is_plural: 'mezuzoth'};
ok noun(q{fossae})->is_plural  => q{is_plural: 'fossae'};
ok noun(q{Amboinese})->is_plural  => q{is_plural: 'Amboinese'};
ok noun(q{minutiae})->is_plural  => q{is_plural: 'minutiae'};
ok noun(q{matinees musicales})->is_plural  => q{is_plural: 'matinees musicales'};
ok noun(q{1 star generals})->is_plural  => q{is_plural: '1 star generals'};
ok noun(q{intervalla})->is_plural  => q{is_plural: 'intervalla'};
ok noun(q{sarcophagi})->is_plural  => q{is_plural: 'sarcophagi'};
ok noun(q{modelli})->is_plural  => q{is_plural: 'modelli'};
ok noun(q{lidos})->is_plural  => q{is_plural: 'lidos'};
ok noun(q{hernias})->is_plural  => q{is_plural: 'hernias'};
ok noun(q{solos})->is_plural  => q{is_plural: 'solos'};
ok noun(q{parabolas})->is_plural  => q{is_plural: 'parabolas'};
ok noun(q{corpora})->is_plural  => q{is_plural: 'corpora'};
ok noun(q{haustra})->is_plural  => q{is_plural: 'haustra'};
ok noun(q{modellos})->is_plural  => q{is_plural: 'modellos'};
ok noun(q{terebratulas})->is_plural  => q{is_plural: 'terebratulas'};
ok noun(q{sizzes})->is_plural  => q{is_plural: 'sizzes'};
ok noun(q{Normans})->is_plural  => q{is_plural: 'Normans'};
ok noun(q{valute})->is_plural  => q{is_plural: 'valute'};
ok noun(q{pediluvia})->is_plural  => q{is_plural: 'pediluvia'};
ok noun(q{quadratrices})->is_plural  => q{is_plural: 'quadratrices'};
ok noun(q{vlaktes})->is_plural  => q{is_plural: 'vlaktes'};
ok noun(q{vasa})->is_plural  => q{is_plural: 'vasa'};
ok noun(q{lora})->is_plural  => q{is_plural: 'lora'};
ok noun(q{axons})->is_plural  => q{is_plural: 'axons'};
ok noun(q{perithecia})->is_plural  => q{is_plural: 'perithecia'};
ok noun(q{fomites})->is_plural  => q{is_plural: 'fomites'};
ok noun(q{triforia})->is_plural  => q{is_plural: 'triforia'};
ok noun(q{Tonkinese})->is_plural  => q{is_plural: 'Tonkinese'};
ok noun(q{Hottentotese})->is_plural  => q{is_plural: 'Hottentotese'};
ok noun(q{baals})->is_plural  => q{is_plural: 'baals'};
ok noun(q{propyla})->is_plural  => q{is_plural: 'propyla'};
ok noun(q{appressoria})->is_plural  => q{is_plural: 'appressoria'};
ok noun(q{trattorias})->is_plural  => q{is_plural: 'trattorias'};
ok noun(q{germaria})->is_plural  => q{is_plural: 'germaria'};
ok noun(q{veneres})->is_plural  => q{is_plural: 'veneres'};
ok noun(q{cortices})->is_plural  => q{is_plural: 'cortices'};
ok noun(q{mediatrices})->is_plural  => q{is_plural: 'mediatrices'};
ok noun(q{caddises})->is_plural  => q{is_plural: 'caddises'};
ok noun(q{courts martial})->is_plural  => q{is_plural: 'courts martial'};
ok noun(q{4-star generals})->is_plural  => q{is_plural: '4-star generals'};
ok noun(q{musees imaginaires})->is_plural  => q{is_plural: 'musees imaginaires'};
ok noun(q{autos})->is_plural  => q{is_plural: 'autos'};
ok noun(q{routes nationales})->is_plural  => q{is_plural: 'routes nationales'};
ok noun(q{raggare})->is_plural  => q{is_plural: 'raggare'};
ok noun(q{scombri})->is_plural  => q{is_plural: 'scombri'};
ok noun(q{pincers})->is_plural  => q{is_plural: 'pincers'};
ok noun(q{maars})->is_plural  => q{is_plural: 'maars'};
ok noun(q{honorariums})->is_plural  => q{is_plural: 'honorariums'};
ok noun(q{bulimi})->is_plural  => q{is_plural: 'bulimi'};
ok noun(q{streptococci})->is_plural  => q{is_plural: 'streptococci'};
ok noun(q{bandeaux})->is_plural  => q{is_plural: 'bandeaux'};
ok noun(q{jacobus})->is_plural  => q{is_plural: 'jacobus'};
ok noun(q{Otomies})->is_plural  => q{is_plural: 'Otomies'};
ok noun(q{pieds a terre})->is_plural  => q{is_plural: 'pieds a terre'};
ok noun(q{gousblomme})->is_plural  => q{is_plural: 'gousblomme'};
ok noun(q{stomia})->is_plural  => q{is_plural: 'stomia'};
ok noun(q{tiros})->is_plural  => q{is_plural: 'tiros'};
ok noun(q{xoana})->is_plural  => q{is_plural: 'xoana'};
ok noun(q{men-children})->is_plural  => q{is_plural: 'men-children'};
ok noun(q{amorini})->is_plural  => q{is_plural: 'amorini'};
ok noun(q{ragazze})->is_plural  => q{is_plural: 'ragazze'};
ok noun(q{xysti})->is_plural  => q{is_plural: 'xysti'};
ok noun(q{protypa})->is_plural  => q{is_plural: 'protypa'};
ok noun(q{pendulums})->is_plural  => q{is_plural: 'pendulums'};
ok noun(q{saxicavae})->is_plural  => q{is_plural: 'saxicavae'};
ok noun(q{moakses})->is_plural  => q{is_plural: 'moakses'};
ok noun(q{inuit})->is_plural  => q{is_plural: 'inuit'};
ok noun(q{Faroese})->is_plural  => q{is_plural: 'Faroese'};
ok noun(q{livedos})->is_plural  => q{is_plural: 'livedos'};
ok noun(q{conidia})->is_plural  => q{is_plural: 'conidia'};
ok noun(q{venuses})->is_plural  => q{is_plural: 'venuses'};
ok noun(q{sacella})->is_plural  => q{is_plural: 'sacella'};
ok noun(q{praecognita})->is_plural  => q{is_plural: 'praecognita'};
ok noun(q{wolves})->is_plural  => q{is_plural: 'wolves'};
ok noun(q{osteoclastomata})->is_plural  => q{is_plural: 'osteoclastomata'};
ok noun(q{toruses})->is_plural  => q{is_plural: 'toruses'};
ok noun(q{lymphangiomata})->is_plural  => q{is_plural: 'lymphangiomata'};
ok noun(q{ngwee})->is_plural  => q{is_plural: 'ngwee'};
ok noun(q{haruspices})->is_plural  => q{is_plural: 'haruspices'};
ok noun(q{mythoi})->is_plural  => q{is_plural: 'mythoi'};
ok noun(q{loas})->is_plural  => q{is_plural: 'loas'};
ok noun(q{stichidia})->is_plural  => q{is_plural: 'stichidia'};
ok noun(q{satellites})->is_plural  => q{is_plural: 'satellites'};
ok noun(q{yuon})->is_plural  => q{is_plural: 'yuon'};
ok noun(q{plexus})->is_plural  => q{is_plural: 'plexus'};
ok noun(q{punti blanchi})->is_plural  => q{is_plural: 'punti blanchi'};
ok noun(q{flag staves})->is_plural  => q{is_plural: 'flag staves'};
ok noun(q{meatuses})->is_plural  => q{is_plural: 'meatuses'};
ok noun(q{shorts})->is_plural  => q{is_plural: 'shorts'};
ok noun(q{tegmenta})->is_plural  => q{is_plural: 'tegmenta'};
ok noun(q{vaalpens})->is_plural  => q{is_plural: 'vaalpens'};
ok noun(q{bons mots})->is_plural  => q{is_plural: 'bons mots'};
ok noun(q{ipse dixits})->is_plural  => q{is_plural: 'ipse dixits'};
ok noun(q{vaalpensen})->is_plural  => q{is_plural: 'vaalpensen'};
ok noun(q{uri})->is_plural  => q{is_plural: 'uri'};
ok noun(q{buboes})->is_plural  => q{is_plural: 'buboes'};
ok noun(q{beaux esprits})->is_plural  => q{is_plural: 'beaux esprits'};
ok noun(q{dolphinariums})->is_plural  => q{is_plural: 'dolphinariums'};
ok noun(q{zlotys})->is_plural  => q{is_plural: 'zlotys'};
ok noun(q{mackerel})->is_plural  => q{is_plural: 'mackerel'};
ok noun(q{Ningbos})->is_plural  => q{is_plural: 'Ningbos'};
ok noun(q{six star generals})->is_plural  => q{is_plural: 'six star generals'};
ok noun(q{micros})->is_plural  => q{is_plural: 'micros'};
ok noun(q{piani})->is_plural  => q{is_plural: 'piani'};
ok noun(q{confluvia})->is_plural  => q{is_plural: 'confluvia'};
ok noun(q{musas})->is_plural  => q{is_plural: 'musas'};
ok noun(q{maxillae})->is_plural  => q{is_plural: 'maxillae'};
ok noun(q{sets-to})->is_plural  => q{is_plural: 'sets-to'};
ok noun(q{spicula})->is_plural  => q{is_plural: 'spicula'};
ok noun(q{spheges})->is_plural  => q{is_plural: 'spheges'};
ok noun(q{Macassarese})->is_plural  => q{is_plural: 'Macassarese'};
ok noun(q{solidos})->is_plural  => q{is_plural: 'solidos'};
ok noun(q{chassis})->is_plural  => q{is_plural: 'chassis'};
ok noun(q{nymphae})->is_plural  => q{is_plural: 'nymphae'};
ok noun(q{limbos})->is_plural  => q{is_plural: 'limbos'};
ok noun(q{multigravidas})->is_plural  => q{is_plural: 'multigravidas'};
ok noun(q{parcs fermes})->is_plural  => q{is_plural: 'parcs fermes'};
ok noun(q{pseudopodia})->is_plural  => q{is_plural: 'pseudopodia'};
ok noun(q{felos-de-se})->is_plural  => q{is_plural: 'felos-de-se'};
ok noun(q{spermatoa})->is_plural  => q{is_plural: 'spermatoa'};
ok noun(q{leges humanae})->is_plural  => q{is_plural: 'leges humanae'};
ok noun(q{plethra})->is_plural  => q{is_plural: 'plethra'};
ok noun(q{lepromas})->is_plural  => q{is_plural: 'lepromas'};
ok noun(q{ritardandi})->is_plural  => q{is_plural: 'ritardandi'};
ok noun(q{scherzandos})->is_plural  => q{is_plural: 'scherzandos'};
ok noun(q{endotheliomata})->is_plural  => q{is_plural: 'endotheliomata'};
ok noun(q{plateaus})->is_plural  => q{is_plural: 'plateaus'};
ok noun(q{sceattas})->is_plural  => q{is_plural: 'sceattas'};
ok noun(q{seminia})->is_plural  => q{is_plural: 'seminia'};
ok noun(q{vedutas})->is_plural  => q{is_plural: 'vedutas'};
ok noun(q{intermaxillae})->is_plural  => q{is_plural: 'intermaxillae'};
ok noun(q{repla})->is_plural  => q{is_plural: 'repla'};
ok noun(q{brethren german})->is_plural  => q{is_plural: 'brethren german'};
ok noun(q{Tacomans})->is_plural  => q{is_plural: 'Tacomans'};
ok noun(q{miasmas})->is_plural  => q{is_plural: 'miasmas'};
ok noun(q{principia})->is_plural  => q{is_plural: 'principia'};
ok noun(q{digitalises})->is_plural  => q{is_plural: 'digitalises'};
ok noun(q{aquaria})->is_plural  => q{is_plural: 'aquaria'};
ok noun(q{finger-ends})->is_plural  => q{is_plural: 'finger-ends'};
ok noun(q{knoppers})->is_plural  => q{is_plural: 'knoppers'};
ok noun(q{brothers})->is_plural  => q{is_plural: 'brothers'};
ok noun(q{Monacos})->is_plural  => q{is_plural: 'Monacos'};
ok noun(q{leprosaria})->is_plural  => q{is_plural: 'leprosaria'};
ok noun(q{criteria})->is_plural  => q{is_plural: 'criteria'};
ok noun(q{lineae})->is_plural  => q{is_plural: 'lineae'};
ok noun(q{cognoscenti})->is_plural  => q{is_plural: 'cognoscenti'};
ok noun(q{palpebrae})->is_plural  => q{is_plural: 'palpebrae'};
ok noun(q{plankton})->is_plural  => q{is_plural: 'plankton'};
ok noun(q{senes})->is_plural  => q{is_plural: 'senes'};
ok noun(q{sphagnums})->is_plural  => q{is_plural: 'sphagnums'};
ok noun(q{duumviri})->is_plural  => q{is_plural: 'duumviri'};
ok noun(q{nucleoluses})->is_plural  => q{is_plural: 'nucleoluses'};
ok noun(q{hymnaria})->is_plural  => q{is_plural: 'hymnaria'};
ok noun(q{bursae})->is_plural  => q{is_plural: 'bursae'};
ok noun(q{chromonemata})->is_plural  => q{is_plural: 'chromonemata'};
ok noun(q{3-star generals})->is_plural  => q{is_plural: '3-star generals'};
ok noun(q{sheep})->is_plural  => q{is_plural: 'sheep'};
ok noun(q{fibulas})->is_plural  => q{is_plural: 'fibulas'};
ok noun(q{starosti})->is_plural  => q{is_plural: 'starosti'};
ok noun(q{chapplies})->is_plural  => q{is_plural: 'chapplies'};
ok noun(q{calluses})->is_plural  => q{is_plural: 'calluses'};
ok noun(q{oxyurides})->is_plural  => q{is_plural: 'oxyurides'};
ok noun(q{zoeas})->is_plural  => q{is_plural: 'zoeas'};
ok noun(q{alti})->is_plural  => q{is_plural: 'alti'};
ok noun(q{conoscenti})->is_plural  => q{is_plural: 'conoscenti'};
ok noun(q{osteomata})->is_plural  => q{is_plural: 'osteomata'};
ok noun(q{samboes})->is_plural  => q{is_plural: 'samboes'};
ok noun(q{Borghese})->is_plural  => q{is_plural: 'Borghese'};
ok noun(q{hake})->is_plural  => q{is_plural: 'hake'};
ok noun(q{dace})->is_plural  => q{is_plural: 'dace'};
ok noun(q{cuspides})->is_plural  => q{is_plural: 'cuspides'};
ok noun(q{septemviri})->is_plural  => q{is_plural: 'septemviri'};
ok noun(q{bierstubes})->is_plural  => q{is_plural: 'bierstubes'};
ok noun(q{magili})->is_plural  => q{is_plural: 'magili'};
ok noun(q{scotomata})->is_plural  => q{is_plural: 'scotomata'};
ok noun(q{papulae})->is_plural  => q{is_plural: 'papulae'};
ok noun(q{vibratos})->is_plural  => q{is_plural: 'vibratos'};
ok noun(q{cyathi})->is_plural  => q{is_plural: 'cyathi'};
ok noun(q{sarissae})->is_plural  => q{is_plural: 'sarissae'};
ok noun(q{prothallia})->is_plural  => q{is_plural: 'prothallia'};
ok noun(q{auslesen})->is_plural  => q{is_plural: 'auslesen'};
ok noun(q{tetrapleura})->is_plural  => q{is_plural: 'tetrapleura'};
ok noun(q{trabeculae})->is_plural  => q{is_plural: 'trabeculae'};
ok noun(q{lacunars})->is_plural  => q{is_plural: 'lacunars'};
ok noun(q{giunchi})->is_plural  => q{is_plural: 'giunchi'};
ok noun(q{Bamakos})->is_plural  => q{is_plural: 'Bamakos'};
ok noun(q{ses})->is_plural  => q{is_plural: 'ses'};
ok noun(q{microfiche})->is_plural  => q{is_plural: 'microfiche'};
ok noun(q{impetus})->is_plural  => q{is_plural: 'impetus'};
ok noun(q{hemangiomas})->is_plural  => q{is_plural: 'hemangiomas'};
ok noun(q{maxima})->is_plural  => q{is_plural: 'maxima'};
ok noun(q{hooves})->is_plural  => q{is_plural: 'hooves'};
ok noun(q{tegulae})->is_plural  => q{is_plural: 'tegulae'};
ok noun(q{formulas})->is_plural  => q{is_plural: 'formulas'};
ok noun(q{tsubos})->is_plural  => q{is_plural: 'tsubos'};
ok noun(q{descripta})->is_plural  => q{is_plural: 'descripta'};
ok noun(q{bodegones})->is_plural  => q{is_plural: 'bodegones'};
ok noun(q{gymnasiums})->is_plural  => q{is_plural: 'gymnasiums'};
ok noun(q{matzot})->is_plural  => q{is_plural: 'matzot'};
ok noun(q{Harlemese})->is_plural  => q{is_plural: 'Harlemese'};
ok noun(q{dumkas})->is_plural  => q{is_plural: 'dumkas'};
ok noun(q{Torinos})->is_plural  => q{is_plural: 'Torinos'};
ok noun(q{lord-lieutenants})->is_plural  => q{is_plural: 'lord-lieutenants'};
ok noun(q{sphaerideum})->is_plural  => q{is_plural: 'sphaerideum'};
ok noun(q{blues})->is_plural  => q{is_plural: 'blues'};
ok noun(q{imagos})->is_plural  => q{is_plural: 'imagos'};
ok noun(q{labra})->is_plural  => q{is_plural: 'labra'};
ok noun(q{solstitia})->is_plural  => q{is_plural: 'solstitia'};
ok noun(q{rems})->is_plural  => q{is_plural: 'rems'};
ok noun(q{statuae})->is_plural  => q{is_plural: 'statuae'};
ok noun(q{apparatchiks})->is_plural  => q{is_plural: 'apparatchiks'};
ok noun(q{deposita})->is_plural  => q{is_plural: 'deposita'};
ok noun(q{scriptoriums})->is_plural  => q{is_plural: 'scriptoriums'};
ok noun(q{Mexicos})->is_plural  => q{is_plural: 'Mexicos'};
ok noun(q{paisas})->is_plural  => q{is_plural: 'paisas'};
ok noun(q{species})->is_plural  => q{is_plural: 'species'};
ok noun(q{caryatides})->is_plural  => q{is_plural: 'caryatides'};
ok noun(q{branchiopoda})->is_plural  => q{is_plural: 'branchiopoda'};
ok noun(q{trellises})->is_plural  => q{is_plural: 'trellises'};
ok noun(q{teals})->is_plural  => q{is_plural: 'teals'};
ok noun(q{theologoumena})->is_plural  => q{is_plural: 'theologoumena'};
ok noun(q{morosi})->is_plural  => q{is_plural: 'morosi'};
ok noun(q{gorgoniae})->is_plural  => q{is_plural: 'gorgoniae'};
ok noun(q{brothers-german})->is_plural  => q{is_plural: 'brothers-german'};
ok noun(q{convolvuli})->is_plural  => q{is_plural: 'convolvuli'};
ok noun(q{turrones})->is_plural  => q{is_plural: 'turrones'};
ok noun(q{octopuses})->is_plural  => q{is_plural: 'octopuses'};
ok noun(q{oxymorons})->is_plural  => q{is_plural: 'oxymorons'};
ok noun(q{mucros})->is_plural  => q{is_plural: 'mucros'};
ok noun(q{parhelions})->is_plural  => q{is_plural: 'parhelions'};
ok noun(q{breakaways})->is_plural  => q{is_plural: 'breakaways'};
ok noun(q{frati})->is_plural  => q{is_plural: 'frati'};
ok noun(q{stasimons})->is_plural  => q{is_plural: 'stasimons'};
ok noun(q{aristae})->is_plural  => q{is_plural: 'aristae'};
ok noun(q{headquarters})->is_plural  => q{is_plural: 'headquarters'};
ok noun(q{turrons})->is_plural  => q{is_plural: 'turrons'};
ok noun(q{librettos})->is_plural  => q{is_plural: 'librettos'};
ok noun(q{conversazioni})->is_plural  => q{is_plural: 'conversazioni'};
ok noun(q{precis})->is_plural  => q{is_plural: 'precis'};
ok noun(q{signa})->is_plural  => q{is_plural: 'signa'};
ok noun(q{pyramidions})->is_plural  => q{is_plural: 'pyramidions'};
ok noun(q{vortices})->is_plural  => q{is_plural: 'vortices'};
ok noun(q{elves})->is_plural  => q{is_plural: 'elves'};
ok noun(q{Iquicos})->is_plural  => q{is_plural: 'Iquicos'};
ok noun(q{stryddae})->is_plural  => q{is_plural: 'stryddae'};
ok noun(q{scirrhi})->is_plural  => q{is_plural: 'scirrhi'};
ok noun(q{charismas})->is_plural  => q{is_plural: 'charismas'};
ok noun(q{vers libres})->is_plural  => q{is_plural: 'vers libres'};
ok noun(q{strategoi})->is_plural  => q{is_plural: 'strategoi'};
ok noun(q{stoas})->is_plural  => q{is_plural: 'stoas'};
ok noun(q{concertinos})->is_plural  => q{is_plural: 'concertinos'};
ok noun(q{cosmoses})->is_plural  => q{is_plural: 'cosmoses'};
ok noun(q{whoever})->is_plural  => q{is_plural: 'whoever'};
ok noun(q{ganglions})->is_plural  => q{is_plural: 'ganglions'};
ok noun(q{bemas})->is_plural  => q{is_plural: 'bemas'};
ok noun(q{gastrocnemii})->is_plural  => q{is_plural: 'gastrocnemii'};
ok noun(q{terminuses})->is_plural  => q{is_plural: 'terminuses'};
ok noun(q{triradii})->is_plural  => q{is_plural: 'triradii'};
ok noun(q{snipe})->is_plural  => q{is_plural: 'snipe'};
ok noun(q{zoa})->is_plural  => q{is_plural: 'zoa'};
ok noun(q{tipulae})->is_plural  => q{is_plural: 'tipulae'};
ok noun(q{foramens})->is_plural  => q{is_plural: 'foramens'};
ok noun(q{abscissae})->is_plural  => q{is_plural: 'abscissae'};
ok noun(q{neurinomas})->is_plural  => q{is_plural: 'neurinomas'};
ok noun(q{ricercars})->is_plural  => q{is_plural: 'ricercars'};
ok noun(q{scapulas})->is_plural  => q{is_plural: 'scapulas'};
ok noun(q{mongooses})->is_plural  => q{is_plural: 'mongooses'};
ok noun(q{humeri})->is_plural  => q{is_plural: 'humeri'};
ok noun(q{rhizomas})->is_plural  => q{is_plural: 'rhizomas'};
ok noun(q{fasciae})->is_plural  => q{is_plural: 'fasciae'};
ok noun(q{ottomans})->is_plural  => q{is_plural: 'ottomans'};
ok noun(q{we})->is_plural  => q{is_plural: 'we'};
ok noun(q{facienda})->is_plural  => q{is_plural: 'facienda'};
ok noun(q{sarcinae})->is_plural  => q{is_plural: 'sarcinae'};
ok noun(q{corgys})->is_plural  => q{is_plural: 'corgys'};
ok noun(q{ragazzi})->is_plural  => q{is_plural: 'ragazzi'};
ok noun(q{Romagnese})->is_plural  => q{is_plural: 'Romagnese'};
ok noun(q{soshi})->is_plural  => q{is_plural: 'soshi'};
ok noun(q{conys})->is_plural  => q{is_plural: 'conys'};
ok noun(q{Orinocos})->is_plural  => q{is_plural: 'Orinocos'};
ok noun(q{celiae})->is_plural  => q{is_plural: 'celiae'};
ok noun(q{epididymides})->is_plural  => q{is_plural: 'epididymides'};
ok noun(q{rara avises})->is_plural  => q{is_plural: 'rara avises'};
ok noun(q{hapax legomenons})->is_plural  => q{is_plural: 'hapax legomenons'};
ok noun(q{taenias})->is_plural  => q{is_plural: 'taenias'};
ok noun(q{phyla})->is_plural  => q{is_plural: 'phyla'};
ok noun(q{stelas})->is_plural  => q{is_plural: 'stelas'};
ok noun(q{divertimentos})->is_plural  => q{is_plural: 'divertimentos'};
ok noun(q{penises})->is_plural  => q{is_plural: 'penises'};
ok noun(q{bullae})->is_plural  => q{is_plural: 'bullae'};
ok noun(q{waldoes})->is_plural  => q{is_plural: 'waldoes'};
ok noun(q{bozzetti})->is_plural  => q{is_plural: 'bozzetti'};
ok noun(q{Muranese})->is_plural  => q{is_plural: 'Muranese'};
ok noun(q{thesauruses})->is_plural  => q{is_plural: 'thesauruses'};
ok noun(q{modii})->is_plural  => q{is_plural: 'modii'};
ok noun(q{sacra})->is_plural  => q{is_plural: 'sacra'};
ok noun(q{jumbos})->is_plural  => q{is_plural: 'jumbos'};
ok noun(q{nephridia})->is_plural  => q{is_plural: 'nephridia'};
ok noun(q{osmeteria})->is_plural  => q{is_plural: 'osmeteria'};
ok noun(q{menus})->is_plural  => q{is_plural: 'menus'};
ok noun(q{ballate})->is_plural  => q{is_plural: 'ballate'};
ok noun(q{cilantros})->is_plural  => q{is_plural: 'cilantros'};
ok noun(q{ovula})->is_plural  => q{is_plural: 'ovula'};
ok noun(q{culs de sac})->is_plural  => q{is_plural: 'culs de sac'};
ok noun(q{valleculae})->is_plural  => q{is_plural: 'valleculae'};
ok noun(q{lemurs})->is_plural  => q{is_plural: 'lemurs'};
ok noun(q{stigmariae})->is_plural  => q{is_plural: 'stigmariae'};
ok noun(q{chitarroni})->is_plural  => q{is_plural: 'chitarroni'};
ok noun(q{referendums})->is_plural  => q{is_plural: 'referendums'};
ok noun(q{Tirolese})->is_plural  => q{is_plural: 'Tirolese'};
ok noun(q{ungues})->is_plural  => q{is_plural: 'ungues'};
ok noun(q{plasmalemmae})->is_plural  => q{is_plural: 'plasmalemmae'};
ok noun(q{manteaux})->is_plural  => q{is_plural: 'manteaux'};
ok noun(q{parabolani})->is_plural  => q{is_plural: 'parabolani'};
ok noun(q{rites de passage})->is_plural  => q{is_plural: 'rites de passage'};
ok noun(q{crowfoots})->is_plural  => q{is_plural: 'crowfoots'};
ok noun(q{dichasia})->is_plural  => q{is_plural: 'dichasia'};
ok noun(q{pectens})->is_plural  => q{is_plural: 'pectens'};
ok noun(q{mortaria})->is_plural  => q{is_plural: 'mortaria'};
ok noun(q{hetairai})->is_plural  => q{is_plural: 'hetairai'};
ok noun(q{lapiths})->is_plural  => q{is_plural: 'lapiths'};
ok noun(q{Germans})->is_plural  => q{is_plural: 'Germans'};
ok noun(q{omenta})->is_plural  => q{is_plural: 'omenta'};
ok noun(q{Bolognese})->is_plural  => q{is_plural: 'Bolognese'};
ok noun(q{zucche})->is_plural  => q{is_plural: 'zucche'};
ok noun(q{acini})->is_plural  => q{is_plural: 'acini'};
ok noun(q{zuzim})->is_plural  => q{is_plural: 'zuzim'};
ok noun(q{ploshchadki})->is_plural  => q{is_plural: 'ploshchadki'};
ok noun(q{listeria})->is_plural  => q{is_plural: 'listeria'};
ok noun(q{pteropi})->is_plural  => q{is_plural: 'pteropi'};
ok noun(q{bylinas})->is_plural  => q{is_plural: 'bylinas'};
ok noun(q{goyim})->is_plural  => q{is_plural: 'goyim'};
ok noun(q{blinis})->is_plural  => q{is_plural: 'blinis'};
ok noun(q{myelomas})->is_plural  => q{is_plural: 'myelomas'};
ok noun(q{curricula})->is_plural  => q{is_plural: 'curricula'};
ok noun(q{triumviri})->is_plural  => q{is_plural: 'triumviri'};
ok noun(q{adieus})->is_plural  => q{is_plural: 'adieus'};
ok noun(q{hijinks})->is_plural  => q{is_plural: 'hijinks'};
ok noun(q{topazes})->is_plural  => q{is_plural: 'topazes'};
ok noun(q{pike})->is_plural  => q{is_plural: 'pike'};
ok noun(q{agenda})->is_plural  => q{is_plural: 'agenda'};
ok noun(q{prime donne})->is_plural  => q{is_plural: 'prime donne'};
ok noun(q{sinus})->is_plural  => q{is_plural: 'sinus'};
ok noun(q{neritae})->is_plural  => q{is_plural: 'neritae'};
ok noun(q{spirilla})->is_plural  => q{is_plural: 'spirilla'};
ok noun(q{nouveaux pauvres})->is_plural  => q{is_plural: 'nouveaux pauvres'};
ok noun(q{Asherahs})->is_plural  => q{is_plural: 'Asherahs'};
ok noun(q{improperia})->is_plural  => q{is_plural: 'improperia'};
ok noun(q{uomini universali})->is_plural  => q{is_plural: 'uomini universali'};
ok noun(q{taleae})->is_plural  => q{is_plural: 'taleae'};
ok noun(q{pendula})->is_plural  => q{is_plural: 'pendula'};
ok noun(q{coituses})->is_plural  => q{is_plural: 'coituses'};
ok noun(q{craniums})->is_plural  => q{is_plural: 'craniums'};
ok noun(q{solidi})->is_plural  => q{is_plural: 'solidi'};
ok noun(q{stipulae})->is_plural  => q{is_plural: 'stipulae'};
ok noun(q{lapithae})->is_plural  => q{is_plural: 'lapithae'};
ok noun(q{charismata})->is_plural  => q{is_plural: 'charismata'};
ok noun(q{vibriones})->is_plural  => q{is_plural: 'vibriones'};
ok noun(q{sets-out})->is_plural  => q{is_plural: 'sets-out'};
ok noun(q{cyclopes})->is_plural  => q{is_plural: 'cyclopes'};
ok noun(q{tetanothra})->is_plural  => q{is_plural: 'tetanothra'};
ok noun(q{zygantra})->is_plural  => q{is_plural: 'zygantra'};
ok noun(q{vaginulae})->is_plural  => q{is_plural: 'vaginulae'};
ok noun(q{beerenauslesen})->is_plural  => q{is_plural: 'beerenauslesen'};
ok noun(q{zuppe})->is_plural  => q{is_plural: 'zuppe'};
ok noun(q{hamadrayads})->is_plural  => q{is_plural: 'hamadrayads'};
ok noun(q{propleura})->is_plural  => q{is_plural: 'propleura'};
ok noun(q{ultimata})->is_plural  => q{is_plural: 'ultimata'};
ok noun(q{hyperbata})->is_plural  => q{is_plural: 'hyperbata'};
ok noun(q{zingani})->is_plural  => q{is_plural: 'zingani'};
ok noun(q{hippopotami})->is_plural  => q{is_plural: 'hippopotami'};
ok noun(q{mementos})->is_plural  => q{is_plural: 'mementos'};
ok noun(q{Goanese})->is_plural  => q{is_plural: 'Goanese'};
ok noun(q{wadys})->is_plural  => q{is_plural: 'wadys'};
ok noun(q{chaoses})->is_plural  => q{is_plural: 'chaoses'};
ok noun(q{neurulae})->is_plural  => q{is_plural: 'neurulae'};
ok noun(q{stamen})->is_plural  => q{is_plural: 'stamen'};
ok noun(q{diporpae})->is_plural  => q{is_plural: 'diporpae'};
ok noun(q{centumviri})->is_plural  => q{is_plural: 'centumviri'};
ok noun(q{hypolimnia})->is_plural  => q{is_plural: 'hypolimnia'};
ok noun(q{bhikshook})->is_plural  => q{is_plural: 'bhikshook'};
ok noun(q{uteri})->is_plural  => q{is_plural: 'uteri'};
ok noun(q{gallas})->is_plural  => q{is_plural: 'gallas'};
ok noun(q{milieux})->is_plural  => q{is_plural: 'milieux'};
ok noun(q{trapezia})->is_plural  => q{is_plural: 'trapezia'};
ok noun(q{aphelia})->is_plural  => q{is_plural: 'aphelia'};
ok noun(q{ambuscados})->is_plural  => q{is_plural: 'ambuscados'};
ok noun(q{insulae})->is_plural  => q{is_plural: 'insulae'};
ok noun(q{sensedata})->is_plural  => q{is_plural: 'sensedata'};
ok noun(q{anthemia})->is_plural  => q{is_plural: 'anthemia'};
ok noun(q{Kinkimavos})->is_plural  => q{is_plural: 'Kinkimavos'};
ok noun(q{felones de se})->is_plural  => q{is_plural: 'felones de se'};
ok noun(q{fingers ends})->is_plural  => q{is_plural: 'fingers ends'};
ok noun(q{haustella})->is_plural  => q{is_plural: 'haustella'};
ok noun(q{prolegomena})->is_plural  => q{is_plural: 'prolegomena'};
ok noun(q{Colombos})->is_plural  => q{is_plural: 'Colombos'};
ok noun(q{roes})->is_plural  => q{is_plural: 'roes'};
ok noun(q{regidors})->is_plural  => q{is_plural: 'regidors'};
ok noun(q{vasculitises})->is_plural  => q{is_plural: 'vasculitises'};
ok noun(q{vibracula})->is_plural  => q{is_plural: 'vibracula'};
ok noun(q{ruses de guerre})->is_plural  => q{is_plural: 'ruses de guerre'};
ok noun(q{proboscises})->is_plural  => q{is_plural: 'proboscises'};
ok noun(q{kars})->is_plural  => q{is_plural: 'kars'};
ok noun(q{pinnas})->is_plural  => q{is_plural: 'pinnas'};
ok noun(q{Niasese})->is_plural  => q{is_plural: 'Niasese'};
ok noun(q{Dongolese})->is_plural  => q{is_plural: 'Dongolese'};
ok noun(q{basses})->is_plural  => q{is_plural: 'basses'};
ok noun(q{nagaiki})->is_plural  => q{is_plural: 'nagaiki'};
ok noun(q{urodaea})->is_plural  => q{is_plural: 'urodaea'};
ok noun(q{hymenia})->is_plural  => q{is_plural: 'hymenia'};
ok noun(q{ricercate})->is_plural  => q{is_plural: 'ricercate'};
ok noun(q{gizmos})->is_plural  => q{is_plural: 'gizmos'};
ok noun(q{condottieri})->is_plural  => q{is_plural: 'condottieri'};
ok noun(q{zloty})->is_plural  => q{is_plural: 'zloty'};
ok noun(q{carices})->is_plural  => q{is_plural: 'carices'};
ok noun(q{enemas})->is_plural  => q{is_plural: 'enemas'};
ok noun(q{pelves})->is_plural  => q{is_plural: 'pelves'};
ok noun(q{argumenta})->is_plural  => q{is_plural: 'argumenta'};
ok noun(q{cabalettas})->is_plural  => q{is_plural: 'cabalettas'};
ok noun(q{espressos})->is_plural  => q{is_plural: 'espressos'};
ok noun(q{sistra})->is_plural  => q{is_plural: 'sistra'};
ok noun(q{apparatus})->is_plural  => q{is_plural: 'apparatus'};
ok noun(q{succineae})->is_plural  => q{is_plural: 'succineae'};
ok noun(q{chrysalides})->is_plural  => q{is_plural: 'chrysalides'};
ok noun(q{refugia})->is_plural  => q{is_plural: 'refugia'};
ok noun(q{tegmina})->is_plural  => q{is_plural: 'tegmina'};
ok noun(q{flatfoots})->is_plural  => q{is_plural: 'flatfoots'};
ok noun(q{waltzes})->is_plural  => q{is_plural: 'waltzes'};
ok noun(q{bacilli})->is_plural  => q{is_plural: 'bacilli'};
ok noun(q{vittae})->is_plural  => q{is_plural: 'vittae'};
ok noun(q{whomsoever})->is_plural  => q{is_plural: 'whomsoever'};
ok noun(q{caribous})->is_plural  => q{is_plural: 'caribous'};
ok noun(q{symplasmata})->is_plural  => q{is_plural: 'symplasmata'};
ok noun(q{archipelagoes})->is_plural  => q{is_plural: 'archipelagoes'};
ok noun(q{compendia})->is_plural  => q{is_plural: 'compendia'};
ok noun(q{thelyca})->is_plural  => q{is_plural: 'thelyca'};
ok noun(q{tableaux})->is_plural  => q{is_plural: 'tableaux'};
ok noun(q{proscollae})->is_plural  => q{is_plural: 'proscollae'};
ok noun(q{siliquae})->is_plural  => q{is_plural: 'siliquae'};
ok noun(q{optimums})->is_plural  => q{is_plural: 'optimums'};
ok noun(q{whosesoever})->is_plural  => q{is_plural: 'whosesoever'};
ok noun(q{logos})->is_plural  => q{is_plural: 'logos'};
ok noun(q{programmata})->is_plural  => q{is_plural: 'programmata'};
ok noun(q{armadillos})->is_plural  => q{is_plural: 'armadillos'};
ok noun(q{bersaglieri})->is_plural  => q{is_plural: 'bersaglieri'};
ok noun(q{laciniae})->is_plural  => q{is_plural: 'laciniae'};
ok noun(q{lemnisci})->is_plural  => q{is_plural: 'lemnisci'};
ok noun(q{hemi-elytra})->is_plural  => q{is_plural: 'hemi-elytra'};
ok noun(q{suprascapulae})->is_plural  => q{is_plural: 'suprascapulae'};
ok noun(q{heen})->is_plural  => q{is_plural: 'heen'};
ok noun(q{columbaria})->is_plural  => q{is_plural: 'columbaria'};
ok noun(q{Leonese})->is_plural  => q{is_plural: 'Leonese'};
ok noun(q{ova})->is_plural  => q{is_plural: 'ova'};
ok noun(q{mycorhizae})->is_plural  => q{is_plural: 'mycorhizae'};
ok noun(q{washers-up})->is_plural  => q{is_plural: 'washers-up'};
ok noun(q{antennae})->is_plural  => q{is_plural: 'antennae'};
ok noun(q{voorbokke})->is_plural  => q{is_plural: 'voorbokke'};
ok noun(q{meretrices})->is_plural  => q{is_plural: 'meretrices'};
ok noun(q{tonneaux})->is_plural  => q{is_plural: 'tonneaux'};
ok noun(q{megalosauri})->is_plural  => q{is_plural: 'megalosauri'};
ok noun(q{commandos})->is_plural  => q{is_plural: 'commandos'};
ok noun(q{risottos})->is_plural  => q{is_plural: 'risottos'};
ok noun(q{mares})->is_plural  => q{is_plural: 'mares'};
ok noun(q{pelvises})->is_plural  => q{is_plural: 'pelvises'};
ok noun(q{hefte})->is_plural  => q{is_plural: 'hefte'};
ok noun(q{Burmese})->is_plural  => q{is_plural: 'Burmese'};
ok noun(q{Achinese})->is_plural  => q{is_plural: 'Achinese'};
ok noun(q{Maltese})->is_plural  => q{is_plural: 'Maltese'};
ok noun(q{halibut})->is_plural  => q{is_plural: 'halibut'};
ok noun(q{dragomans})->is_plural  => q{is_plural: 'dragomans'};
ok noun(q{incubi})->is_plural  => q{is_plural: 'incubi'};
ok noun(q{Bernese})->is_plural  => q{is_plural: 'Bernese'};
ok noun(q{phrenes})->is_plural  => q{is_plural: 'phrenes'};
ok noun(q{culs-de-sac})->is_plural  => q{is_plural: 'culs-de-sac'};
ok noun(q{corpuses})->is_plural  => q{is_plural: 'corpuses'};
ok noun(q{caeca})->is_plural  => q{is_plural: 'caeca'};
ok noun(q{neumata})->is_plural  => q{is_plural: 'neumata'};
ok noun(q{rideaus})->is_plural  => q{is_plural: 'rideaus'};
ok noun(q{abstracta})->is_plural  => q{is_plural: 'abstracta'};
ok noun(q{femora})->is_plural  => q{is_plural: 'femora'};
ok noun(q{protococci})->is_plural  => q{is_plural: 'protococci'};
ok noun(q{familiae})->is_plural  => q{is_plural: 'familiae'};
ok noun(q{miasmata})->is_plural  => q{is_plural: 'miasmata'};
ok noun(q{stratums})->is_plural  => q{is_plural: 'stratums'};
ok noun(q{actiniae})->is_plural  => q{is_plural: 'actiniae'};
ok noun(q{triclinia})->is_plural  => q{is_plural: 'triclinia'};
ok noun(q{cantus})->is_plural  => q{is_plural: 'cantus'};
ok noun(q{libretti})->is_plural  => q{is_plural: 'libretti'};
ok noun(q{lingulae})->is_plural  => q{is_plural: 'lingulae'};
ok noun(q{aboiteaux})->is_plural  => q{is_plural: 'aboiteaux'};
ok noun(q{ichthyosauri})->is_plural  => q{is_plural: 'ichthyosauri'};
ok noun(q{percepta})->is_plural  => q{is_plural: 'percepta'};
ok noun(q{kibbutzim})->is_plural  => q{is_plural: 'kibbutzim'};
ok noun(q{stalactites})->is_plural  => q{is_plural: 'stalactites'};
ok noun(q{talismans})->is_plural  => q{is_plural: 'talismans'};
ok noun(q{glomera})->is_plural  => q{is_plural: 'glomera'};
ok noun(q{captain generals})->is_plural  => q{is_plural: 'captain generals'};
ok noun(q{yourselves})->is_plural  => q{is_plural: 'yourselves'};
ok noun(q{glacises})->is_plural  => q{is_plural: 'glacises'};
ok noun(q{stillicidia})->is_plural  => q{is_plural: 'stillicidia'};
ok noun(q{tsubo})->is_plural  => q{is_plural: 'tsubo'};
ok noun(q{nielli})->is_plural  => q{is_plural: 'nielli'};
ok noun(q{snoozes})->is_plural  => q{is_plural: 'snoozes'};
ok noun(q{tabellae})->is_plural  => q{is_plural: 'tabellae'};
ok noun(q{sums-total})->is_plural  => q{is_plural: 'sums-total'};
ok noun(q{plenaria})->is_plural  => q{is_plural: 'plenaria'};
ok noun(q{makuta})->is_plural  => q{is_plural: 'makuta'};
ok noun(q{myae})->is_plural  => q{is_plural: 'myae'};
ok noun(q{micetraps})->is_plural  => q{is_plural: 'micetraps'};
ok noun(q{acropolises})->is_plural  => q{is_plural: 'acropolises'};
ok noun(q{gubernacula})->is_plural  => q{is_plural: 'gubernacula'};
ok noun(q{bajocchi})->is_plural  => q{is_plural: 'bajocchi'};
ok noun(q{kobo})->is_plural  => q{is_plural: 'kobo'};
ok noun(q{strambotti})->is_plural  => q{is_plural: 'strambotti'};
ok noun(q{violette})->is_plural  => q{is_plural: 'violette'};
ok noun(q{moduluses})->is_plural  => q{is_plural: 'moduluses'};
ok noun(q{solfeggi})->is_plural  => q{is_plural: 'solfeggi'};
ok noun(q{data})->is_plural  => q{is_plural: 'data'};
ok noun(q{rads})->is_plural  => q{is_plural: 'rads'};
ok noun(q{sinfonias})->is_plural  => q{is_plural: 'sinfonias'};
ok noun(q{pinetums})->is_plural  => q{is_plural: 'pinetums'};
ok noun(q{villini})->is_plural  => q{is_plural: 'villini'};
ok noun(q{desmans})->is_plural  => q{is_plural: 'desmans'};
ok noun(q{aurorae})->is_plural  => q{is_plural: 'aurorae'};
ok noun(q{seraphim})->is_plural  => q{is_plural: 'seraphim'};
ok noun(q{squamae})->is_plural  => q{is_plural: 'squamae'};
ok noun(q{Muqdishos})->is_plural  => q{is_plural: 'Muqdishos'};
ok noun(q{maremme})->is_plural  => q{is_plural: 'maremme'};
ok noun(q{stomodaea})->is_plural  => q{is_plural: 'stomodaea'};
ok noun(q{cozes})->is_plural  => q{is_plural: 'cozes'};
ok noun(q{nucleolonemata})->is_plural  => q{is_plural: 'nucleolonemata'};
ok noun(q{phalangia})->is_plural  => q{is_plural: 'phalangia'};
ok noun(q{salitas})->is_plural  => q{is_plural: 'salitas'};
ok noun(q{dilettantes})->is_plural  => q{is_plural: 'dilettantes'};
ok noun(q{epyllia})->is_plural  => q{is_plural: 'epyllia'};
ok noun(q{rondeaux})->is_plural  => q{is_plural: 'rondeaux'};
ok noun(q{cultelli})->is_plural  => q{is_plural: 'cultelli'};
ok noun(q{skis})->is_plural  => q{is_plural: 'skis'};
ok noun(q{relata})->is_plural  => q{is_plural: 'relata'};
ok noun(q{ oxen})->is_plural  => q{is_plural: ' oxen'};
ok noun(q{whiting})->is_plural  => q{is_plural: 'whiting'};
ok noun(q{menchildren})->is_plural  => q{is_plural: 'menchildren'};
ok noun(q{peninsulas})->is_plural  => q{is_plural: 'peninsulas'};
ok noun(q{soredia})->is_plural  => q{is_plural: 'soredia'};
ok noun(q{schizostylis})->is_plural  => q{is_plural: 'schizostylis'};
ok noun(q{terrariums})->is_plural  => q{is_plural: 'terrariums'};
ok noun(q{altorelievos})->is_plural  => q{is_plural: 'altorelievos'};
ok noun(q{plasmomata})->is_plural  => q{is_plural: 'plasmomata'};
ok noun(q{britches})->is_plural  => q{is_plural: 'britches'};
ok noun(q{logia})->is_plural  => q{is_plural: 'logia'};
ok noun(q{magi})->is_plural  => q{is_plural: 'magi'};
ok noun(q{Yumans})->is_plural  => q{is_plural: 'Yumans'};
ok noun(q{joes})->is_plural  => q{is_plural: 'joes'};
ok noun(q{tumuli})->is_plural  => q{is_plural: 'tumuli'};
ok noun(q{supercilia})->is_plural  => q{is_plural: 'supercilia'};
ok noun(q{fioriture})->is_plural  => q{is_plural: 'fioriture'};
ok noun(q{Americanese})->is_plural  => q{is_plural: 'Americanese'};
ok noun(q{ovoli})->is_plural  => q{is_plural: 'ovoli'};
ok noun(q{kibbutzes})->is_plural  => q{is_plural: 'kibbutzes'};
ok noun(q{set tos})->is_plural  => q{is_plural: 'set tos'};
ok noun(q{caimans})->is_plural  => q{is_plural: 'caimans'};
ok noun(q{troparia})->is_plural  => q{is_plural: 'troparia'};
ok noun(q{portraits parles})->is_plural  => q{is_plural: 'portraits parles'};
ok noun(q{nucleolonemas})->is_plural  => q{is_plural: 'nucleolonemas'};
ok noun(q{saddos})->is_plural  => q{is_plural: 'saddos'};
ok noun(q{spadices})->is_plural  => q{is_plural: 'spadices'};
ok noun(q{striata})->is_plural  => q{is_plural: 'striata'};
ok noun(q{terps})->is_plural  => q{is_plural: 'terps'};
ok noun(q{latices})->is_plural  => q{is_plural: 'latices'};
ok noun(q{sabertooths})->is_plural  => q{is_plural: 'sabertooths'};
ok noun(q{purlieus})->is_plural  => q{is_plural: 'purlieus'};
ok noun(q{larnakes})->is_plural  => q{is_plural: 'larnakes'};
ok noun(q{beefs})->is_plural  => q{is_plural: 'beefs'};
ok noun(q{breeches})->is_plural  => q{is_plural: 'breeches'};
ok noun(q{spermogonia})->is_plural  => q{is_plural: 'spermogonia'};
ok noun(q{tempi})->is_plural  => q{is_plural: 'tempi'};
ok noun(q{vorstellungen})->is_plural  => q{is_plural: 'vorstellungen'};
ok noun(q{flatuses})->is_plural  => q{is_plural: 'flatuses'};
ok noun(q{blitzes})->is_plural  => q{is_plural: 'blitzes'};
ok noun(q{carp})->is_plural  => q{is_plural: 'carp'};
ok noun(q{set-offs})->is_plural  => q{is_plural: 'set-offs'};
ok noun(q{scholia})->is_plural  => q{is_plural: 'scholia'};
ok noun(q{bravoes})->is_plural  => q{is_plural: 'bravoes'};
ok noun(q{bhikshus})->is_plural  => q{is_plural: 'bhikshus'};
ok noun(q{rhomboidei})->is_plural  => q{is_plural: 'rhomboidei'};
ok noun(q{Foochowese})->is_plural  => q{is_plural: 'Foochowese'};
ok noun(q{Sienese})->is_plural  => q{is_plural: 'Sienese'};
ok noun(q{pasteurellae})->is_plural  => q{is_plural: 'pasteurellae'};
ok noun(q{uvae})->is_plural  => q{is_plural: 'uvae'};
ok noun(q{agents provocateurs})->is_plural  => q{is_plural: 'agents provocateurs'};
ok noun(q{canvases})->is_plural  => q{is_plural: 'canvases'};
ok noun(q{vasculitides})->is_plural  => q{is_plural: 'vasculitides'};
ok noun(q{toxii})->is_plural  => q{is_plural: 'toxii'};
ok noun(q{goys})->is_plural  => q{is_plural: 'goys'};
ok noun(q{larynges})->is_plural  => q{is_plural: 'larynges'};
ok noun(q{geishas})->is_plural  => q{is_plural: 'geishas'};
ok noun(q{banditti})->is_plural  => q{is_plural: 'banditti'};
ok noun(q{cerci})->is_plural  => q{is_plural: 'cerci'};
ok noun(q{tetragrammata})->is_plural  => q{is_plural: 'tetragrammata'};
ok noun(q{Maracaibos})->is_plural  => q{is_plural: 'Maracaibos'};
ok noun(q{phragmata})->is_plural  => q{is_plural: 'phragmata'};
ok noun(q{turbots})->is_plural  => q{is_plural: 'turbots'};
ok noun(q{pickerel})->is_plural  => q{is_plural: 'pickerel'};
ok noun(q{foci})->is_plural  => q{is_plural: 'foci'};
ok noun(q{astrocytomas})->is_plural  => q{is_plural: 'astrocytomas'};
ok noun(q{Siamese})->is_plural  => q{is_plural: 'Siamese'};
ok noun(q{hiatuses})->is_plural  => q{is_plural: 'hiatuses'};
ok noun(q{army corps generals})->is_plural  => q{is_plural: 'army corps generals'};
ok noun(q{prima donnas})->is_plural  => q{is_plural: 'prima donnas'};
ok noun(q{themselves})->is_plural  => q{is_plural: 'themselves'};
ok noun(q{varices})->is_plural  => q{is_plural: 'varices'};
ok noun(q{seeds})->is_plural  => q{is_plural: 'seeds'};
ok noun(q{turfs})->is_plural  => q{is_plural: 'turfs'};
ok noun(q{vomitoriums})->is_plural  => q{is_plural: 'vomitoriums'};
ok noun(q{epimera})->is_plural  => q{is_plural: 'epimera'};
ok noun(q{proaves})->is_plural  => q{is_plural: 'proaves'};
ok noun(q{karrenfelder})->is_plural  => q{is_plural: 'karrenfelder'};
ok noun(q{weirdos})->is_plural  => q{is_plural: 'weirdos'};
ok noun(q{lox})->is_plural  => q{is_plural: 'lox'};
ok noun(q{ommatidia})->is_plural  => q{is_plural: 'ommatidia'};
ok noun(q{interreges})->is_plural  => q{is_plural: 'interreges'};
ok noun(q{Bengalese})->is_plural  => q{is_plural: 'Bengalese'};
ok noun(q{desiderata})->is_plural  => q{is_plural: 'desiderata'};
ok noun(q{Pekingese})->is_plural  => q{is_plural: 'Pekingese'};
ok noun(q{ophiophagi})->is_plural  => q{is_plural: 'ophiophagi'};
ok noun(q{simplices})->is_plural  => q{is_plural: 'simplices'};
ok noun(q{erven})->is_plural  => q{is_plural: 'erven'};
ok noun(q{storeys})->is_plural  => q{is_plural: 'storeys'};
ok noun(q{potestates})->is_plural  => q{is_plural: 'potestates'};
ok noun(q{haustoria})->is_plural  => q{is_plural: 'haustoria'};
ok noun(q{gaonim})->is_plural  => q{is_plural: 'gaonim'};
ok noun(q{nymphea})->is_plural  => q{is_plural: 'nymphea'};
ok noun(q{thalami})->is_plural  => q{is_plural: 'thalami'};
ok noun(q{monsignors})->is_plural  => q{is_plural: 'monsignors'};
ok noun(q{sphagna})->is_plural  => q{is_plural: 'sphagna'};
ok noun(q{candelabra})->is_plural  => q{is_plural: 'candelabra'};
ok noun(q{bongos})->is_plural  => q{is_plural: 'bongos'};
ok noun(q{fowls})->is_plural  => q{is_plural: 'fowls'};
ok noun(q{flag staffs})->is_plural  => q{is_plural: 'flag staffs'};
ok noun(q{laminae})->is_plural  => q{is_plural: 'laminae'};
ok noun(q{leishmanias})->is_plural  => q{is_plural: 'leishmanias'};
ok noun(q{beaux hommes})->is_plural  => q{is_plural: 'beaux hommes'};
ok noun(q{men milliners})->is_plural  => q{is_plural: 'men milliners'};
ok noun(q{Selmans})->is_plural  => q{is_plural: 'Selmans'};
ok noun(q{memoranda})->is_plural  => q{is_plural: 'memoranda'};
ok noun(q{irides})->is_plural  => q{is_plural: 'irides'};
ok noun(q{snipes})->is_plural  => q{is_plural: 'snipes'};
ok noun(q{editiones principes})->is_plural  => q{is_plural: 'editiones principes'};
ok noun(q{sum totals})->is_plural  => q{is_plural: 'sum totals'};
ok noun(q{coneys})->is_plural  => q{is_plural: 'coneys'};
ok noun(q{Senegalese})->is_plural  => q{is_plural: 'Senegalese'};
ok noun(q{representamina})->is_plural  => q{is_plural: 'representamina'};
ok noun(q{interphenomena})->is_plural  => q{is_plural: 'interphenomena'};
ok noun(q{lei})->is_plural  => q{is_plural: 'lei'};
ok noun(q{aquariums})->is_plural  => q{is_plural: 'aquariums'};
ok noun(q{strobili})->is_plural  => q{is_plural: 'strobili'};
ok noun(q{Shavese})->is_plural  => q{is_plural: 'Shavese'};
ok noun(q{laiki})->is_plural  => q{is_plural: 'laiki'};
ok noun(q{umbones})->is_plural  => q{is_plural: 'umbones'};
ok noun(q{squadrists})->is_plural  => q{is_plural: 'squadrists'};
ok noun(q{forums})->is_plural  => q{is_plural: 'forums'};
ok noun(q{lieder})->is_plural  => q{is_plural: 'lieder'};
ok noun(q{synapticulas})->is_plural  => q{is_plural: 'synapticulas'};
ok noun(q{leaves})->is_plural  => q{is_plural: 'leaves'};
ok noun(q{evirati})->is_plural  => q{is_plural: 'evirati'};
ok noun(q{dies})->is_plural  => q{is_plural: 'dies'};
ok noun(q{faunae})->is_plural  => q{is_plural: 'faunae'};
ok noun(q{legionellae})->is_plural  => q{is_plural: 'legionellae'};
ok noun(q{onagers})->is_plural  => q{is_plural: 'onagers'};
ok noun(q{eroses})->is_plural  => q{is_plural: 'eroses'};
ok noun(q{secundagravidas})->is_plural  => q{is_plural: 'secundagravidas'};
ok noun(q{frustula})->is_plural  => q{is_plural: 'frustula'};
ok noun(q{helices})->is_plural  => q{is_plural: 'helices'};
ok noun(q{famuli})->is_plural  => q{is_plural: 'famuli'};
ok noun(q{solaria})->is_plural  => q{is_plural: 'solaria'};
ok noun(q{situlas})->is_plural  => q{is_plural: 'situlas'};
ok noun(q{meshumadim})->is_plural  => q{is_plural: 'meshumadim'};
ok noun(q{shelves})->is_plural  => q{is_plural: 'shelves'};
ok noun(q{rhinoceroses})->is_plural  => q{is_plural: 'rhinoceroses'};
ok noun(q{Bolzanos})->is_plural  => q{is_plural: 'Bolzanos'};
ok noun(q{frottole})->is_plural  => q{is_plural: 'frottole'};
ok noun(q{hoes})->is_plural  => q{is_plural: 'hoes'};
ok noun(q{pipkraker})->is_plural  => q{is_plural: 'pipkraker'};
ok noun(q{Kanarese})->is_plural  => q{is_plural: 'Kanarese'};
ok noun(q{temblores})->is_plural  => q{is_plural: 'temblores'};
ok noun(q{metae})->is_plural  => q{is_plural: 'metae'};
ok noun(q{metapleura})->is_plural  => q{is_plural: 'metapleura'};
ok noun(q{sternos})->is_plural  => q{is_plural: 'sternos'};
ok noun(q{vibrios})->is_plural  => q{is_plural: 'vibrios'};
ok noun(q{bordereaux})->is_plural  => q{is_plural: 'bordereaux'};
ok noun(q{Dracos})->is_plural  => q{is_plural: 'Dracos'};
ok noun(q{Heavenese})->is_plural  => q{is_plural: 'Heavenese'};
ok noun(q{trapeziums})->is_plural  => q{is_plural: 'trapeziums'};
ok noun(q{thesauri})->is_plural  => q{is_plural: 'thesauri'};
ok noun(q{columnae})->is_plural  => q{is_plural: 'columnae'};
ok noun(q{agapae})->is_plural  => q{is_plural: 'agapae'};
ok noun(q{silos})->is_plural  => q{is_plural: 'silos'};
ok noun(q{plutei})->is_plural  => q{is_plural: 'plutei'};
ok noun(q{persons})->is_plural  => q{is_plural: 'persons'};
ok noun(q{interstitiums})->is_plural  => q{is_plural: 'interstitiums'};
ok noun(q{Sinhalese})->is_plural  => q{is_plural: 'Sinhalese'};
ok noun(q{teredos})->is_plural  => q{is_plural: 'teredos'};
ok noun(q{ados})->is_plural  => q{is_plural: 'ados'};
ok noun(q{lochi})->is_plural  => q{is_plural: 'lochi'};
ok noun(q{cellos})->is_plural  => q{is_plural: 'cellos'};
ok noun(q{Jerrys})->is_plural  => q{is_plural: 'Jerrys'};
ok noun(q{hordeola})->is_plural  => q{is_plural: 'hordeola'};
ok noun(q{hippos})->is_plural  => q{is_plural: 'hippos'};
ok noun(q{nagaikas})->is_plural  => q{is_plural: 'nagaikas'};
ok noun(q{autos-de-fes})->is_plural  => q{is_plural: 'autos-de-fes'};
ok noun(q{pengo})->is_plural  => q{is_plural: 'pengo'};
ok noun(q{moes})->is_plural  => q{is_plural: 'moes'};
ok noun(q{voeux})->is_plural  => q{is_plural: 'voeux'};
ok noun(q{mafiose})->is_plural  => q{is_plural: 'mafiose'};
ok noun(q{crura})->is_plural  => q{is_plural: 'crura'};
ok noun(q{Yengeese})->is_plural  => q{is_plural: 'Yengeese'};
ok noun(q{kine})->is_plural  => q{is_plural: 'kine'};
ok noun(q{agends})->is_plural  => q{is_plural: 'agends'};
ok noun(q{entia rationis})->is_plural  => q{is_plural: 'entia rationis'};
ok noun(q{scoleces})->is_plural  => q{is_plural: 'scoleces'};
ok noun(q{teratomata})->is_plural  => q{is_plural: 'teratomata'};
ok noun(q{anathemas})->is_plural  => q{is_plural: 'anathemas'};
ok noun(q{kare})->is_plural  => q{is_plural: 'kare'};
ok noun(q{Romanese})->is_plural  => q{is_plural: 'Romanese'};
ok noun(q{hiatus})->is_plural  => q{is_plural: 'hiatus'};
ok noun(q{plasmalemmas})->is_plural  => q{is_plural: 'plasmalemmas'};
ok noun(q{turbot})->is_plural  => q{is_plural: 'turbot'};
ok noun(q{crescendos})->is_plural  => q{is_plural: 'crescendos'};
ok noun(q{sphinxes})->is_plural  => q{is_plural: 'sphinxes'};
ok noun(q{Celanese})->is_plural  => q{is_plural: 'Celanese'};
ok noun(q{geisha})->is_plural  => q{is_plural: 'geisha'};
ok noun(q{silbadores})->is_plural  => q{is_plural: 'silbadores'};
ok noun(q{ultimatums})->is_plural  => q{is_plural: 'ultimatums'};
ok noun(q{intercalare})->is_plural  => q{is_plural: 'intercalare'};
ok noun(q{zoophori})->is_plural  => q{is_plural: 'zoophori'};
ok noun(q{calypsos})->is_plural  => q{is_plural: 'calypsos'};
ok noun(q{eland})->is_plural  => q{is_plural: 'eland'};
ok noun(q{alans})->is_plural  => q{is_plural: 'alans'};
ok noun(q{bierstuben})->is_plural  => q{is_plural: 'bierstuben'};
ok noun(q{teal})->is_plural  => q{is_plural: 'teal'};
ok noun(q{hydrae})->is_plural  => q{is_plural: 'hydrae'};
ok noun(q{synaesthesiae})->is_plural  => q{is_plural: 'synaesthesiae'};
ok noun(q{legumens})->is_plural  => q{is_plural: 'legumens'};
ok noun(q{melastomae})->is_plural  => q{is_plural: 'melastomae'};
ok noun(q{personae})->is_plural  => q{is_plural: 'personae'};
ok noun(q{sterigmata})->is_plural  => q{is_plural: 'sterigmata'};
ok noun(q{testudos})->is_plural  => q{is_plural: 'testudos'};
ok noun(q{collegia musica})->is_plural  => q{is_plural: 'collegia musica'};
ok noun(q{myelomata})->is_plural  => q{is_plural: 'myelomata'};
ok noun(q{konditorei})->is_plural  => q{is_plural: 'konditorei'};
ok noun(q{vile})->is_plural  => q{is_plural: 'vile'};
ok noun(q{machos})->is_plural  => q{is_plural: 'machos'};
ok noun(q{monotae})->is_plural  => q{is_plural: 'monotae'};
ok noun(q{nuntii})->is_plural  => q{is_plural: 'nuntii'};
ok noun(q{mezzo rilievos})->is_plural  => q{is_plural: 'mezzo rilievos'};
ok noun(q{designata})->is_plural  => q{is_plural: 'designata'};
ok noun(q{cassoni})->is_plural  => q{is_plural: 'cassoni'};
ok noun(q{honoraria})->is_plural  => q{is_plural: 'honoraria'};
ok noun(q{cristae})->is_plural  => q{is_plural: 'cristae'};
ok noun(q{plectra})->is_plural  => q{is_plural: 'plectra'};
ok noun(q{pterylae})->is_plural  => q{is_plural: 'pterylae'};
ok noun(q{lisses})->is_plural  => q{is_plural: 'lisses'};
ok noun(q{dolmans})->is_plural  => q{is_plural: 'dolmans'};
ok noun(q{potatoes})->is_plural  => q{is_plural: 'potatoes'};
ok noun(q{remous})->is_plural  => q{is_plural: 'remous'};
ok noun(q{prosopia})->is_plural  => q{is_plural: 'prosopia'};
ok noun(q{podiums})->is_plural  => q{is_plural: 'podiums'};
ok noun(q{Faros})->is_plural  => q{is_plural: 'Faros'};
ok noun(q{Atlantes})->is_plural  => q{is_plural: 'Atlantes'};
ok noun(q{anacolutha})->is_plural  => q{is_plural: 'anacolutha'};
ok noun(q{auspices})->is_plural  => q{is_plural: 'auspices'};
ok noun(q{swine})->is_plural  => q{is_plural: 'swine'};
ok noun(q{noctilucae})->is_plural  => q{is_plural: 'noctilucae'};
ok noun(q{allargandi})->is_plural  => q{is_plural: 'allargandi'};
ok noun(q{sgraffiati})->is_plural  => q{is_plural: 'sgraffiati'};
ok noun(q{karakia})->is_plural  => q{is_plural: 'karakia'};
ok noun(q{nuclei})->is_plural  => q{is_plural: 'nuclei'};
ok noun(q{pintos})->is_plural  => q{is_plural: 'pintos'};
ok noun(q{velums})->is_plural  => q{is_plural: 'velums'};
ok noun(q{hypna})->is_plural  => q{is_plural: 'hypna'};
ok noun(q{4 star generals})->is_plural  => q{is_plural: '4 star generals'};
ok noun(q{chintzes})->is_plural  => q{is_plural: 'chintzes'};
ok noun(q{womenchildren})->is_plural  => q{is_plural: 'womenchildren'};
ok noun(q{hemi elytra})->is_plural  => q{is_plural: 'hemi elytra'};
ok noun(q{Oklahomans})->is_plural  => q{is_plural: 'Oklahomans'};
ok noun(q{perradii})->is_plural  => q{is_plural: 'perradii'};
ok noun(q{sigli})->is_plural  => q{is_plural: 'sigli'};
ok noun(q{Botos})->is_plural  => q{is_plural: 'Botos'};
ok noun(q{agones})->is_plural  => q{is_plural: 'agones'};
ok noun(q{shawabtis})->is_plural  => q{is_plural: 'shawabtis'};
ok noun(q{hippopotamuses})->is_plural  => q{is_plural: 'hippopotamuses'};
ok noun(q{cardophagi})->is_plural  => q{is_plural: 'cardophagi'};
ok noun(q{contraltos})->is_plural  => q{is_plural: 'contraltos'};
ok noun(q{glacis})->is_plural  => q{is_plural: 'glacis'};
ok noun(q{clippers})->is_plural  => q{is_plural: 'clippers'};
ok noun(q{espanoles})->is_plural  => q{is_plural: 'espanoles'};
ok noun(q{herring})->is_plural  => q{is_plural: 'herring'};
ok noun(q{pennia})->is_plural  => q{is_plural: 'pennia'};
ok noun(q{cantuses})->is_plural  => q{is_plural: 'cantuses'};
ok noun(q{equinoctiums})->is_plural  => q{is_plural: 'equinoctiums'};
ok noun(q{moderni})->is_plural  => q{is_plural: 'moderni'};
ok noun(q{rhinoceros})->is_plural  => q{is_plural: 'rhinoceros'};
ok noun(q{women-children})->is_plural  => q{is_plural: 'women-children'};
ok noun(q{soes})->is_plural  => q{is_plural: 'soes'};
ok noun(q{papyri})->is_plural  => q{is_plural: 'papyri'};
ok noun(q{lords-lieutenant})->is_plural  => q{is_plural: 'lords-lieutenant'};
ok noun(q{yoes})->is_plural  => q{is_plural: 'yoes'};
ok noun(q{eunuchs})->is_plural  => q{is_plural: 'eunuchs'};
ok noun(q{residuums})->is_plural  => q{is_plural: 'residuums'};
ok noun(q{adminicula})->is_plural  => q{is_plural: 'adminicula'};
ok noun(q{baalim})->is_plural  => q{is_plural: 'baalim'};
ok noun(q{melicerides})->is_plural  => q{is_plural: 'melicerides'};
ok noun(q{varely})->is_plural  => q{is_plural: 'varely'};
ok noun(q{mortadellas})->is_plural  => q{is_plural: 'mortadellas'};
ok noun(q{rhinos})->is_plural  => q{is_plural: 'rhinos'};
ok noun(q{nouveaux riches})->is_plural  => q{is_plural: 'nouveaux riches'};
ok noun(q{scissors})->is_plural  => q{is_plural: 'scissors'};
ok noun(q{1-star generals})->is_plural  => q{is_plural: '1-star generals'};
ok noun(q{beaux gestes})->is_plural  => q{is_plural: 'beaux gestes'};
ok noun(q{ale-wives})->is_plural  => q{is_plural: 'ale-wives'};
ok noun(q{puncta})->is_plural  => q{is_plural: 'puncta'};
ok noun(q{setae})->is_plural  => q{is_plural: 'setae'};
ok noun(q{politicoes})->is_plural  => q{is_plural: 'politicoes'};
ok noun(q{septaria})->is_plural  => q{is_plural: 'septaria'};
ok noun(q{they})->is_plural  => q{is_plural: 'they'};
ok noun(q{podetia})->is_plural  => q{is_plural: 'podetia'};
ok noun(q{platypuses})->is_plural  => q{is_plural: 'platypuses'};
ok noun(q{isthmuses})->is_plural  => q{is_plural: 'isthmuses'};
ok noun(q{nebulae})->is_plural  => q{is_plural: 'nebulae'};
ok noun(q{Balinese})->is_plural  => q{is_plural: 'Balinese'};
ok noun(q{radixes})->is_plural  => q{is_plural: 'radixes'};
ok noun(q{trichinae})->is_plural  => q{is_plural: 'trichinae'};
ok noun(q{magnum opuses})->is_plural  => q{is_plural: 'magnum opuses'};
ok noun(q{Swahilese})->is_plural  => q{is_plural: 'Swahilese'};
ok noun(q{zeppoli})->is_plural  => q{is_plural: 'zeppoli'};
ok noun(q{stellae})->is_plural  => q{is_plural: 'stellae'};
ok noun(q{magmata})->is_plural  => q{is_plural: 'magmata'};
ok noun(q{lieus})->is_plural  => q{is_plural: 'lieus'};
ok noun(q{minima})->is_plural  => q{is_plural: 'minima'};
ok noun(q{felones})->is_plural  => q{is_plural: 'felones'};
ok noun(q{torulae})->is_plural  => q{is_plural: 'torulae'};
ok noun(q{divertimenti})->is_plural  => q{is_plural: 'divertimenti'};
ok noun(q{strategi})->is_plural  => q{is_plural: 'strategi'};
ok noun(q{morceaux})->is_plural  => q{is_plural: 'morceaux'};
ok noun(q{parabolae})->is_plural  => q{is_plural: 'parabolae'};
ok noun(q{starovers})->is_plural  => q{is_plural: 'starovers'};
ok noun(q{auto-de-fes})->is_plural  => q{is_plural: 'auto-de-fes'};
ok noun(q{menages a quatre})->is_plural  => q{is_plural: 'menages a quatre'};
ok noun(q{bathoses})->is_plural  => q{is_plural: 'bathoses'};
ok noun(q{Lilos})->is_plural  => q{is_plural: 'Lilos'};
ok noun(q{coccidia})->is_plural  => q{is_plural: 'coccidia'};
ok noun(q{nucleoli})->is_plural  => q{is_plural: 'nucleoli'};
ok noun(q{cerimans})->is_plural  => q{is_plural: 'cerimans'};
ok noun(q{otomi})->is_plural  => q{is_plural: 'otomi'};
ok noun(q{asylums})->is_plural  => q{is_plural: 'asylums'};
ok noun(q{extrema})->is_plural  => q{is_plural: 'extrema'};
ok noun(q{supracleithra})->is_plural  => q{is_plural: 'supracleithra'};
ok noun(q{syrphi})->is_plural  => q{is_plural: 'syrphi'};
ok noun(q{linctuses})->is_plural  => q{is_plural: 'linctuses'};
ok noun(q{alberghi})->is_plural  => q{is_plural: 'alberghi'};
ok noun(q{panini})->is_plural  => q{is_plural: 'panini'};
ok noun(q{supposita})->is_plural  => q{is_plural: 'supposita'};
ok noun(q{Madurese})->is_plural  => q{is_plural: 'Madurese'};
ok noun(q{Asherim})->is_plural  => q{is_plural: 'Asherim'};
ok noun(q{bandits})->is_plural  => q{is_plural: 'bandits'};
ok noun(q{emporiums})->is_plural  => q{is_plural: 'emporiums'};
ok noun(q{ballerinas})->is_plural  => q{is_plural: 'ballerinas'};
ok noun(q{dictums})->is_plural  => q{is_plural: 'dictums'};
ok noun(q{synangia})->is_plural  => q{is_plural: 'synangia'};
ok noun(q{sets out})->is_plural  => q{is_plural: 'sets out'};
ok noun(q{biscotti})->is_plural  => q{is_plural: 'biscotti'};
ok noun(q{phocas})->is_plural  => q{is_plural: 'phocas'};
ok noun(q{aptychi})->is_plural  => q{is_plural: 'aptychi'};
ok noun(q{crazie})->is_plural  => q{is_plural: 'crazie'};
ok noun(q{intervallums})->is_plural  => q{is_plural: 'intervallums'};
ok noun(q{thaumaturgi})->is_plural  => q{is_plural: 'thaumaturgi'};
ok noun(q{protomae})->is_plural  => q{is_plural: 'protomae'};
ok noun(q{choruses})->is_plural  => q{is_plural: 'choruses'};
ok noun(q{glochidia})->is_plural  => q{is_plural: 'glochidia'};
ok noun(q{daces})->is_plural  => q{is_plural: 'daces'};
ok noun(q{hakes})->is_plural  => q{is_plural: 'hakes'};
ok noun(q{Zibos})->is_plural  => q{is_plural: 'Zibos'};
ok noun(q{loaves})->is_plural  => q{is_plural: 'loaves'};
ok noun(q{taxes})->is_plural  => q{is_plural: 'taxes'};
ok noun(q{anacoluthons})->is_plural  => q{is_plural: 'anacoluthons'};
ok noun(q{fedais})->is_plural  => q{is_plural: 'fedais'};
ok noun(q{alulae})->is_plural  => q{is_plural: 'alulae'};
ok noun(q{carcinomata})->is_plural  => q{is_plural: 'carcinomata'};
ok noun(q{asyndeta})->is_plural  => q{is_plural: 'asyndeta'};
ok noun(q{stimuli})->is_plural  => q{is_plural: 'stimuli'};
ok noun(q{jambeaus})->is_plural  => q{is_plural: 'jambeaus'};
ok noun(q{acari})->is_plural  => q{is_plural: 'acari'};
ok noun(q{peciae})->is_plural  => q{is_plural: 'peciae'};
ok noun(q{thecae})->is_plural  => q{is_plural: 'thecae'};
ok noun(q{oreganos})->is_plural  => q{is_plural: 'oreganos'};
ok noun(q{referenda})->is_plural  => q{is_plural: 'referenda'};
ok noun(q{intermezzos})->is_plural  => q{is_plural: 'intermezzos'};
ok noun(q{alveoli})->is_plural  => q{is_plural: 'alveoli'};
ok noun(q{pulmonaria})->is_plural  => q{is_plural: 'pulmonaria'};
ok noun(q{sbirri})->is_plural  => q{is_plural: 'sbirri'};
ok noun(q{umwelten})->is_plural  => q{is_plural: 'umwelten'};
ok noun(q{scriptoria})->is_plural  => q{is_plural: 'scriptoria'};
ok noun(q{secundigravidae})->is_plural  => q{is_plural: 'secundigravidae'};
ok noun(q{duumvirs})->is_plural  => q{is_plural: 'duumvirs'};
ok noun(q{Piedmontese})->is_plural  => q{is_plural: 'Piedmontese'};
ok noun(q{nubeculae})->is_plural  => q{is_plural: 'nubeculae'};
ok noun(q{pili})->is_plural  => q{is_plural: 'pili'};
ok noun(q{army-corps generals})->is_plural  => q{is_plural: 'army-corps generals'};
ok noun(q{staminidia})->is_plural  => q{is_plural: 'staminidia'};
ok noun(q{Shawanese})->is_plural  => q{is_plural: 'Shawanese'};
ok noun(q{entia realia})->is_plural  => q{is_plural: 'entia realia'};
ok noun(q{antae})->is_plural  => q{is_plural: 'antae'};
ok noun(q{starovery})->is_plural  => q{is_plural: 'starovery'};
ok noun(q{tortillas espanolas})->is_plural  => q{is_plural: 'tortillas espanolas'};
ok noun(q{abscissas})->is_plural  => q{is_plural: 'abscissas'};
ok noun(q{terrae filii})->is_plural  => q{is_plural: 'terrae filii'};
ok noun(q{geniuses})->is_plural  => q{is_plural: 'geniuses'};
ok noun(q{Lapponese})->is_plural  => q{is_plural: 'Lapponese'};
ok noun(q{mafiosos})->is_plural  => q{is_plural: 'mafiosos'};
ok noun(q{desmas})->is_plural  => q{is_plural: 'desmas'};
ok noun(q{offspring})->is_plural  => q{is_plural: 'offspring'};
ok noun(q{soralia})->is_plural  => q{is_plural: 'soralia'};
ok noun(q{sotches})->is_plural  => q{is_plural: 'sotches'};
ok noun(q{melanomas})->is_plural  => q{is_plural: 'melanomas'};
ok noun(q{calices})->is_plural  => q{is_plural: 'calices'};
ok noun(q{pingos})->is_plural  => q{is_plural: 'pingos'};
ok noun(q{mafiosi})->is_plural  => q{is_plural: 'mafiosi'};
ok noun(q{bonis fidebus})->is_plural  => q{is_plural: 'bonis fidebus'};
ok noun(q{bechuanas})->is_plural  => q{is_plural: 'bechuanas'};
ok noun(q{cris de coeur})->is_plural  => q{is_plural: 'cris de coeur'};
ok noun(q{serrae})->is_plural  => q{is_plural: 'serrae'};
ok noun(q{proglottides})->is_plural  => q{is_plural: 'proglottides'};
ok noun(q{kletterschuhe})->is_plural  => q{is_plural: 'kletterschuhe'};
ok noun(q{gorgonias})->is_plural  => q{is_plural: 'gorgonias'};
ok noun(q{cicatrices})->is_plural  => q{is_plural: 'cicatrices'};
ok noun(q{cappuccinos})->is_plural  => q{is_plural: 'cappuccinos'};
ok noun(q{terraria})->is_plural  => q{is_plural: 'terraria'};
ok noun(q{explananda})->is_plural  => q{is_plural: 'explananda'};
ok noun(q{pocula})->is_plural  => q{is_plural: 'pocula'};
ok noun(q{Lapithae})->is_plural  => q{is_plural: 'Lapithae'};
ok noun(q{carmens})->is_plural  => q{is_plural: 'carmens'};
ok noun(q{quartos})->is_plural  => q{is_plural: 'quartos'};
ok noun(q{staccatos})->is_plural  => q{is_plural: 'staccatos'};
ok noun(q{regidores})->is_plural  => q{is_plural: 'regidores'};
ok noun(q{paranuclei})->is_plural  => q{is_plural: 'paranuclei'};
ok noun(q{xiphiplastra})->is_plural  => q{is_plural: 'xiphiplastra'};
ok noun(q{impetigos})->is_plural  => q{is_plural: 'impetigos'};
ok noun(q{Barquisimetos})->is_plural  => q{is_plural: 'Barquisimetos'};
ok noun(q{carmina})->is_plural  => q{is_plural: 'carmina'};
ok noun(q{appendixes})->is_plural  => q{is_plural: 'appendixes'};
ok noun(q{epicardia})->is_plural  => q{is_plural: 'epicardia'};
ok noun(q{medusae})->is_plural  => q{is_plural: 'medusae'};
ok noun(q{paparrazi})->is_plural  => q{is_plural: 'paparrazi'};
ok noun(q{opuses})->is_plural  => q{is_plural: 'opuses'};
ok noun(q{faveoli})->is_plural  => q{is_plural: 'faveoli'};
ok noun(q{dipsades})->is_plural  => q{is_plural: 'dipsades'};
ok noun(q{Indochinese})->is_plural  => q{is_plural: 'Indochinese'};
ok noun(q{axillae})->is_plural  => q{is_plural: 'axillae'};
ok noun(q{sinfonie})->is_plural  => q{is_plural: 'sinfonie'};
ok noun(q{clavulae})->is_plural  => q{is_plural: 'clavulae'};
ok noun(q{vacua})->is_plural  => q{is_plural: 'vacua'};
ok noun(q{milieus})->is_plural  => q{is_plural: 'milieus'};
ok noun(q{linenos})->is_plural  => q{is_plural: 'linenos'};
ok noun(q{viri})->is_plural  => q{is_plural: 'viri'};
ok noun(q{mycorrhizas})->is_plural  => q{is_plural: 'mycorrhizas'};
ok noun(q{inocula})->is_plural  => q{is_plural: 'inocula'};
ok noun(q{gummas})->is_plural  => q{is_plural: 'gummas'};
ok noun(q{niduses})->is_plural  => q{is_plural: 'niduses'};
ok noun(q{mementoes})->is_plural  => q{is_plural: 'mementoes'};
ok noun(q{noemata})->is_plural  => q{is_plural: 'noemata'};
ok noun(q{mala in se})->is_plural  => q{is_plural: 'mala in se'};
ok noun(q{break aways})->is_plural  => q{is_plural: 'break aways'};
ok noun(q{portmanteaux})->is_plural  => q{is_plural: 'portmanteaux'};
ok noun(q{simiae})->is_plural  => q{is_plural: 'simiae'};
ok noun(q{cystidia})->is_plural  => q{is_plural: 'cystidia'};
ok noun(q{myxomata})->is_plural  => q{is_plural: 'myxomata'};
ok noun(q{Tornesi})->is_plural  => q{is_plural: 'Tornesi'};
ok noun(q{Lapiths})->is_plural  => q{is_plural: 'Lapiths'};
ok noun(q{varellaes})->is_plural  => q{is_plural: 'varellaes'};
ok noun(q{naumachias})->is_plural  => q{is_plural: 'naumachias'};
ok noun(q{aphides})->is_plural  => q{is_plural: 'aphides'};
ok noun(q{boleros})->is_plural  => q{is_plural: 'boleros'};
ok noun(q{djinn})->is_plural  => q{is_plural: 'djinn'};
ok noun(q{myas})->is_plural  => q{is_plural: 'myas'};
ok noun(q{puls})->is_plural  => q{is_plural: 'puls'};
ok noun(q{summa bona})->is_plural  => q{is_plural: 'summa bona'};
ok noun(q{cardines})->is_plural  => q{is_plural: 'cardines'};
ok noun(q{contralti})->is_plural  => q{is_plural: 'contralti'};
ok noun(q{monstres sacres})->is_plural  => q{is_plural: 'monstres sacres'};
ok noun(q{flag-staffs})->is_plural  => q{is_plural: 'flag-staffs'};
ok noun(q{simpula})->is_plural  => q{is_plural: 'simpula'};
ok noun(q{Chimangos})->is_plural  => q{is_plural: 'Chimangos'};
ok noun(q{verrucae})->is_plural  => q{is_plural: 'verrucae'};
ok noun(q{cleithra})->is_plural  => q{is_plural: 'cleithra'};
ok noun(q{stamina})->is_plural  => q{is_plural: 'stamina'};
ok noun(q{beaux})->is_plural  => q{is_plural: 'beaux'};
ok noun(q{puli})->is_plural  => q{is_plural: 'puli'};
ok noun(q{dragomen})->is_plural  => q{is_plural: 'dragomen'};
ok noun(q{rondos})->is_plural  => q{is_plural: 'rondos'};
ok noun(q{bon vivants})->is_plural  => q{is_plural: 'bon vivants'};
ok noun(q{synesthesiae})->is_plural  => q{is_plural: 'synesthesiae'};
ok noun(q{stichoi})->is_plural  => q{is_plural: 'stichoi'};
ok noun(q{Porto-Novos})->is_plural  => q{is_plural: 'Porto-Novos'};
ok noun(q{maculas})->is_plural  => q{is_plural: 'maculas'};
ok noun(q{spermathecae})->is_plural  => q{is_plural: 'spermathecae'};
ok noun(q{quid})->is_plural  => q{is_plural: 'quid'};
ok noun(q{sums total})->is_plural  => q{is_plural: 'sums total'};
ok noun(q{ponchos})->is_plural  => q{is_plural: 'ponchos'};
ok noun(q{pontifices})->is_plural  => q{is_plural: 'pontifices'};
ok noun(q{stuccos})->is_plural  => q{is_plural: 'stuccos'};
ok noun(q{chapeaus})->is_plural  => q{is_plural: 'chapeaus'};
ok noun(q{hedrons})->is_plural  => q{is_plural: 'hedrons'};
ok noun(q{conies})->is_plural  => q{is_plural: 'conies'};
ok noun(q{media})->is_plural  => q{is_plural: 'media'};
ok noun(q{Bostonese})->is_plural  => q{is_plural: 'Bostonese'};
ok noun(q{primigravidae})->is_plural  => q{is_plural: 'primigravidae'};
ok noun(q{zemirot})->is_plural  => q{is_plural: 'zemirot'};
ok noun(q{sphaeridia})->is_plural  => q{is_plural: 'sphaeridia'};
ok noun(q{axes})->is_plural  => q{is_plural: 'axes'};
ok noun(q{bursitises})->is_plural  => q{is_plural: 'bursitises'};
ok noun(q{lustra})->is_plural  => q{is_plural: 'lustra'};
ok noun(q{coitus})->is_plural  => q{is_plural: 'coitus'};
ok noun(q{whomever})->is_plural  => q{is_plural: 'whomever'};
ok noun(q{syrinxes})->is_plural  => q{is_plural: 'syrinxes'};
ok noun(q{genies})->is_plural  => q{is_plural: 'genies'};
ok noun(q{haggis})->is_plural  => q{is_plural: 'haggis'};
ok noun(q{lis})->is_plural  => q{is_plural: 'lis'};
ok noun(q{concetti})->is_plural  => q{is_plural: 'concetti'};
ok noun(q{three-star generals})->is_plural  => q{is_plural: 'three-star generals'};
ok noun(q{lines out})->is_plural  => q{is_plural: 'lines out'};
ok noun(q{puttonys})->is_plural  => q{is_plural: 'puttonys'};
ok noun(q{gyri})->is_plural  => q{is_plural: 'gyri'};
ok noun(q{feet})->is_plural  => q{is_plural: 'feet'};
ok noun(q{scudi})->is_plural  => q{is_plural: 'scudi'};
ok noun(q{prosencephala})->is_plural  => q{is_plural: 'prosencephala'};
ok noun(q{terebratulae})->is_plural  => q{is_plural: 'terebratulae'};
ok noun(q{purum})->is_plural  => q{is_plural: 'purum'};
ok noun(q{pieds noirs})->is_plural  => q{is_plural: 'pieds noirs'};
ok noun(q{improvisatrici})->is_plural  => q{is_plural: 'improvisatrici'};
ok noun(q{epidermises})->is_plural  => q{is_plural: 'epidermises'};
ok noun(q{stadia})->is_plural  => q{is_plural: 'stadia'};
ok noun(q{bratwursts})->is_plural  => q{is_plural: 'bratwursts'};
ok noun(q{archipelagos})->is_plural  => q{is_plural: 'archipelagos'};
ok noun(q{tangos})->is_plural  => q{is_plural: 'tangos'};
ok noun(q{shamans})->is_plural  => q{is_plural: 'shamans'};
ok noun(q{usneas})->is_plural  => q{is_plural: 'usneas'};
ok noun(q{rideaux})->is_plural  => q{is_plural: 'rideaux'};
ok noun(q{triumvirs})->is_plural  => q{is_plural: 'triumvirs'};
ok noun(q{locos})->is_plural  => q{is_plural: 'locos'};
ok noun(q{ulpanim})->is_plural  => q{is_plural: 'ulpanim'};
ok noun(q{stomas})->is_plural  => q{is_plural: 'stomas'};
ok noun(q{baths})->is_plural  => q{is_plural: 'baths'};
ok noun(q{autostradas})->is_plural  => q{is_plural: 'autostradas'};
ok noun(q{edemas})->is_plural  => q{is_plural: 'edemas'};
ok noun(q{devoti})->is_plural  => q{is_plural: 'devoti'};
ok noun(q{noda})->is_plural  => q{is_plural: 'noda'};
ok noun(q{froes})->is_plural  => q{is_plural: 'froes'};
ok noun(q{indices})->is_plural  => q{is_plural: 'indices'};
ok noun(q{sterna})->is_plural  => q{is_plural: 'sterna'};
ok noun(q{intichiuma})->is_plural  => q{is_plural: 'intichiuma'};
ok noun(q{diplococci})->is_plural  => q{is_plural: 'diplococci'};
ok noun(q{gliomata})->is_plural  => q{is_plural: 'gliomata'};
ok noun(q{caymans})->is_plural  => q{is_plural: 'caymans'};
ok noun(q{choanae})->is_plural  => q{is_plural: 'choanae'};
ok noun(q{cherubs})->is_plural  => q{is_plural: 'cherubs'};
ok noun(q{amoebas})->is_plural  => q{is_plural: 'amoebas'};
ok noun(q{pectines})->is_plural  => q{is_plural: 'pectines'};
ok noun(q{frusta})->is_plural  => q{is_plural: 'frusta'};
ok noun(q{piscinae})->is_plural  => q{is_plural: 'piscinae'};
ok noun(q{anlagen})->is_plural  => q{is_plural: 'anlagen'};
ok noun(q{squillae})->is_plural  => q{is_plural: 'squillae'};
ok noun(q{pastorali})->is_plural  => q{is_plural: 'pastorali'};
ok noun(q{Pistoiese})->is_plural  => q{is_plural: 'Pistoiese'};
ok noun(q{3 star generals})->is_plural  => q{is_plural: '3 star generals'};
ok noun(q{antra})->is_plural  => q{is_plural: 'antra'};
ok noun(q{imbrices})->is_plural  => q{is_plural: 'imbrices'};
ok noun(q{messeigneurs})->is_plural  => q{is_plural: 'messeigneurs'};
ok noun(q{ententes cordiales})->is_plural  => q{is_plural: 'ententes cordiales'};
ok noun(q{metatarsi})->is_plural  => q{is_plural: 'metatarsi'};
ok noun(q{pyramidia})->is_plural  => q{is_plural: 'pyramidia'};
ok noun(q{tali})->is_plural  => q{is_plural: 'tali'};
ok noun(q{synusiae})->is_plural  => q{is_plural: 'synusiae'};
ok noun(q{tormas})->is_plural  => q{is_plural: 'tormas'};
ok noun(q{lares})->is_plural  => q{is_plural: 'lares'};
ok noun(q{representamens})->is_plural  => q{is_plural: 'representamens'};
ok noun(q{denarii})->is_plural  => q{is_plural: 'denarii'};
ok noun(q{glutei})->is_plural  => q{is_plural: 'glutei'};
ok noun(q{startzy})->is_plural  => q{is_plural: 'startzy'};
ok noun(q{telia})->is_plural  => q{is_plural: 'telia'};
ok noun(q{nectocalyces})->is_plural  => q{is_plural: 'nectocalyces'};
ok noun(q{montes})->is_plural  => q{is_plural: 'montes'};
ok noun(q{hydriae})->is_plural  => q{is_plural: 'hydriae'};
ok noun(q{versos})->is_plural  => q{is_plural: 'versos'};
ok noun(q{Purums})->is_plural  => q{is_plural: 'Purums'};
ok noun(q{breaksaway})->is_plural  => q{is_plural: 'breaksaway'};
ok noun(q{corpuscula})->is_plural  => q{is_plural: 'corpuscula'};
ok noun(q{trichine})->is_plural  => q{is_plural: 'trichine'};
ok noun(q{lords lieutenant})->is_plural  => q{is_plural: 'lords lieutenant'};
ok noun(q{courts-martial})->is_plural  => q{is_plural: 'courts-martial'};
ok noun(q{souvlakia})->is_plural  => q{is_plural: 'souvlakia'};
ok noun(q{Arakanese})->is_plural  => q{is_plural: 'Arakanese'};
ok noun(q{swines})->is_plural  => q{is_plural: 'swines'};
ok noun(q{emporia})->is_plural  => q{is_plural: 'emporia'};
ok noun(q{fraena})->is_plural  => q{is_plural: 'fraena'};
ok noun(q{alae})->is_plural  => q{is_plural: 'alae'};
ok noun(q{thoraxes})->is_plural  => q{is_plural: 'thoraxes'};
ok noun(q{jerries})->is_plural  => q{is_plural: 'jerries'};
ok noun(q{wadies})->is_plural  => q{is_plural: 'wadies'};
ok noun(q{pylae})->is_plural  => q{is_plural: 'pylae'};
ok noun(q{pectora})->is_plural  => q{is_plural: 'pectora'};
ok noun(q{lars})->is_plural  => q{is_plural: 'lars'};
ok noun(q{rhynchodaea})->is_plural  => q{is_plural: 'rhynchodaea'};
ok noun(q{exempla})->is_plural  => q{is_plural: 'exempla'};
ok noun(q{Taikos})->is_plural  => q{is_plural: 'Taikos'};
ok noun(q{vetturini})->is_plural  => q{is_plural: 'vetturini'};
ok noun(q{autobahnen})->is_plural  => q{is_plural: 'autobahnen'};
ok noun(q{syllabaria})->is_plural  => q{is_plural: 'syllabaria'};
ok noun(q{seed})->is_plural  => q{is_plural: 'seed'};
ok noun(q{dentalia})->is_plural  => q{is_plural: 'dentalia'};
ok noun(q{nses})->is_plural  => q{is_plural: 'nses'};
ok noun(q{Kokakos})->is_plural  => q{is_plural: 'Kokakos'};
ok noun(q{extremums})->is_plural  => q{is_plural: 'extremums'};
ok noun(q{fess})->is_plural  => q{is_plural: 'fess'};
ok noun(q{tholi})->is_plural  => q{is_plural: 'tholi'};
ok noun(q{ilia})->is_plural  => q{is_plural: 'ilia'};
ok noun(q{shears})->is_plural  => q{is_plural: 'shears'};
ok noun(q{ballabili})->is_plural  => q{is_plural: 'ballabili'};
ok noun(q{onagri})->is_plural  => q{is_plural: 'onagri'};
ok noun(q{sestieri})->is_plural  => q{is_plural: 'sestieri'};
ok noun(q{barricoes})->is_plural  => q{is_plural: 'barricoes'};
ok noun(q{bemata})->is_plural  => q{is_plural: 'bemata'};
ok noun(q{synapticulae})->is_plural  => q{is_plural: 'synapticulae'};
ok noun(q{ricercari})->is_plural  => q{is_plural: 'ricercari'};
ok noun(q{indumenta})->is_plural  => q{is_plural: 'indumenta'};
ok noun(q{telamones})->is_plural  => q{is_plural: 'telamones'};
ok noun(q{proscenia})->is_plural  => q{is_plural: 'proscenia'};
ok noun(q{exencephali})->is_plural  => q{is_plural: 'exencephali'};
ok noun(q{remou})->is_plural  => q{is_plural: 'remou'};
ok noun(q{lieutenant generals})->is_plural  => q{is_plural: 'lieutenant generals'};
ok noun(q{collegia})->is_plural  => q{is_plural: 'collegia'};
ok noun(q{plicae})->is_plural  => q{is_plural: 'plicae'};
ok noun(q{monsiegneurs})->is_plural  => q{is_plural: 'monsiegneurs'};
ok noun(q{women children})->is_plural  => q{is_plural: 'women children'};
ok noun(q{lebensformen})->is_plural  => q{is_plural: 'lebensformen'};
ok noun(q{synedria})->is_plural  => q{is_plural: 'synedria'};
ok noun(q{succineas})->is_plural  => q{is_plural: 'succineas'};
ok noun(q{generalissimos})->is_plural  => q{is_plural: 'generalissimos'};
ok noun(q{rezidentsii})->is_plural  => q{is_plural: 'rezidentsii'};
ok noun(q{amphipneusts})->is_plural  => q{is_plural: 'amphipneusts'};
ok noun(q{tyros})->is_plural  => q{is_plural: 'tyros'};
ok noun(q{two-star generals})->is_plural  => q{is_plural: 'two-star generals'};
ok noun(q{vires})->is_plural  => q{is_plural: 'vires'};
ok noun(q{set outs})->is_plural  => q{is_plural: 'set outs'};
ok noun(q{surculi})->is_plural  => q{is_plural: 'surculi'};
ok noun(q{syndendria})->is_plural  => q{is_plural: 'syndendria'};
ok noun(q{arcana})->is_plural  => q{is_plural: 'arcana'};
ok noun(q{mustachios})->is_plural  => q{is_plural: 'mustachios'};
ok noun(q{compendiums})->is_plural  => q{is_plural: 'compendiums'};
ok noun(q{pathoses})->is_plural  => q{is_plural: 'pathoses'};
ok noun(q{rubashki})->is_plural  => q{is_plural: 'rubashki'};
ok noun(q{elands})->is_plural  => q{is_plural: 'elands'};
ok noun(q{residua})->is_plural  => q{is_plural: 'residua'};
ok noun(q{maecenases})->is_plural  => q{is_plural: 'maecenases'};
ok noun(q{clepsydrae})->is_plural  => q{is_plural: 'clepsydrae'};
ok noun(q{novi homines})->is_plural  => q{is_plural: 'novi homines'};
ok noun(q{irises})->is_plural  => q{is_plural: 'irises'};
ok noun(q{aelfe})->is_plural  => q{is_plural: 'aelfe'};
ok noun(q{Hiroshimans})->is_plural  => q{is_plural: 'Hiroshimans'};
ok noun(q{flag-staves})->is_plural  => q{is_plural: 'flag-staves'};
ok noun(q{spermata})->is_plural  => q{is_plural: 'spermata'};
ok noun(q{denkmaler})->is_plural  => q{is_plural: 'denkmaler'};
ok noun(q{pasteurellas})->is_plural  => q{is_plural: 'pasteurellas'};
ok noun(q{bustoes})->is_plural  => q{is_plural: 'bustoes'};
ok noun(q{phalli})->is_plural  => q{is_plural: 'phalli'};
ok noun(q{kuvaszok})->is_plural  => q{is_plural: 'kuvaszok'};
ok noun(q{phyogemmaria})->is_plural  => q{is_plural: 'phyogemmaria'};
ok noun(q{hapax legomena})->is_plural  => q{is_plural: 'hapax legomena'};
ok noun(q{roms})->is_plural  => q{is_plural: 'roms'};
ok noun(q{thyridia})->is_plural  => q{is_plural: 'thyridia'};
ok noun(q{flamencos})->is_plural  => q{is_plural: 'flamencos'};
ok noun(q{suffrutices})->is_plural  => q{is_plural: 'suffrutices'};
ok noun(q{helia})->is_plural  => q{is_plural: 'helia'};
ok noun(q{geese})->is_plural  => q{is_plural: 'geese'};
ok noun(q{fowl})->is_plural  => q{is_plural: 'fowl'};
ok noun(q{mangos})->is_plural  => q{is_plural: 'mangos'};
ok noun(q{subsidia})->is_plural  => q{is_plural: 'subsidia'};
ok noun(q{Vietnamese})->is_plural  => q{is_plural: 'Vietnamese'};
ok noun(q{nasuti})->is_plural  => q{is_plural: 'nasuti'};
ok noun(q{paragangliomas})->is_plural  => q{is_plural: 'paragangliomas'};
ok noun(q{rhinophymas})->is_plural  => q{is_plural: 'rhinophymas'};
ok noun(q{Azerbaijanese})->is_plural  => q{is_plural: 'Azerbaijanese'};
ok noun(q{mycorrhizae})->is_plural  => q{is_plural: 'mycorrhizae'};
ok noun(q{samurai})->is_plural  => q{is_plural: 'samurai'};
ok noun(q{devotos})->is_plural  => q{is_plural: 'devotos'};
ok noun(q{salmon})->is_plural  => q{is_plural: 'salmon'};
ok noun(q{loggie})->is_plural  => q{is_plural: 'loggie'};
ok noun(q{osteoclastomas})->is_plural  => q{is_plural: 'osteoclastomas'};
ok noun(q{lithophyta})->is_plural  => q{is_plural: 'lithophyta'};
ok noun(q{afreeti})->is_plural  => q{is_plural: 'afreeti'};
ok noun(q{oglys})->is_plural  => q{is_plural: 'oglys'};
ok noun(q{pajamas})->is_plural  => q{is_plural: 'pajamas'};
ok noun(q{spiracula})->is_plural  => q{is_plural: 'spiracula'};
ok noun(q{asbestoses})->is_plural  => q{is_plural: 'asbestoses'};
ok noun(q{buffalos})->is_plural  => q{is_plural: 'buffalos'};
ok noun(q{Moroccos})->is_plural  => q{is_plural: 'Moroccos'};
ok noun(q{knives})->is_plural  => q{is_plural: 'knives'};
ok noun(q{mimosae})->is_plural  => q{is_plural: 'mimosae'};
ok noun(q{fish})->is_plural  => q{is_plural: 'fish'};
ok noun(q{tympana})->is_plural  => q{is_plural: 'tympana'};
ok noun(q{Montenegros})->is_plural  => q{is_plural: 'Montenegros'};
ok noun(q{bacteria})->is_plural  => q{is_plural: 'bacteria'};
ok noun(q{summa genera})->is_plural  => q{is_plural: 'summa genera'};
ok noun(q{mithraea})->is_plural  => q{is_plural: 'mithraea'};
ok noun(q{teredines})->is_plural  => q{is_plural: 'teredines'};
ok noun(q{juga})->is_plural  => q{is_plural: 'juga'};
ok noun(q{souvlakis})->is_plural  => q{is_plural: 'souvlakis'};
ok noun(q{crafts-childer})->is_plural  => q{is_plural: 'crafts-childer'};
ok noun(q{those})->is_plural  => q{is_plural: 'those'};
ok noun(q{hormogonia})->is_plural  => q{is_plural: 'hormogonia'};
ok noun(q{magna opera})->is_plural  => q{is_plural: 'magna opera'};
ok noun(q{microbia})->is_plural  => q{is_plural: 'microbia'};
ok noun(q{funambuli})->is_plural  => q{is_plural: 'funambuli'};
ok noun(q{thebe})->is_plural  => q{is_plural: 'thebe'};
ok noun(q{menages a trois})->is_plural  => q{is_plural: 'menages a trois'};
ok noun(q{iueles})->is_plural  => q{is_plural: 'iueles'};
ok noun(q{pedes})->is_plural  => q{is_plural: 'pedes'};
ok noun(q{apothecia})->is_plural  => q{is_plural: 'apothecia'};
ok noun(q{floras})->is_plural  => q{is_plural: 'floras'};
ok noun(q{schistosomula})->is_plural  => q{is_plural: 'schistosomula'};
ok noun(q{syringes})->is_plural  => q{is_plural: 'syringes'};
ok noun(q{vertices})->is_plural  => q{is_plural: 'vertices'};
ok noun(q{quantums})->is_plural  => q{is_plural: 'quantums'};
ok noun(q{cinclides})->is_plural  => q{is_plural: 'cinclides'};
ok noun(q{melanomata})->is_plural  => q{is_plural: 'melanomata'};
ok noun(q{apparatuses})->is_plural  => q{is_plural: 'apparatuses'};
ok noun(q{Milanese})->is_plural  => q{is_plural: 'Milanese'};
ok noun(q{matzahs})->is_plural  => q{is_plural: 'matzahs'};
ok noun(q{Messinese})->is_plural  => q{is_plural: 'Messinese'};
ok noun(q{aides de camp})->is_plural  => q{is_plural: 'aides de camp'};
ok noun(q{apparatchiki})->is_plural  => q{is_plural: 'apparatchiki'};
ok noun(q{whom})->is_plural  => q{is_plural: 'whom'};
ok noun(q{tintinnabula})->is_plural  => q{is_plural: 'tintinnabula'};
ok noun(q{cartes-de-visite})->is_plural  => q{is_plural: 'cartes-de-visite'};
ok noun(q{craspeda})->is_plural  => q{is_plural: 'craspeda'};
ok noun(q{numina})->is_plural  => q{is_plural: 'numina'};
ok noun(q{treponemata})->is_plural  => q{is_plural: 'treponemata'};
ok noun(q{rhododendrons})->is_plural  => q{is_plural: 'rhododendrons'};
ok noun(q{corgis})->is_plural  => q{is_plural: 'corgis'};
ok noun(q{curriculums})->is_plural  => q{is_plural: 'curriculums'};
ok noun(q{glissandi})->is_plural  => q{is_plural: 'glissandi'};
ok noun(q{astrocytomata})->is_plural  => q{is_plural: 'astrocytomata'};
ok noun(q{lacunas})->is_plural  => q{is_plural: 'lacunas'};
ok noun(q{protarsi})->is_plural  => q{is_plural: 'protarsi'};
ok noun(q{umbras})->is_plural  => q{is_plural: 'umbras'};
ok noun(q{stylos})->is_plural  => q{is_plural: 'stylos'};
ok noun(q{striolae})->is_plural  => q{is_plural: 'striolae'};
ok noun(q{pupae})->is_plural  => q{is_plural: 'pupae'};
ok noun(q{some})->is_plural  => q{is_plural: 'some'};
ok noun(q{quinarii})->is_plural  => q{is_plural: 'quinarii'};
ok noun(q{hypodermata})->is_plural  => q{is_plural: 'hypodermata'};
ok noun(q{faeculae})->is_plural  => q{is_plural: 'faeculae'};
ok noun(q{confervae})->is_plural  => q{is_plural: 'confervae'};
ok noun(q{microfiches})->is_plural  => q{is_plural: 'microfiches'};
ok noun(q{pros})->is_plural  => q{is_plural: 'pros'};
ok noun(q{trochi})->is_plural  => q{is_plural: 'trochi'};
ok noun(q{syncelli})->is_plural  => q{is_plural: 'syncelli'};
ok noun(q{Polonese})->is_plural  => q{is_plural: 'Polonese'};
ok noun(q{sensoriola})->is_plural  => q{is_plural: 'sensoriola'};
ok noun(q{tuberes})->is_plural  => q{is_plural: 'tuberes'};
ok noun(q{mezzo-rilievos})->is_plural  => q{is_plural: 'mezzo-rilievos'};
ok noun(q{Ferrarese})->is_plural  => q{is_plural: 'Ferrarese'};
ok noun(q{squadre})->is_plural  => q{is_plural: 'squadre'};
ok noun(q{Angolese})->is_plural  => q{is_plural: 'Angolese'};
ok noun(q{pallia})->is_plural  => q{is_plural: 'pallia'};
ok noun(q{louis})->is_plural  => q{is_plural: 'louis'};
ok noun(q{idees fixes})->is_plural  => q{is_plural: 'idees fixes'};
ok noun(q{senarii})->is_plural  => q{is_plural: 'senarii'};
ok noun(q{hairdos})->is_plural  => q{is_plural: 'hairdos'};
ok noun(q{territoria})->is_plural  => q{is_plural: 'territoria'};
ok noun(q{Tyrolese})->is_plural  => q{is_plural: 'Tyrolese'};
ok noun(q{ammos})->is_plural  => q{is_plural: 'ammos'};
ok noun(q{cows})->is_plural  => q{is_plural: 'cows'};
ok noun(q{diabetes})->is_plural  => q{is_plural: 'diabetes'};
ok noun(q{tentacula})->is_plural  => q{is_plural: 'tentacula'};
ok noun(q{bassi})->is_plural  => q{is_plural: 'bassi'};
ok noun(q{areolae})->is_plural  => q{is_plural: 'areolae'};
ok noun(q{papillomata})->is_plural  => q{is_plural: 'papillomata'};
ok noun(q{Sogdianese})->is_plural  => q{is_plural: 'Sogdianese'};
ok noun(q{moduses})->is_plural  => q{is_plural: 'moduses'};
ok noun(q{novas})->is_plural  => q{is_plural: 'novas'};
ok noun(q{Gestapos})->is_plural  => q{is_plural: 'Gestapos'};
ok noun(q{prosodiencephala})->is_plural  => q{is_plural: 'prosodiencephala'};
ok noun(q{gymnasia})->is_plural  => q{is_plural: 'gymnasia'};
ok noun(q{three star generals})->is_plural  => q{is_plural: 'three star generals'};
ok noun(q{lines-out})->is_plural  => q{is_plural: 'lines-out'};
ok noun(q{tours de force})->is_plural  => q{is_plural: 'tours de force'};
ok noun(q{djinns})->is_plural  => q{is_plural: 'djinns'};
ok noun(q{trapezii})->is_plural  => q{is_plural: 'trapezii'};
ok noun(q{torni})->is_plural  => q{is_plural: 'torni'};
ok noun(q{yarramans})->is_plural  => q{is_plural: 'yarramans'};
ok noun(q{haddocks})->is_plural  => q{is_plural: 'haddocks'};
ok noun(q{phototaxes})->is_plural  => q{is_plural: 'phototaxes'};
ok noun(q{chlamydiae})->is_plural  => q{is_plural: 'chlamydiae'};
ok noun(q{arangoes})->is_plural  => q{is_plural: 'arangoes'};
ok noun(q{milites gloriosi})->is_plural  => q{is_plural: 'milites gloriosi'};
ok noun(q{sphinges})->is_plural  => q{is_plural: 'sphinges'};
ok noun(q{Porto Novos})->is_plural  => q{is_plural: 'Porto Novos'};
ok noun(q{cremasteres})->is_plural  => q{is_plural: 'cremasteres'};
ok noun(q{sternebrae})->is_plural  => q{is_plural: 'sternebrae'};
ok noun(q{glissandos})->is_plural  => q{is_plural: 'glissandos'};
ok noun(q{rhinophymata})->is_plural  => q{is_plural: 'rhinophymata'};
ok noun(q{chevaux})->is_plural  => q{is_plural: 'chevaux'};
ok noun(q{agorae})->is_plural  => q{is_plural: 'agorae'};
ok noun(q{summae})->is_plural  => q{is_plural: 'summae'};
ok noun(q{efreets})->is_plural  => q{is_plural: 'efreets'};
ok noun(q{us})->is_plural  => q{is_plural: 'us'};
ok noun(q{mantellette})->is_plural  => q{is_plural: 'mantellette'};
ok noun(q{memorandums})->is_plural  => q{is_plural: 'memorandums'};
ok noun(q{bifolia})->is_plural  => q{is_plural: 'bifolia'};
ok noun(q{pinons})->is_plural  => q{is_plural: 'pinons'};
ok noun(q{proferentes})->is_plural  => q{is_plural: 'proferentes'};
ok noun(q{hinaki})->is_plural  => q{is_plural: 'hinaki'};
ok noun(q{coronae})->is_plural  => q{is_plural: 'coronae'};
ok noun(q{scotomas})->is_plural  => q{is_plural: 'scotomas'};
ok noun(q{lumens})->is_plural  => q{is_plural: 'lumens'};
ok noun(q{flagella})->is_plural  => q{is_plural: 'flagella'};
ok noun(q{striae})->is_plural  => q{is_plural: 'striae'};
ok noun(q{scirrhusses})->is_plural  => q{is_plural: 'scirrhusses'};
ok noun(q{cyphellae})->is_plural  => q{is_plural: 'cyphellae'};
ok noun(q{Lyonese})->is_plural  => q{is_plural: 'Lyonese'};
ok noun(q{Alfurese})->is_plural  => q{is_plural: 'Alfurese'};
ok noun(q{matres lectionis})->is_plural  => q{is_plural: 'matres lectionis'};
ok noun(q{Sundanese})->is_plural  => q{is_plural: 'Sundanese'};
ok noun(q{syllabuses})->is_plural  => q{is_plural: 'syllabuses'};
ok noun(q{limaces})->is_plural  => q{is_plural: 'limaces'};
ok noun(q{fuci})->is_plural  => q{is_plural: 'fuci'};
ok noun(q{anthodia})->is_plural  => q{is_plural: 'anthodia'};
ok noun(q{seaquaria})->is_plural  => q{is_plural: 'seaquaria'};
ok noun(q{vomitoria})->is_plural  => q{is_plural: 'vomitoria'};
ok noun(q{pulveratrices})->is_plural  => q{is_plural: 'pulveratrices'};
ok noun(q{dogmas})->is_plural  => q{is_plural: 'dogmas'};
ok noun(q{typos})->is_plural  => q{is_plural: 'typos'};
ok noun(q{paths})->is_plural  => q{is_plural: 'paths'};
ok noun(q{nentsy})->is_plural  => q{is_plural: 'nentsy'};
ok noun(q{toriles})->is_plural  => q{is_plural: 'toriles'};
ok noun(q{lux})->is_plural  => q{is_plural: 'lux'};
ok noun(q{oculi})->is_plural  => q{is_plural: 'oculi'};
ok noun(q{lemmata})->is_plural  => q{is_plural: 'lemmata'};
ok noun(q{explicanda})->is_plural  => q{is_plural: 'explicanda'};
ok noun(q{pleura})->is_plural  => q{is_plural: 'pleura'};
ok noun(q{paise})->is_plural  => q{is_plural: 'paise'};
ok noun(q{uteruses})->is_plural  => q{is_plural: 'uteruses'};
ok noun(q{washers up})->is_plural  => q{is_plural: 'washers up'};
ok noun(q{scarabaei})->is_plural  => q{is_plural: 'scarabaei'};
ok noun(q{elks})->is_plural  => q{is_plural: 'elks'};
ok noun(q{soprani})->is_plural  => q{is_plural: 'soprani'};
ok noun(q{fedai})->is_plural  => q{is_plural: 'fedai'};
ok noun(q{wharves})->is_plural  => q{is_plural: 'wharves'};
ok noun(q{canzonettas})->is_plural  => q{is_plural: 'canzonettas'};
ok noun(q{sopranos})->is_plural  => q{is_plural: 'sopranos'};
ok noun(q{limuli})->is_plural  => q{is_plural: 'limuli'};
ok noun(q{contagia})->is_plural  => q{is_plural: 'contagia'};
ok noun(q{cubicula})->is_plural  => q{is_plural: 'cubicula'};
ok noun(q{odea})->is_plural  => q{is_plural: 'odea'};
ok noun(q{Virgos})->is_plural  => q{is_plural: 'Virgos'};
ok noun(q{plexuses})->is_plural  => q{is_plural: 'plexuses'};
ok noun(q{meatus})->is_plural  => q{is_plural: 'meatus'};
ok noun(q{lepromata})->is_plural  => q{is_plural: 'lepromata'};
ok noun(q{dumky})->is_plural  => q{is_plural: 'dumky'};
ok noun(q{convolvuluses})->is_plural  => q{is_plural: 'convolvuluses'};
ok noun(q{guys})->is_plural  => q{is_plural: 'guys'};
ok noun(q{alumni})->is_plural  => q{is_plural: 'alumni'};
ok noun(q{poderi})->is_plural  => q{is_plural: 'poderi'};
ok noun(q{alguacils})->is_plural  => q{is_plural: 'alguacils'};
ok noun(q{pneumothoraces})->is_plural  => q{is_plural: 'pneumothoraces'};
ok noun(q{tagmata})->is_plural  => q{is_plural: 'tagmata'};
ok noun(q{castrati})->is_plural  => q{is_plural: 'castrati'};
ok noun(q{lentigines})->is_plural  => q{is_plural: 'lentigines'};
ok noun(q{infimae species})->is_plural  => q{is_plural: 'infimae species'};
ok noun(q{prosae})->is_plural  => q{is_plural: 'prosae'};
ok noun(q{succubi})->is_plural  => q{is_plural: 'succubi'};
ok noun(q{veges})->is_plural  => q{is_plural: 'veges'};
ok noun(q{chateaus})->is_plural  => q{is_plural: 'chateaus'};
ok noun(q{res})->is_plural  => q{is_plural: 'res'};
ok noun(q{capos})->is_plural  => q{is_plural: 'capos'};
ok noun(q{pikes})->is_plural  => q{is_plural: 'pikes'};
ok noun(q{monochasia})->is_plural  => q{is_plural: 'monochasia'};
ok noun(q{filarias})->is_plural  => q{is_plural: 'filarias'};
ok noun(q{mucrones})->is_plural  => q{is_plural: 'mucrones'};
ok noun(q{men servants})->is_plural  => q{is_plural: 'men servants'};
ok noun(q{nomismata})->is_plural  => q{is_plural: 'nomismata'};
ok noun(q{finger ends})->is_plural  => q{is_plural: 'finger ends'};
ok noun(q{does})->is_plural  => q{is_plural: 'does'};
ok noun(q{toes})->is_plural  => q{is_plural: 'toes'};
ok noun(q{Cairos})->is_plural  => q{is_plural: 'Cairos'};
ok noun(q{trilbys})->is_plural  => q{is_plural: 'trilbys'};
ok noun(q{Purum})->is_plural  => q{is_plural: 'Purum'};
ok noun(q{dramas})->is_plural  => q{is_plural: 'dramas'};
ok noun(q{prima ballerinas})->is_plural  => q{is_plural: 'prima ballerinas'};
ok noun(q{scoriae})->is_plural  => q{is_plural: 'scoriae'};
ok noun(q{portmanteaus})->is_plural  => q{is_plural: 'portmanteaus'};
ok noun(q{vaginae})->is_plural  => q{is_plural: 'vaginae'};
ok noun(q{murices})->is_plural  => q{is_plural: 'murices'};
ok noun(q{whosever})->is_plural  => q{is_plural: 'whosever'};
ok noun(q{trousers})->is_plural  => q{is_plural: 'trousers'};
ok noun(q{torma})->is_plural  => q{is_plural: 'torma'};
ok noun(q{staterae})->is_plural  => q{is_plural: 'staterae'};
ok noun(q{conducti})->is_plural  => q{is_plural: 'conducti'};
ok noun(q{farmans})->is_plural  => q{is_plural: 'farmans'};
ok noun(q{Cantonese})->is_plural  => q{is_plural: 'Cantonese'};
ok noun(q{children})->is_plural  => q{is_plural: 'children'};
ok noun(q{series})->is_plural  => q{is_plural: 'series'};
ok noun(q{Nakayamans})->is_plural  => q{is_plural: 'Nakayamans'};
ok noun(q{zophori})->is_plural  => q{is_plural: 'zophori'};
ok noun(q{apteria})->is_plural  => q{is_plural: 'apteria'};
ok noun(q{rhizomata})->is_plural  => q{is_plural: 'rhizomata'};
ok noun(q{talouses})->is_plural  => q{is_plural: 'talouses'};
ok noun(q{pedicellariae})->is_plural  => q{is_plural: 'pedicellariae'};
ok noun(q{parerga})->is_plural  => q{is_plural: 'parerga'};
ok noun(q{castra})->is_plural  => q{is_plural: 'castra'};
ok noun(q{sets to})->is_plural  => q{is_plural: 'sets to'};
ok noun(q{bingos})->is_plural  => q{is_plural: 'bingos'};
ok noun(q{men midwives})->is_plural  => q{is_plural: 'men midwives'};
ok noun(q{break-aways})->is_plural  => q{is_plural: 'break-aways'};
ok noun(q{anathemata})->is_plural  => q{is_plural: 'anathemata'};
ok noun(q{fingers-ends})->is_plural  => q{is_plural: 'fingers-ends'};
ok noun(q{coxendices})->is_plural  => q{is_plural: 'coxendices'};
ok noun(q{one star generals})->is_plural  => q{is_plural: 'one star generals'};
ok noun(q{biases})->is_plural  => q{is_plural: 'biases'};
ok noun(q{lord lieutenants})->is_plural  => q{is_plural: 'lord lieutenants'};
ok noun(q{kilos})->is_plural  => q{is_plural: 'kilos'};
ok noun(q{sachverhalte})->is_plural  => q{is_plural: 'sachverhalte'};
ok noun(q{parhelia})->is_plural  => q{is_plural: 'parhelia'};
ok noun(q{opercula})->is_plural  => q{is_plural: 'opercula'};
ok noun(q{rhombohedra})->is_plural  => q{is_plural: 'rhombohedra'};
ok noun(q{cimices})->is_plural  => q{is_plural: 'cimices'};
ok noun(q{these})->is_plural  => q{is_plural: 'these'};
ok noun(q{apexes})->is_plural  => q{is_plural: 'apexes'};
ok noun(q{vomicae})->is_plural  => q{is_plural: 'vomicae'};
ok noun(q{myos})->is_plural  => q{is_plural: 'myos'};
ok noun(q{mottoes})->is_plural  => q{is_plural: 'mottoes'};
ok noun(q{tremolos})->is_plural  => q{is_plural: 'tremolos'};
ok noun(q{ergastula})->is_plural  => q{is_plural: 'ergastula'};
ok noun(q{auto de fes})->is_plural  => q{is_plural: 'auto de fes'};
ok noun(q{siphunculi})->is_plural  => q{is_plural: 'siphunculi'};
ok noun(q{purums})->is_plural  => q{is_plural: 'purums'};
ok noun(q{soldi})->is_plural  => q{is_plural: 'soldi'};
ok noun(q{thalamoi})->is_plural  => q{is_plural: 'thalamoi'};
ok noun(q{depositums})->is_plural  => q{is_plural: 'depositums'};
ok noun(q{trousseaus})->is_plural  => q{is_plural: 'trousseaus'};
ok noun(q{somatenes})->is_plural  => q{is_plural: 'somatenes'};
ok noun(q{amoretti})->is_plural  => q{is_plural: 'amoretti'};
ok noun(q{libidos})->is_plural  => q{is_plural: 'libidos'};
ok noun(q{Sacramentos})->is_plural  => q{is_plural: 'Sacramentos'};
ok noun(q{zucchinis})->is_plural  => q{is_plural: 'zucchinis'};
ok noun(q{wives})->is_plural  => q{is_plural: 'wives'};
ok noun(q{lumina})->is_plural  => q{is_plural: 'lumina'};
ok noun(q{blemyae})->is_plural  => q{is_plural: 'blemyae'};
ok noun(q{hyperbolae})->is_plural  => q{is_plural: 'hyperbolae'};
ok noun(q{divisional generals})->is_plural  => q{is_plural: 'divisional generals'};
ok noun(q{credos})->is_plural  => q{is_plural: 'credos'};
ok noun(q{rococos})->is_plural  => q{is_plural: 'rococos'};
ok noun(q{octavos})->is_plural  => q{is_plural: 'octavos'};
ok noun(q{entrochi})->is_plural  => q{is_plural: 'entrochi'};
ok noun(q{chevaux-de-bataille})->is_plural  => q{is_plural: 'chevaux-de-bataille'};
ok noun(q{gonidia})->is_plural  => q{is_plural: 'gonidia'};
ok noun(q{gaons})->is_plural  => q{is_plural: 'gaons'};
ok noun(q{nexuses})->is_plural  => q{is_plural: 'nexuses'};
ok noun(q{caffe macchiatos})->is_plural  => q{is_plural: 'caffe macchiatos'};
ok noun(q{supernovas})->is_plural  => q{is_plural: 'supernovas'};
ok noun(q{uncini})->is_plural  => q{is_plural: 'uncini'};
ok noun(q{trousseaux})->is_plural  => q{is_plural: 'trousseaux'};
ok noun(q{Hainanese})->is_plural  => q{is_plural: 'Hainanese'};
ok noun(q{noxae})->is_plural  => q{is_plural: 'noxae'};
ok noun(q{loculi})->is_plural  => q{is_plural: 'loculi'};
ok noun(q{Majuros})->is_plural  => q{is_plural: 'Majuros'};
ok noun(q{Filipinos})->is_plural  => q{is_plural: 'Filipinos'};
ok noun(q{Vermontese})->is_plural  => q{is_plural: 'Vermontese'};
ok noun(q{progymnasia})->is_plural  => q{is_plural: 'progymnasia'};
ok noun(q{metropolises})->is_plural  => q{is_plural: 'metropolises'};
ok noun(q{octohedrons})->is_plural  => q{is_plural: 'octohedrons'};
ok noun(q{solvi})->is_plural  => q{is_plural: 'solvi'};
ok noun(q{lieux})->is_plural  => q{is_plural: 'lieux'};
ok noun(q{Amoyese})->is_plural  => q{is_plural: 'Amoyese'};
ok noun(q{macaci})->is_plural  => q{is_plural: 'macaci'};
ok noun(q{phylae})->is_plural  => q{is_plural: 'phylae'};
ok noun(q{konditoreien})->is_plural  => q{is_plural: 'konditoreien'};
ok noun(q{planulae})->is_plural  => q{is_plural: 'planulae'};
ok noun(q{sigloi})->is_plural  => q{is_plural: 'sigloi'};
ok noun(q{hedra})->is_plural  => q{is_plural: 'hedra'};
ok noun(q{ancone})->is_plural  => q{is_plural: 'ancone'};
ok noun(q{fuzzes})->is_plural  => q{is_plural: 'fuzzes'};
ok noun(q{Congoese})->is_plural  => q{is_plural: 'Congoese'};
ok noun(q{sandrs})->is_plural  => q{is_plural: 'sandrs'};
ok noun(q{venae})->is_plural  => q{is_plural: 'venae'};
ok noun(q{canaliculi})->is_plural  => q{is_plural: 'canaliculi'};
ok noun(q{calamistra})->is_plural  => q{is_plural: 'calamistra'};
ok noun(q{status})->is_plural  => q{is_plural: 'status'};
ok noun(q{tubercula})->is_plural  => q{is_plural: 'tubercula'};
ok noun(q{choux})->is_plural  => q{is_plural: 'choux'};
ok noun(q{radii})->is_plural  => q{is_plural: 'radii'};
ok noun(q{trientes})->is_plural  => q{is_plural: 'trientes'};
ok noun(q{rhythmi})->is_plural  => q{is_plural: 'rhythmi'};
ok noun(q{prime ballerine})->is_plural  => q{is_plural: 'prime ballerine'};
ok noun(q{pueblos})->is_plural  => q{is_plural: 'pueblos'};
ok noun(q{jackanapes})->is_plural  => q{is_plural: 'jackanapes'};
ok noun(q{altos})->is_plural  => q{is_plural: 'altos'};
ok noun(q{Czechs})->is_plural  => q{is_plural: 'Czechs'};
ok noun(q{pilei})->is_plural  => q{is_plural: 'pilei'};
ok noun(q{zadruge})->is_plural  => q{is_plural: 'zadruge'};
ok noun(q{viruses})->is_plural  => q{is_plural: 'viruses'};
ok noun(q{scutula})->is_plural  => q{is_plural: 'scutula'};
ok noun(q{interregna})->is_plural  => q{is_plural: 'interregna'};
ok noun(q{pontifexes})->is_plural  => q{is_plural: 'pontifexes'};
ok noun(q{nidi})->is_plural  => q{is_plural: 'nidi'};
ok noun(q{modelletti})->is_plural  => q{is_plural: 'modelletti'};
ok noun(q{Gilbertese})->is_plural  => q{is_plural: 'Gilbertese'};
ok noun(q{responsa})->is_plural  => q{is_plural: 'responsa'};
ok noun(q{plateaux})->is_plural  => q{is_plural: 'plateaux'};
ok noun(q{quanta})->is_plural  => q{is_plural: 'quanta'};
ok noun(q{court martials})->is_plural  => q{is_plural: 'court martials'};
ok noun(q{Calabrese})->is_plural  => q{is_plural: 'Calabrese'};
ok noun(q{neutrinos})->is_plural  => q{is_plural: 'neutrinos'};
ok noun(q{folles})->is_plural  => q{is_plural: 'folles'};
ok noun(q{occipita})->is_plural  => q{is_plural: 'occipita'};
ok noun(q{sententiae})->is_plural  => q{is_plural: 'sententiae'};
ok noun(q{aficionados})->is_plural  => q{is_plural: 'aficionados'};
ok noun(q{phlegmasiae})->is_plural  => q{is_plural: 'phlegmasiae'};
ok noun(q{trichomata})->is_plural  => q{is_plural: 'trichomata'};
ok noun(q{alto relievos})->is_plural  => q{is_plural: 'alto relievos'};
ok noun(q{ranunculuses})->is_plural  => q{is_plural: 'ranunculuses'};
ok noun(q{Yakimans})->is_plural  => q{is_plural: 'Yakimans'};
ok noun(q{news})->is_plural  => q{is_plural: 'news'};
ok noun(q{rilievos})->is_plural  => q{is_plural: 'rilievos'};
ok noun(q{listerellae})->is_plural  => q{is_plural: 'listerellae'};
ok noun(q{cargadores})->is_plural  => q{is_plural: 'cargadores'};
ok noun(q{vela})->is_plural  => q{is_plural: 'vela'};
ok noun(q{thrasoes})->is_plural  => q{is_plural: 'thrasoes'};
ok noun(q{paradores})->is_plural  => q{is_plural: 'paradores'};
ok noun(q{polos})->is_plural  => q{is_plural: 'polos'};
ok noun(q{succubuses})->is_plural  => q{is_plural: 'succubuses'};
ok noun(q{panorpae})->is_plural  => q{is_plural: 'panorpae'};
ok noun(q{set-tos})->is_plural  => q{is_plural: 'set-tos'};
ok noun(q{breaks-away})->is_plural  => q{is_plural: 'breaks-away'};
ok noun(q{canthari})->is_plural  => q{is_plural: 'canthari'};
ok noun(q{politbureaux})->is_plural  => q{is_plural: 'politbureaux'};
ok noun(q{raggares})->is_plural  => q{is_plural: 'raggares'};
ok noun(q{velamina})->is_plural  => q{is_plural: 'velamina'};
ok noun(q{Havanese})->is_plural  => q{is_plural: 'Havanese'};
ok noun(q{clitorides})->is_plural  => q{is_plural: 'clitorides'};
ok noun(q{Nicobarese})->is_plural  => q{is_plural: 'Nicobarese'};
ok noun(q{pollices})->is_plural  => q{is_plural: 'pollices'};
ok noun(q{puirt-a-beul})->is_plural  => q{is_plural: 'puirt-a-beul'};
ok noun(q{parenchymata})->is_plural  => q{is_plural: 'parenchymata'};
ok noun(q{oratrices})->is_plural  => q{is_plural: 'oratrices'};
ok noun(q{syntaxes})->is_plural  => q{is_plural: 'syntaxes'};
ok noun(q{snekkjur})->is_plural  => q{is_plural: 'snekkjur'};
ok noun(q{shawabtiu})->is_plural  => q{is_plural: 'shawabtiu'};
ok noun(q{faunas})->is_plural  => q{is_plural: 'faunas'};
ok noun(q{set offs})->is_plural  => q{is_plural: 'set offs'};
ok noun(q{nymphaea})->is_plural  => q{is_plural: 'nymphaea'};
ok noun(q{sacculi})->is_plural  => q{is_plural: 'sacculi'};
ok noun(q{ryper})->is_plural  => q{is_plural: 'ryper'};
ok noun(q{filariae})->is_plural  => q{is_plural: 'filariae'};
ok noun(q{ausleses})->is_plural  => q{is_plural: 'ausleses'};
ok noun(q{parisa})->is_plural  => q{is_plural: 'parisa'};
ok noun(q{Johnsonese})->is_plural  => q{is_plural: 'Johnsonese'};
ok noun(q{Navarrese})->is_plural  => q{is_plural: 'Navarrese'};
ok noun(q{Parmese})->is_plural  => q{is_plural: 'Parmese'};
ok noun(q{lactobacilli})->is_plural  => q{is_plural: 'lactobacilli'};
ok noun(q{hemelytra})->is_plural  => q{is_plural: 'hemelytra'};
ok noun(q{terebella})->is_plural  => q{is_plural: 'terebella'};
ok noun(q{Biros})->is_plural  => q{is_plural: 'Biros'};
ok noun(q{tripla})->is_plural  => q{is_plural: 'tripla'};
ok noun(q{musae})->is_plural  => q{is_plural: 'musae'};
ok noun(q{porticoes})->is_plural  => q{is_plural: 'porticoes'};
ok noun(q{major generals})->is_plural  => q{is_plural: 'major generals'};
ok noun(q{funguses})->is_plural  => q{is_plural: 'funguses'};
ok noun(q{stephanions})->is_plural  => q{is_plural: 'stephanions'};
ok noun(q{semunciae})->is_plural  => q{is_plural: 'semunciae'};
ok noun(q{scolopidia})->is_plural  => q{is_plural: 'scolopidia'};
ok noun(q{Sarajevos})->is_plural  => q{is_plural: 'Sarajevos'};
ok noun(q{tropaeola})->is_plural  => q{is_plural: 'tropaeola'};
ok noun(q{what})->is_plural  => q{is_plural: 'what'};
ok noun(q{lentisci})->is_plural  => q{is_plural: 'lentisci'};
ok noun(q{stirpes})->is_plural  => q{is_plural: 'stirpes'};
ok noun(q{tondi})->is_plural  => q{is_plural: 'tondi'};
ok noun(q{maecenates})->is_plural  => q{is_plural: 'maecenates'};
ok noun(q{subbotniki})->is_plural  => q{is_plural: 'subbotniki'};
ok noun(q{syllabi})->is_plural  => q{is_plural: 'syllabi'};
ok noun(q{chromidia})->is_plural  => q{is_plural: 'chromidia'};
ok noun(q{stornelli})->is_plural  => q{is_plural: 'stornelli'};
ok noun(q{manteaus})->is_plural  => q{is_plural: 'manteaus'};
ok noun(q{guanos})->is_plural  => q{is_plural: 'guanos'};
ok noun(q{hoties})->is_plural  => q{is_plural: 'hoties'};
ok noun(q{guglioes})->is_plural  => q{is_plural: 'guglioes'};
ok noun(q{herniae})->is_plural  => q{is_plural: 'herniae'};
ok noun(q{contangos})->is_plural  => q{is_plural: 'contangos'};
ok noun(q{costae})->is_plural  => q{is_plural: 'costae'};
ok noun(q{umbos})->is_plural  => q{is_plural: 'umbos'};
ok noun(q{musiques concretes})->is_plural  => q{is_plural: 'musiques concretes'};
ok noun(q{guglios})->is_plural  => q{is_plural: 'guglios'};
ok noun(q{phalanges})->is_plural  => q{is_plural: 'phalanges'};
ok noun(q{diverticula})->is_plural  => q{is_plural: 'diverticula'};
ok noun(q{atlases})->is_plural  => q{is_plural: 'atlases'};
ok noun(q{meshummadim})->is_plural  => q{is_plural: 'meshummadim'};
ok noun(q{logodaedali})->is_plural  => q{is_plural: 'logodaedali'};
ok noun(q{fizzes})->is_plural  => q{is_plural: 'fizzes'};
ok noun(q{tsubas})->is_plural  => q{is_plural: 'tsubas'};
ok noun(q{men-milliners})->is_plural  => q{is_plural: 'men-milliners'};
ok noun(q{monosyllaba})->is_plural  => q{is_plural: 'monosyllaba'};
ok noun(q{mackerels})->is_plural  => q{is_plural: 'mackerels'};
ok noun(q{Greensboros})->is_plural  => q{is_plural: 'Greensboros'};
ok noun(q{sericteria})->is_plural  => q{is_plural: 'sericteria'};
ok noun(q{mousetraps})->is_plural  => q{is_plural: 'mousetraps'};
ok noun(q{stylopodia})->is_plural  => q{is_plural: 'stylopodia'};
ok noun(q{interstitia})->is_plural  => q{is_plural: 'interstitia'};
ok noun(q{eyases})->is_plural  => q{is_plural: 'eyases'};
ok noun(q{micrococci})->is_plural  => q{is_plural: 'micrococci'};
ok noun(q{minnelieder})->is_plural  => q{is_plural: 'minnelieder'};
ok noun(q{sum-totals})->is_plural  => q{is_plural: 'sum-totals'};
ok noun(q{extispices})->is_plural  => q{is_plural: 'extispices'};
ok noun(q{tombaroli})->is_plural  => q{is_plural: 'tombaroli'};
ok noun(q{mesothelia})->is_plural  => q{is_plural: 'mesothelia'};
ok noun(q{zoeae})->is_plural  => q{is_plural: 'zoeae'};
ok noun(q{corpora vilia})->is_plural  => q{is_plural: 'corpora vilia'};
ok noun(q{branchiopods})->is_plural  => q{is_plural: 'branchiopods'};
ok noun(q{sassafrases})->is_plural  => q{is_plural: 'sassafrases'};
ok noun(q{gymnoti})->is_plural  => q{is_plural: 'gymnoti'};
ok noun(q{elk})->is_plural  => q{is_plural: 'elk'};
ok noun(q{nimbi})->is_plural  => q{is_plural: 'nimbi'};
ok noun(q{commanding generals})->is_plural  => q{is_plural: 'commanding generals'};
ok noun(q{caffe macchiati})->is_plural  => q{is_plural: 'caffe macchiati'};
ok noun(q{fabellae})->is_plural  => q{is_plural: 'fabellae'};
ok noun(q{clausulae})->is_plural  => q{is_plural: 'clausulae'};
ok noun(q{parvenus})->is_plural  => q{is_plural: 'parvenus'};
ok noun(q{whose})->is_plural  => q{is_plural: 'whose'};
ok noun(q{poise})->is_plural  => q{is_plural: 'poise'};
ok noun(q{francs archers})->is_plural  => q{is_plural: 'francs archers'};
ok noun(q{dogmata})->is_plural  => q{is_plural: 'dogmata'};
ok noun(q{secundiparae})->is_plural  => q{is_plural: 'secundiparae'};
ok noun(q{perniones})->is_plural  => q{is_plural: 'perniones'};
ok noun(q{mycorhizas})->is_plural  => q{is_plural: 'mycorhizas'};
ok noun(q{lemmas})->is_plural  => q{is_plural: 'lemmas'};
ok noun(q{planctus})->is_plural  => q{is_plural: 'planctus'};
ok noun(q{felos de se})->is_plural  => q{is_plural: 'felos de se'};
ok noun(q{vermiculi})->is_plural  => q{is_plural: 'vermiculi'};
ok noun(q{fibromata})->is_plural  => q{is_plural: 'fibromata'};
ok noun(q{mitochondria})->is_plural  => q{is_plural: 'mitochondria'};
ok noun(q{ephemerises})->is_plural  => q{is_plural: 'ephemerises'};
ok noun(q{knoppern})->is_plural  => q{is_plural: 'knoppern'};
ok noun(q{toruli})->is_plural  => q{is_plural: 'toruli'};
ok noun(q{tortrices})->is_plural  => q{is_plural: 'tortrices'};
ok noun(q{ri})->is_plural  => q{is_plural: 'ri'};
ok noun(q{monoxyla})->is_plural  => q{is_plural: 'monoxyla'};
ok noun(q{palpi})->is_plural  => q{is_plural: 'palpi'};
ok noun(q{sequestra})->is_plural  => q{is_plural: 'sequestra'};
ok noun(q{apices})->is_plural  => q{is_plural: 'apices'};
ok noun(q{ballerine})->is_plural  => q{is_plural: 'ballerine'};
ok noun(q{fascias})->is_plural  => q{is_plural: 'fascias'};
ok noun(q{zizzes})->is_plural  => q{is_plural: 'zizzes'};
ok noun(q{zoaeae})->is_plural  => q{is_plural: 'zoaeae'};
ok noun(q{xanthomata})->is_plural  => q{is_plural: 'xanthomata'};
ok noun(q{umbilici})->is_plural  => q{is_plural: 'umbilici'};
ok noun(q{manifestos})->is_plural  => q{is_plural: 'manifestos'};
ok noun(q{Ceylonese})->is_plural  => q{is_plural: 'Ceylonese'};
ok noun(q{reiche})->is_plural  => q{is_plural: 'reiche'};
ok noun(q{prodromi})->is_plural  => q{is_plural: 'prodromi'};
ok noun(q{surimonos})->is_plural  => q{is_plural: 'surimonos'};
ok noun(q{maare})->is_plural  => q{is_plural: 'maare'};
ok noun(q{mice})->is_plural  => q{is_plural: 'mice'};
ok noun(q{liberos})->is_plural  => q{is_plural: 'liberos'};
ok noun(q{strigae})->is_plural  => q{is_plural: 'strigae'};
ok noun(q{tuberculomas})->is_plural  => q{is_plural: 'tuberculomas'};
ok noun(q{taeniae})->is_plural  => q{is_plural: 'taeniae'};
ok noun(q{culs-de-lampe})->is_plural  => q{is_plural: 'culs-de-lampe'};
ok noun(q{pinnae})->is_plural  => q{is_plural: 'pinnae'};
ok noun(q{peltae})->is_plural  => q{is_plural: 'peltae'};
ok noun(q{rami})->is_plural  => q{is_plural: 'rami'};
ok noun(q{pants})->is_plural  => q{is_plural: 'pants'};
ok noun(q{virtuosi})->is_plural  => q{is_plural: 'virtuosi'};
ok noun(q{oscula})->is_plural  => q{is_plural: 'oscula'};
ok noun(q{colonel generals})->is_plural  => q{is_plural: 'colonel generals'};
ok noun(q{vitellaria})->is_plural  => q{is_plural: 'vitellaria'};
ok noun(q{trabeae})->is_plural  => q{is_plural: 'trabeae'};
ok noun(q{Pangasinanes})->is_plural  => q{is_plural: 'Pangasinanes'};
ok noun(q{stigmas})->is_plural  => q{is_plural: 'stigmas'};
ok noun(q{amenta})->is_plural  => q{is_plural: 'amenta'};
ok noun(q{sotchs})->is_plural  => q{is_plural: 'sotchs'};
ok noun(q{penes})->is_plural  => q{is_plural: 'penes'};
ok noun(q{dreikanters})->is_plural  => q{is_plural: 'dreikanters'};
ok noun(q{paleae})->is_plural  => q{is_plural: 'paleae'};
ok noun(q{graffiti})->is_plural  => q{is_plural: 'graffiti'};
ok noun(q{rimonim})->is_plural  => q{is_plural: 'rimonim'};
ok noun(q{pingoes})->is_plural  => q{is_plural: 'pingoes'};
ok noun(q{pyritae})->is_plural  => q{is_plural: 'pyritae'};
ok noun(q{valvulae})->is_plural  => q{is_plural: 'valvulae'};
ok noun(q{pollinia})->is_plural  => q{is_plural: 'pollinia'};
ok noun(q{staphylococci})->is_plural  => q{is_plural: 'staphylococci'};
ok noun(q{schemas})->is_plural  => q{is_plural: 'schemas'};
ok noun(q{amphorae})->is_plural  => q{is_plural: 'amphorae'};
ok noun(q{isthmi})->is_plural  => q{is_plural: 'isthmi'};
ok noun(q{bilboes})->is_plural  => q{is_plural: 'bilboes'};
ok noun(q{chevaux de bataille})->is_plural  => q{is_plural: 'chevaux de bataille'};
ok noun(q{sulci})->is_plural  => q{is_plural: 'sulci'};
ok noun(q{aliases})->is_plural  => q{is_plural: 'aliases'};
ok noun(q{Londonese})->is_plural  => q{is_plural: 'Londonese'};
ok noun(q{terpen})->is_plural  => q{is_plural: 'terpen'};
ok noun(q{uredosori})->is_plural  => q{is_plural: 'uredosori'};
ok noun(q{arboreta})->is_plural  => q{is_plural: 'arboreta'};
ok noun(q{star-fishes})->is_plural  => q{is_plural: 'star-fishes'};
ok noun(q{lves})->is_plural  => q{is_plural: 'lves'};
ok noun(q{abortuses})->is_plural  => q{is_plural: 'abortuses'};
ok noun(q{tarsi})->is_plural  => q{is_plural: 'tarsi'};
ok noun(q{sephardin})->is_plural  => q{is_plural: 'sephardin'};
ok noun(q{technos})->is_plural  => q{is_plural: 'technos'};
ok noun(q{stipites})->is_plural  => q{is_plural: 'stipites'};
ok noun(q{moose})->is_plural  => q{is_plural: 'moose'};
ok noun(q{psammomata})->is_plural  => q{is_plural: 'psammomata'};
ok noun(q{Kosovos})->is_plural  => q{is_plural: 'Kosovos'};
ok noun(q{pluralia tantum})->is_plural  => q{is_plural: 'pluralia tantum'};
ok noun(q{phymata})->is_plural  => q{is_plural: 'phymata'};
ok noun(q{pliers})->is_plural  => q{is_plural: 'pliers'};
ok noun(q{reguli})->is_plural  => q{is_plural: 'reguli'};
ok noun(q{beaus})->is_plural  => q{is_plural: 'beaus'};
ok noun(q{papyruses})->is_plural  => q{is_plural: 'papyruses'};
ok noun(q{thoes})->is_plural  => q{is_plural: 'thoes'};
ok noun(q{nockerln})->is_plural  => q{is_plural: 'nockerln'};
ok noun(q{salite})->is_plural  => q{is_plural: 'salite'};
ok noun(q{nemathecia})->is_plural  => q{is_plural: 'nemathecia'};
ok noun(q{cantos})->is_plural  => q{is_plural: 'cantos'};
ok noun(q{burschen})->is_plural  => q{is_plural: 'burschen'};
ok noun(q{synaxes})->is_plural  => q{is_plural: 'synaxes'};
ok noun(q{pragmas})->is_plural  => q{is_plural: 'pragmas'};
ok noun(q{propria})->is_plural  => q{is_plural: 'propria'};
ok noun(q{tobaccos})->is_plural  => q{is_plural: 'tobaccos'};
ok noun(q{substratums})->is_plural  => q{is_plural: 'substratums'};
ok noun(q{peninsulae})->is_plural  => q{is_plural: 'peninsulae'};
ok noun(q{glasses})->is_plural  => q{is_plural: 'glasses'};
ok noun(q{favellae})->is_plural  => q{is_plural: 'favellae'};
ok noun(q{sancta sanctorum})->is_plural  => q{is_plural: 'sancta sanctorum'};
ok noun(q{maria})->is_plural  => q{is_plural: 'maria'};
ok noun(q{silbadors})->is_plural  => q{is_plural: 'silbadors'};
ok noun(q{trulli})->is_plural  => q{is_plural: 'trulli'};
ok noun(q{tomatoes})->is_plural  => q{is_plural: 'tomatoes'};
ok noun(q{paraselenae})->is_plural  => q{is_plural: 'paraselenae'};
ok noun(q{tetrapleurons})->is_plural  => q{is_plural: 'tetrapleurons'};
ok noun(q{soli})->is_plural  => q{is_plural: 'soli'};
ok noun(q{codices})->is_plural  => q{is_plural: 'codices'};
ok noun(q{uraei})->is_plural  => q{is_plural: 'uraei'};
ok noun(q{chervontzi})->is_plural  => q{is_plural: 'chervontzi'};
ok noun(q{sestertia})->is_plural  => q{is_plural: 'sestertia'};
ok noun(q{ourselves})->is_plural  => q{is_plural: 'ourselves'};
ok noun(q{scungilli})->is_plural  => q{is_plural: 'scungilli'};
ok noun(q{geisteswissenschaften})->is_plural  => q{is_plural: 'geisteswissenschaften'};
ok noun(q{specula})->is_plural  => q{is_plural: 'specula'};
ok noun(q{indexes})->is_plural  => q{is_plural: 'indexes'};
ok noun(q{hemangeiomas})->is_plural  => q{is_plural: 'hemangeiomas'};
ok noun(q{platypodes})->is_plural  => q{is_plural: 'platypodes'};
ok noun(q{directrices})->is_plural  => q{is_plural: 'directrices'};
ok noun(q{pence})->is_plural  => q{is_plural: 'pence'};
ok noun(q{stromodaea})->is_plural  => q{is_plural: 'stromodaea'};
ok noun(q{miracidia})->is_plural  => q{is_plural: 'miracidia'};
ok noun(q{calzones})->is_plural  => q{is_plural: 'calzones'};
ok noun(q{tractella})->is_plural  => q{is_plural: 'tractella'};
ok noun(q{zygomas})->is_plural  => q{is_plural: 'zygomas'};
ok noun(q{exanthemata})->is_plural  => q{is_plural: 'exanthemata'};
ok noun(q{atlantes})->is_plural  => q{is_plural: 'atlantes'};
ok noun(q{flabella})->is_plural  => q{is_plural: 'flabella'};
ok noun(q{camerae obscurae})->is_plural  => q{is_plural: 'camerae obscurae'};
ok noun(q{tenues})->is_plural  => q{is_plural: 'tenues'};
ok noun(q{curiosos})->is_plural  => q{is_plural: 'curiosos'};
ok noun(q{pimentos})->is_plural  => q{is_plural: 'pimentos'};
ok noun(q{byliny})->is_plural  => q{is_plural: 'byliny'};
ok noun(q{nexus})->is_plural  => q{is_plural: 'nexus'};
ok noun(q{Viennese})->is_plural  => q{is_plural: 'Viennese'};
ok noun(q{zuzzes})->is_plural  => q{is_plural: 'zuzzes'};
ok noun(q{bisons})->is_plural  => q{is_plural: 'bisons'};
ok noun(q{curiosi})->is_plural  => q{is_plural: 'curiosi'};
ok noun(q{cecidia})->is_plural  => q{is_plural: 'cecidia'};
ok noun(q{Sikkimese})->is_plural  => q{is_plural: 'Sikkimese'};
ok noun(q{nucleuses})->is_plural  => q{is_plural: 'nucleuses'};
ok noun(q{appendices})->is_plural  => q{is_plural: 'appendices'};
ok noun(q{bateaus})->is_plural  => q{is_plural: 'bateaus'};
ok noun(q{solenia})->is_plural  => q{is_plural: 'solenia'};
ok noun(q{oxybapha})->is_plural  => q{is_plural: 'oxybapha'};
ok noun(q{simulacrums})->is_plural  => q{is_plural: 'simulacrums'};
ok noun(q{trapezohedrons})->is_plural  => q{is_plural: 'trapezohedrons'};
ok noun(q{rotulae})->is_plural  => q{is_plural: 'rotulae'};
ok noun(q{lymphomas})->is_plural  => q{is_plural: 'lymphomas'};
ok noun(q{congii})->is_plural  => q{is_plural: 'congii'};
ok noun(q{mediastina})->is_plural  => q{is_plural: 'mediastina'};
ok noun(q{zeros})->is_plural  => q{is_plural: 'zeros'};
ok noun(q{batzes})->is_plural  => q{is_plural: 'batzes'};
ok noun(q{oedemas})->is_plural  => q{is_plural: 'oedemas'};
ok noun(q{lumbagos})->is_plural  => q{is_plural: 'lumbagos'};
ok noun(q{paxillae})->is_plural  => q{is_plural: 'paxillae'};
ok noun(q{vasculums})->is_plural  => q{is_plural: 'vasculums'};
ok noun(q{corps})->is_plural  => q{is_plural: 'corps'};
ok noun(q{thieves})->is_plural  => q{is_plural: 'thieves'};
ok noun(q{statuas})->is_plural  => q{is_plural: 'statuas'};
ok noun(q{dynamos})->is_plural  => q{is_plural: 'dynamos'};
ok noun(q{parapsides})->is_plural  => q{is_plural: 'parapsides'};
ok noun(q{termites})->is_plural  => q{is_plural: 'termites'};
ok noun(q{anti sera})->is_plural  => q{is_plural: 'anti sera'};
ok noun(q{nouveaux arrives})->is_plural  => q{is_plural: 'nouveaux arrives'};
ok noun(q{tangoes})->is_plural  => q{is_plural: 'tangoes'};
ok noun(q{molimina})->is_plural  => q{is_plural: 'molimina'};
ok noun(q{postpubes})->is_plural  => q{is_plural: 'postpubes'};
ok noun(q{rejones})->is_plural  => q{is_plural: 'rejones'};
ok noun(q{halteridia})->is_plural  => q{is_plural: 'halteridia'};
ok noun(q{serpigines})->is_plural  => q{is_plural: 'serpigines'};
ok noun(q{tabulae})->is_plural  => q{is_plural: 'tabulae'};
ok noun(q{vlakten})->is_plural  => q{is_plural: 'vlakten'};
ok noun(q{Portos})->is_plural  => q{is_plural: 'Portos'};
ok noun(q{tenacula})->is_plural  => q{is_plural: 'tenacula'};
ok noun(q{pianos})->is_plural  => q{is_plural: 'pianos'};
ok noun(q{women servants})->is_plural  => q{is_plural: 'women servants'};
ok noun(q{siroccos})->is_plural  => q{is_plural: 'siroccos'};
ok noun(q{shauries})->is_plural  => q{is_plural: 'shauries'};
ok noun(q{ephemeras})->is_plural  => q{is_plural: 'ephemeras'};
ok noun(q{carabinieri})->is_plural  => q{is_plural: 'carabinieri'};
ok noun(q{paterae})->is_plural  => q{is_plural: 'paterae'};
ok noun(q{shauris})->is_plural  => q{is_plural: 'shauris'};
ok noun(q{Hoosierese})->is_plural  => q{is_plural: 'Hoosierese'};
ok noun(q{shomrim})->is_plural  => q{is_plural: 'shomrim'};
ok noun(q{fermate})->is_plural  => q{is_plural: 'fermate'};
ok noun(q{melismas})->is_plural  => q{is_plural: 'melismas'};
ok noun(q{camera obscuras})->is_plural  => q{is_plural: 'camera obscuras'};
ok noun(q{scazons})->is_plural  => q{is_plural: 'scazons'};
ok noun(q{culs de four})->is_plural  => q{is_plural: 'culs de four'};
ok noun(q{fenestrae})->is_plural  => q{is_plural: 'fenestrae'};
ok noun(q{traumata})->is_plural  => q{is_plural: 'traumata'};
ok noun(q{momentums})->is_plural  => q{is_plural: 'momentums'};
ok noun(q{pulli})->is_plural  => q{is_plural: 'pulli'};
ok noun(q{bandeaus})->is_plural  => q{is_plural: 'bandeaus'};
ok noun(q{retinulae})->is_plural  => q{is_plural: 'retinulae'};
ok noun(q{Gabunese})->is_plural  => q{is_plural: 'Gabunese'};
ok noun(q{Kongoese})->is_plural  => q{is_plural: 'Kongoese'};
ok noun(q{politicos})->is_plural  => q{is_plural: 'politicos'};
ok noun(q{caducei})->is_plural  => q{is_plural: 'caducei'};
ok noun(q{uruses})->is_plural  => q{is_plural: 'uruses'};
ok noun(q{basilicas})->is_plural  => q{is_plural: 'basilicas'};
ok noun(q{cyanos})->is_plural  => q{is_plural: 'cyanos'};
ok noun(q{fibulae})->is_plural  => q{is_plural: 'fibulae'};
ok noun(q{them})->is_plural  => q{is_plural: 'them'};
ok noun(q{nentsi})->is_plural  => q{is_plural: 'nentsi'};
ok noun(q{lepta})->is_plural  => q{is_plural: 'lepta'};
ok noun(q{bon mots})->is_plural  => q{is_plural: 'bon mots'};
ok noun(q{carcinomas})->is_plural  => q{is_plural: 'carcinomas'};
ok noun(q{Pangasinans})->is_plural  => q{is_plural: 'Pangasinans'};
ok noun(q{regmata})->is_plural  => q{is_plural: 'regmata'};
ok noun(q{grottoes})->is_plural  => q{is_plural: 'grottoes'};
ok noun(q{hypnums})->is_plural  => q{is_plural: 'hypnums'};
ok noun(q{pizze})->is_plural  => q{is_plural: 'pizze'};
ok noun(q{vaqueros})->is_plural  => q{is_plural: 'vaqueros'};
ok noun(q{saga})->is_plural  => q{is_plural: 'saga'};
ok noun(q{tessellae})->is_plural  => q{is_plural: 'tessellae'};
ok noun(q{rondeaus})->is_plural  => q{is_plural: 'rondeaus'};
ok noun(q{mantises})->is_plural  => q{is_plural: 'mantises'};
ok noun(q{grottos})->is_plural  => q{is_plural: 'grottos'};
ok noun(q{denotata})->is_plural  => q{is_plural: 'denotata'};
ok noun(q{superstrata})->is_plural  => q{is_plural: 'superstrata'};
ok noun(q{six-star generals})->is_plural  => q{is_plural: 'six-star generals'};
ok noun(q{symposia})->is_plural  => q{is_plural: 'symposia'};
ok noun(q{Spaetlesen})->is_plural  => q{is_plural: 'Spaetlesen'};
ok noun(q{culs de lampe})->is_plural  => q{is_plural: 'culs de lampe'};
ok noun(q{autochthons})->is_plural  => q{is_plural: 'autochthons'};
ok noun(q{rimmonim})->is_plural  => q{is_plural: 'rimmonim'};
ok noun(q{Yamoussoukros})->is_plural  => q{is_plural: 'Yamoussoukros'};
ok noun(q{stromata})->is_plural  => q{is_plural: 'stromata'};
ok noun(q{listerias})->is_plural  => q{is_plural: 'listerias'};
ok noun(q{chrysalises})->is_plural  => q{is_plural: 'chrysalises'};
ok noun(q{modi})->is_plural  => q{is_plural: 'modi'};
ok noun(q{tentamina})->is_plural  => q{is_plural: 'tentamina'};
ok noun(q{legumina})->is_plural  => q{is_plural: 'legumina'};
ok noun(q{equiseta})->is_plural  => q{is_plural: 'equiseta'};
ok noun(q{minimums})->is_plural  => q{is_plural: 'minimums'};
ok noun(q{opuscula})->is_plural  => q{is_plural: 'opuscula'};
ok noun(q{thymiateria})->is_plural  => q{is_plural: 'thymiateria'};
ok noun(q{five-star generals})->is_plural  => q{is_plural: 'five-star generals'};
ok noun(q{sipunculi})->is_plural  => q{is_plural: 'sipunculi'};
ok noun(q{halibuts})->is_plural  => q{is_plural: 'halibuts'};
ok noun(q{alguaciles})->is_plural  => q{is_plural: 'alguaciles'};
ok noun(q{podia})->is_plural  => q{is_plural: 'podia'};
ok noun(q{purlieux})->is_plural  => q{is_plural: 'purlieux'};
ok noun(q{strobilae})->is_plural  => q{is_plural: 'strobilae'};
ok noun(q{thoraces})->is_plural  => q{is_plural: 'thoraces'};
ok noun(q{oceanaria})->is_plural  => q{is_plural: 'oceanaria'};
ok noun(q{sets off})->is_plural  => q{is_plural: 'sets off'};
ok noun(q{belles epoques})->is_plural  => q{is_plural: 'belles epoques'};
ok noun(q{bregmata})->is_plural  => q{is_plural: 'bregmata'};
ok noun(q{rediae})->is_plural  => q{is_plural: 'rediae'};
ok noun(q{simplexes})->is_plural  => q{is_plural: 'simplexes'};
ok noun(q{sandr})->is_plural  => q{is_plural: 'sandr'};
ok noun(q{pengoes})->is_plural  => q{is_plural: 'pengoes'};
ok noun(q{Malabos})->is_plural  => q{is_plural: 'Malabos'};
ok noun(q{lymphomata})->is_plural  => q{is_plural: 'lymphomata'};
ok noun(q{sensa})->is_plural  => q{is_plural: 'sensa'};
ok noun(q{pistillidia})->is_plural  => q{is_plural: 'pistillidia'};
ok noun(q{tibiae})->is_plural  => q{is_plural: 'tibiae'};
ok noun(q{prototypons})->is_plural  => q{is_plural: 'prototypons'};
ok noun(q{organa})->is_plural  => q{is_plural: 'organa'};
ok noun(q{coes})->is_plural  => q{is_plural: 'coes'};
ok noun(q{olfactoria})->is_plural  => q{is_plural: 'olfactoria'};
ok noun(q{Nankingese})->is_plural  => q{is_plural: 'Nankingese'};
ok noun(q{scherzos})->is_plural  => q{is_plural: 'scherzos'};
ok noun(q{sephardim})->is_plural  => q{is_plural: 'sephardim'};
ok noun(q{rarae aves})->is_plural  => q{is_plural: 'rarae aves'};
ok noun(q{Genoese})->is_plural  => q{is_plural: 'Genoese'};
ok noun(q{kovshi})->is_plural  => q{is_plural: 'kovshi'};
ok noun(q{ignoramuses})->is_plural  => q{is_plural: 'ignoramuses'};
ok noun(q{bustos})->is_plural  => q{is_plural: 'bustos'};
ok noun(q{lithodomi})->is_plural  => q{is_plural: 'lithodomi'};
ok noun(q{individua})->is_plural  => q{is_plural: 'individua'};
ok noun(q{atamans})->is_plural  => q{is_plural: 'atamans'};
ok noun(q{suggestums})->is_plural  => q{is_plural: 'suggestums'};
ok noun(q{agrogoroda})->is_plural  => q{is_plural: 'agrogoroda'};
ok noun(q{bureaus})->is_plural  => q{is_plural: 'bureaus'};
ok noun(q{pietre})->is_plural  => q{is_plural: 'pietre'};
ok noun(q{vortexes})->is_plural  => q{is_plural: 'vortexes'};
ok noun(q{soles})->is_plural  => q{is_plural: 'soles'};
ok noun(q{brethren-german})->is_plural  => q{is_plural: 'brethren-german'};
ok noun(q{stomata})->is_plural  => q{is_plural: 'stomata'};
ok noun(q{buzzes})->is_plural  => q{is_plural: 'buzzes'};
ok noun(q{caribou})->is_plural  => q{is_plural: 'caribou'};
ok noun(q{mangoes})->is_plural  => q{is_plural: 'mangoes'};
ok noun(q{brachiopods})->is_plural  => q{is_plural: 'brachiopods'};
ok noun(q{edemata})->is_plural  => q{is_plural: 'edemata'};
ok noun(q{stelae})->is_plural  => q{is_plural: 'stelae'};
ok noun(q{measles})->is_plural  => q{is_plural: 'measles'};
ok noun(q{sympodia})->is_plural  => q{is_plural: 'sympodia'};
ok noun(q{mouths})->is_plural  => q{is_plural: 'mouths'};
ok noun(q{messe di voce})->is_plural  => q{is_plural: 'messe di voce'};
ok noun(q{alani})->is_plural  => q{is_plural: 'alani'};
ok noun(q{embryomata})->is_plural  => q{is_plural: 'embryomata'};
ok noun(q{tholoi})->is_plural  => q{is_plural: 'tholoi'};
ok noun(q{prospectuses})->is_plural  => q{is_plural: 'prospectuses'};
ok noun(q{desmata})->is_plural  => q{is_plural: 'desmata'};
ok noun(q{poises})->is_plural  => q{is_plural: 'poises'};
ok noun(q{cremasters})->is_plural  => q{is_plural: 'cremasters'};
ok noun(q{dicta})->is_plural  => q{is_plural: 'dicta'};
ok noun(q{figurantes})->is_plural  => q{is_plural: 'figurantes'};
ok noun(q{favissae})->is_plural  => q{is_plural: 'favissae'};
ok noun(q{rhopalia})->is_plural  => q{is_plural: 'rhopalia'};
ok noun(q{serpigoes})->is_plural  => q{is_plural: 'serpigoes'};
ok noun(q{strumae})->is_plural  => q{is_plural: 'strumae'};
ok noun(q{parnassim})->is_plural  => q{is_plural: 'parnassim'};
ok noun(q{Idahos})->is_plural  => q{is_plural: 'Idahos'};
ok noun(q{politbureaus})->is_plural  => q{is_plural: 'politbureaus'};
ok noun(q{lingos})->is_plural  => q{is_plural: 'lingos'};
ok noun(q{contrafacta})->is_plural  => q{is_plural: 'contrafacta'};
ok noun(q{gladioli})->is_plural  => q{is_plural: 'gladioli'};
ok noun(q{beau gestes})->is_plural  => q{is_plural: 'beau gestes'};
ok noun(q{claustra})->is_plural  => q{is_plural: 'claustra'};
ok noun(q{scuole})->is_plural  => q{is_plural: 'scuole'};
ok noun(q{alumnae})->is_plural  => q{is_plural: 'alumnae'};
ok noun(q{stomodea})->is_plural  => q{is_plural: 'stomodea'};
ok noun(q{pyrexiae})->is_plural  => q{is_plural: 'pyrexiae'};
ok noun(q{faits accomplis})->is_plural  => q{is_plural: 'faits accomplis'};
ok noun(q{vaporetti})->is_plural  => q{is_plural: 'vaporetti'};
ok noun(q{asyla})->is_plural  => q{is_plural: 'asyla'};
ok noun(q{limos})->is_plural  => q{is_plural: 'limos'};
ok noun(q{ibises})->is_plural  => q{is_plural: 'ibises'};
ok noun(q{siemens})->is_plural  => q{is_plural: 'siemens'};
ok noun(q{diplomata})->is_plural  => q{is_plural: 'diplomata'};
ok noun(q{Panamans})->is_plural  => q{is_plural: 'Panamans'};
ok noun(q{otomies})->is_plural  => q{is_plural: 'otomies'};
ok noun(q{haemangiomata})->is_plural  => q{is_plural: 'haemangiomata'};
ok noun(q{Buginese})->is_plural  => q{is_plural: 'Buginese'};
ok noun(q{guardias civiles})->is_plural  => q{is_plural: 'guardias civiles'};
ok noun(q{dice})->is_plural  => q{is_plural: 'dice'};
ok noun(q{polises})->is_plural  => q{is_plural: 'polises'};
ok noun(q{corni})->is_plural  => q{is_plural: 'corni'};
ok noun(q{placita})->is_plural  => q{is_plural: 'placita'};
ok noun(q{cactuses})->is_plural  => q{is_plural: 'cactuses'};
ok noun(q{proboscides})->is_plural  => q{is_plural: 'proboscides'};
ok noun(q{inhalatoria})->is_plural  => q{is_plural: 'inhalatoria'};
ok noun(q{pyxidia})->is_plural  => q{is_plural: 'pyxidia'};
ok noun(q{caryopsides})->is_plural  => q{is_plural: 'caryopsides'};
ok noun(q{rejoneadores})->is_plural  => q{is_plural: 'rejoneadores'};
ok noun(q{Milanos})->is_plural  => q{is_plural: 'Milanos'};
ok noun(q{versiculi})->is_plural  => q{is_plural: 'versiculi'};
ok noun(q{fanfoots})->is_plural  => q{is_plural: 'fanfoots'};
ok noun(q{ours})->is_plural  => q{is_plural: 'ours'};
ok noun(q{patagia})->is_plural  => q{is_plural: 'patagia'};
ok noun(q{vibices})->is_plural  => q{is_plural: 'vibices'};
ok noun(q{shiftas})->is_plural  => q{is_plural: 'shiftas'};
ok noun(q{merides})->is_plural  => q{is_plural: 'merides'};
ok noun(q{tsuba})->is_plural  => q{is_plural: 'tsuba'};
ok noun(q{mausolea})->is_plural  => q{is_plural: 'mausolea'};
ok noun(q{brethren})->is_plural  => q{is_plural: 'brethren'};
ok noun(q{brothers german})->is_plural  => q{is_plural: 'brothers german'};
ok noun(q{culs-de-four})->is_plural  => q{is_plural: 'culs-de-four'};
ok noun(q{rezidenty})->is_plural  => q{is_plural: 'rezidenty'};
ok noun(q{prorae})->is_plural  => q{is_plural: 'prorae'};
ok noun(q{xanthomas})->is_plural  => q{is_plural: 'xanthomas'};
ok noun(q{sagos})->is_plural  => q{is_plural: 'sagos'};
ok noun(q{villanelle})->is_plural  => q{is_plural: 'villanelle'};
ok noun(q{Assamese})->is_plural  => q{is_plural: 'Assamese'};
ok noun(q{piscinas})->is_plural  => q{is_plural: 'piscinas'};
ok noun(q{acroamata})->is_plural  => q{is_plural: 'acroamata'};
ok noun(q{four star generals})->is_plural  => q{is_plural: 'four star generals'};
ok noun(q{grouses})->is_plural  => q{is_plural: 'grouses'};
ok noun(q{ustilagines})->is_plural  => q{is_plural: 'ustilagines'};
ok noun(q{tetanother})->is_plural  => q{is_plural: 'tetanother'};
ok noun(q{Chinese})->is_plural  => q{is_plural: 'Chinese'};
ok noun(q{thanatoria})->is_plural  => q{is_plural: 'thanatoria'};
ok noun(q{tazze})->is_plural  => q{is_plural: 'tazze'};
ok noun(q{abacuses})->is_plural  => q{is_plural: 'abacuses'};
ok noun(q{ostia})->is_plural  => q{is_plural: 'ostia'};
ok noun(q{spondyli})->is_plural  => q{is_plural: 'spondyli'};
ok noun(q{peridia})->is_plural  => q{is_plural: 'peridia'};
ok noun(q{court-martials})->is_plural  => q{is_plural: 'court-martials'};
ok noun(q{autochthones})->is_plural  => q{is_plural: 'autochthones'};
ok noun(q{macros})->is_plural  => q{is_plural: 'macros'};
ok noun(q{flocculi})->is_plural  => q{is_plural: 'flocculi'};
ok noun(q{Genevese})->is_plural  => q{is_plural: 'Genevese'};
ok noun(q{neritas})->is_plural  => q{is_plural: 'neritas'};
ok noun(q{gummata})->is_plural  => q{is_plural: 'gummata'};
ok noun(q{cherubim})->is_plural  => q{is_plural: 'cherubim'};
ok noun(q{gravamina})->is_plural  => q{is_plural: 'gravamina'};
ok noun(q{radialia})->is_plural  => q{is_plural: 'radialia'};
ok noun(q{epiphenomena})->is_plural  => q{is_plural: 'epiphenomena'};
ok noun(q{lenses})->is_plural  => q{is_plural: 'lenses'};
ok noun(q{metalimnia})->is_plural  => q{is_plural: 'metalimnia'};
ok noun(q{velaria})->is_plural  => q{is_plural: 'velaria'};
ok noun(q{rubashkas})->is_plural  => q{is_plural: 'rubashkas'};
ok noun(q{sacraria})->is_plural  => q{is_plural: 'sacraria'};
ok noun(q{quaesita})->is_plural  => q{is_plural: 'quaesita'};
ok noun(q{aboiteaus})->is_plural  => q{is_plural: 'aboiteaus'};
ok noun(q{vehicula})->is_plural  => q{is_plural: 'vehicula'};
ok noun(q{people})->is_plural  => q{is_plural: 'people'};
ok noun(q{frustums})->is_plural  => q{is_plural: 'frustums'};
ok noun(q{cod})->is_plural  => q{is_plural: 'cod'};
ok noun(q{starfishes})->is_plural  => q{is_plural: 'starfishes'};
ok noun(q{thyrsi})->is_plural  => q{is_plural: 'thyrsi'};
ok noun(q{agapes})->is_plural  => q{is_plural: 'agapes'};
ok noun(q{postnati})->is_plural  => q{is_plural: 'postnati'};
ok noun(q{trochuses})->is_plural  => q{is_plural: 'trochuses'};
ok noun(q{schemata})->is_plural  => q{is_plural: 'schemata'};
ok noun(q{craft})->is_plural  => q{is_plural: 'craft'};
ok noun(q{tragi})->is_plural  => q{is_plural: 'tragi'};
ok noun(q{flocci})->is_plural  => q{is_plural: 'flocci'};
ok noun(q{mondi})->is_plural  => q{is_plural: 'mondi'};
ok noun(q{pifferari})->is_plural  => q{is_plural: 'pifferari'};
ok noun(q{palae})->is_plural  => q{is_plural: 'palae'};
ok noun(q{tesserae})->is_plural  => q{is_plural: 'tesserae'};
ok noun(q{momenta})->is_plural  => q{is_plural: 'momenta'};
ok noun(q{styluses})->is_plural  => q{is_plural: 'styluses'};
ok noun(q{ambos})->is_plural  => q{is_plural: 'ambos'};
ok noun(q{flounder})->is_plural  => q{is_plural: 'flounder'};
ok noun(q{vacuums})->is_plural  => q{is_plural: 'vacuums'};
ok noun(q{Siluri})->is_plural  => q{is_plural: 'Siluri'};
ok noun(q{judicata})->is_plural  => q{is_plural: 'judicata'};
ok noun(q{herpes})->is_plural  => q{is_plural: 'herpes'};
ok noun(q{herren})->is_plural  => q{is_plural: 'herren'};
ok noun(q{succi})->is_plural  => q{is_plural: 'succi'};
ok noun(q{puntos blancos})->is_plural  => q{is_plural: 'puntos blancos'};
ok noun(q{graben})->is_plural  => q{is_plural: 'graben'};
ok noun(q{juntos})->is_plural  => q{is_plural: 'juntos'};
ok noun(q{semas})->is_plural  => q{is_plural: 'semas'};
ok noun(q{shads})->is_plural  => q{is_plural: 'shads'};
ok noun(q{Kiplingese})->is_plural  => q{is_plural: 'Kiplingese'};
ok noun(q{eucalyptuses})->is_plural  => q{is_plural: 'eucalyptuses'};
ok noun(q{mallei})->is_plural  => q{is_plural: 'mallei'};
ok noun(q{tuna})->is_plural  => q{is_plural: 'tuna'};
ok noun(q{peronia})->is_plural  => q{is_plural: 'peronia'};
ok noun(q{sternums})->is_plural  => q{is_plural: 'sternums'};
ok noun(q{pinones})->is_plural  => q{is_plural: 'pinones'};
ok noun(q{vedute})->is_plural  => q{is_plural: 'vedute'};
ok noun(q{pangasinanes})->is_plural  => q{is_plural: 'pangasinanes'};
ok noun(q{5 star generals})->is_plural  => q{is_plural: '5 star generals'};
ok noun(q{itinera})->is_plural  => q{is_plural: 'itinera'};
ok noun(q{murexes})->is_plural  => q{is_plural: 'murexes'};
ok noun(q{sombreros})->is_plural  => q{is_plural: 'sombreros'};
ok noun(q{situlae})->is_plural  => q{is_plural: 'situlae'};
ok noun(q{Camaldolese})->is_plural  => q{is_plural: 'Camaldolese'};
ok noun(q{stigmata})->is_plural  => q{is_plural: 'stigmata'};
ok noun(q{viatica})->is_plural  => q{is_plural: 'viatica'};
ok noun(q{personas})->is_plural  => q{is_plural: 'personas'};
ok noun(q{provisos})->is_plural  => q{is_plural: 'provisos'};
ok noun(q{secundagravidae})->is_plural  => q{is_plural: 'secundagravidae'};
ok noun(q{zeitgebers})->is_plural  => q{is_plural: 'zeitgebers'};
ok noun(q{caveae})->is_plural  => q{is_plural: 'caveae'};
ok noun(q{axones})->is_plural  => q{is_plural: 'axones'};
ok noun(q{gallows})->is_plural  => q{is_plural: 'gallows'};
ok noun(q{coagula})->is_plural  => q{is_plural: 'coagula'};
ok noun(q{progymnasmata})->is_plural  => q{is_plural: 'progymnasmata'};
ok noun(q{rabies})->is_plural  => q{is_plural: 'rabies'};
ok noun(q{tempos})->is_plural  => q{is_plural: 'tempos'};
ok noun(q{lustrums})->is_plural  => q{is_plural: 'lustrums'};
ok noun(q{concerti grossi})->is_plural  => q{is_plural: 'concerti grossi'};
ok noun(q{stadiums})->is_plural  => q{is_plural: 'stadiums'};
ok noun(q{squali})->is_plural  => q{is_plural: 'squali'};
ok noun(q{uniones})->is_plural  => q{is_plural: 'uniones'};
ok noun(q{vaporettos})->is_plural  => q{is_plural: 'vaporettos'};
ok noun(q{vascula})->is_plural  => q{is_plural: 'vascula'};
ok noun(q{ballistae})->is_plural  => q{is_plural: 'ballistae'};
ok noun(q{naye paise})->is_plural  => q{is_plural: 'naye paise'};
ok noun(q{ziti})->is_plural  => q{is_plural: 'ziti'};
ok noun(q{man milliners})->is_plural  => q{is_plural: 'man milliners'};
ok noun(q{toreros})->is_plural  => q{is_plural: 'toreros'};
ok noun(q{comae})->is_plural  => q{is_plural: 'comae'};
ok noun(q{cortexes})->is_plural  => q{is_plural: 'cortexes'};
ok noun(q{subbotniks})->is_plural  => q{is_plural: 'subbotniks'};
ok noun(q{Lebanese})->is_plural  => q{is_plural: 'Lebanese'};
ok noun(q{lumbrici})->is_plural  => q{is_plural: 'lumbrici'};
ok noun(q{asteriae})->is_plural  => q{is_plural: 'asteriae'};
ok noun(q{magmas})->is_plural  => q{is_plural: 'magmas'};
ok noun(q{pobladores})->is_plural  => q{is_plural: 'pobladores'};
ok noun(q{multigravidae})->is_plural  => q{is_plural: 'multigravidae'};
ok noun(q{wildebeests})->is_plural  => q{is_plural: 'wildebeests'};
ok noun(q{millenniums})->is_plural  => q{is_plural: 'millenniums'};
ok noun(q{prytanes})->is_plural  => q{is_plural: 'prytanes'};
ok noun(q{virgae})->is_plural  => q{is_plural: 'virgae'};
ok noun(q{women-servants})->is_plural  => q{is_plural: 'women-servants'};
ok noun(q{cuniculi})->is_plural  => q{is_plural: 'cuniculi'};
ok noun(q{ambulacra})->is_plural  => q{is_plural: 'ambulacra'};
ok noun(q{pragmata})->is_plural  => q{is_plural: 'pragmata'};
ok noun(q{iters})->is_plural  => q{is_plural: 'iters'};
ok noun(q{cartes de visite})->is_plural  => q{is_plural: 'cartes de visite'};
ok noun(q{Colorados})->is_plural  => q{is_plural: 'Colorados'};
ok noun(q{who})->is_plural  => q{is_plural: 'who'};
ok noun(q{gonimia})->is_plural  => q{is_plural: 'gonimia'};
ok noun(q{speculums})->is_plural  => q{is_plural: 'speculums'};
ok noun(q{seecatchie})->is_plural  => q{is_plural: 'seecatchie'};
ok noun(q{salpae})->is_plural  => q{is_plural: 'salpae'};
ok noun(q{line-outs})->is_plural  => q{is_plural: 'line-outs'};
ok noun(q{placeboes})->is_plural  => q{is_plural: 'placeboes'};
ok noun(q{pyjamas})->is_plural  => q{is_plural: 'pyjamas'};
ok noun(q{virtuosos})->is_plural  => q{is_plural: 'virtuosos'};
ok noun(q{manubriums})->is_plural  => q{is_plural: 'manubriums'};
ok noun(q{malleoli})->is_plural  => q{is_plural: 'malleoli'};
ok noun(q{heroes})->is_plural  => q{is_plural: 'heroes'};
ok noun(q{romanzen})->is_plural  => q{is_plural: 'romanzen'};
ok noun(q{mesotheliomas})->is_plural  => q{is_plural: 'mesotheliomas'};
ok noun(q{corrigenda})->is_plural  => q{is_plural: 'corrigenda'};
ok noun(q{anti-serums})->is_plural  => q{is_plural: 'anti-serums'};
ok noun(q{urodea})->is_plural  => q{is_plural: 'urodea'};
ok noun(q{infernos})->is_plural  => q{is_plural: 'infernos'};
ok noun(q{oedemata})->is_plural  => q{is_plural: 'oedemata'};
ok noun(q{sarcomata})->is_plural  => q{is_plural: 'sarcomata'};
ok noun(q{phalluses})->is_plural  => q{is_plural: 'phalluses'};
ok noun(q{topoi})->is_plural  => q{is_plural: 'topoi'};
ok noun(q{menisci})->is_plural  => q{is_plural: 'menisci'};
ok noun(q{rugae})->is_plural  => q{is_plural: 'rugae'};
ok noun(q{limites})->is_plural  => q{is_plural: 'limites'};
ok noun(q{terrazzos})->is_plural  => q{is_plural: 'terrazzos'};
ok noun(q{involucra})->is_plural  => q{is_plural: 'involucra'};
ok noun(q{opera magna})->is_plural  => q{is_plural: 'opera magna'};
ok noun(q{pickerels})->is_plural  => q{is_plural: 'pickerels'};
ok noun(q{sanatoria})->is_plural  => q{is_plural: 'sanatoria'};
ok noun(q{afrits})->is_plural  => q{is_plural: 'afrits'};
ok noun(q{medulloblastomas})->is_plural  => q{is_plural: 'medulloblastomas'};
ok noun(q{Sangirese})->is_plural  => q{is_plural: 'Sangirese'};
ok noun(q{lamellae})->is_plural  => q{is_plural: 'lamellae'};
ok noun(q{zygomata})->is_plural  => q{is_plural: 'zygomata'};
ok noun(q{you})->is_plural  => q{is_plural: 'you'};
ok noun(q{gentes})->is_plural  => q{is_plural: 'gentes'};
ok noun(q{superficies})->is_plural  => q{is_plural: 'superficies'};
ok noun(q{hamuli})->is_plural  => q{is_plural: 'hamuli'};
ok noun(q{tonneaus})->is_plural  => q{is_plural: 'tonneaus'};
ok noun(q{moratoriums})->is_plural  => q{is_plural: 'moratoriums'};
ok noun(q{zooeae})->is_plural  => q{is_plural: 'zooeae'};
ok noun(q{hubrises})->is_plural  => q{is_plural: 'hubrises'};
ok noun(q{men children})->is_plural  => q{is_plural: 'men children'};
ok noun(q{matins})->is_plural  => q{is_plural: 'matins'};
ok noun(q{judases})->is_plural  => q{is_plural: 'judases'};
ok noun(q{micronuclei})->is_plural  => q{is_plural: 'micronuclei'};
ok noun(q{somata})->is_plural  => q{is_plural: 'somata'};
ok noun(q{aegises})->is_plural  => q{is_plural: 'aegises'};
ok noun(q{listerellas})->is_plural  => q{is_plural: 'listerellas'};
ok noun(q{2 star generals})->is_plural  => q{is_plural: '2 star generals'};
ok noun(q{spermatia})->is_plural  => q{is_plural: 'spermatia'};
ok noun(q{paraganglia})->is_plural  => q{is_plural: 'paraganglia'};
ok noun(q{coups d'etat})->is_plural  => q{is_plural: 'coups d'etat'};
ok noun(q{consortiums})->is_plural  => q{is_plural: 'consortiums'};
ok noun(q{bronchitises})->is_plural  => q{is_plural: 'bronchitises'};
ok noun(q{medicos})->is_plural  => q{is_plural: 'medicos'};
ok noun(q{differentiae})->is_plural  => q{is_plural: 'differentiae'};
ok noun(q{traumas})->is_plural  => q{is_plural: 'traumas'};
ok noun(q{flies})->is_plural  => q{is_plural: 'flies'};
ok noun(q{whatever})->is_plural  => q{is_plural: 'whatever'};
ok noun(q{pyralides})->is_plural  => q{is_plural: 'pyralides'};
ok noun(q{pholades})->is_plural  => q{is_plural: 'pholades'};
ok noun(q{medicoes})->is_plural  => q{is_plural: 'medicoes'};
ok noun(q{trumeaux})->is_plural  => q{is_plural: 'trumeaux'};
ok noun(q{6 star generals})->is_plural  => q{is_plural: '6 star generals'};
ok noun(q{yo-yos})->is_plural  => q{is_plural: 'yo-yos'};
ok noun(q{tenias})->is_plural  => q{is_plural: 'tenias'};
ok noun(q{star fish})->is_plural  => q{is_plural: 'star fish'};
ok noun(q{centesimi})->is_plural  => q{is_plural: 'centesimi'};
ok noun(q{ixodides})->is_plural  => q{is_plural: 'ixodides'};
ok noun(q{fidei defensores})->is_plural  => q{is_plural: 'fidei defensores'};
ok noun(q{mesotheliomata})->is_plural  => q{is_plural: 'mesotheliomata'};
ok noun(q{mottos})->is_plural  => q{is_plural: 'mottos'};
ok noun(q{helions})->is_plural  => q{is_plural: 'helions'};
ok noun(q{pangasinans})->is_plural  => q{is_plural: 'pangasinans'};
ok noun(q{volcanoes})->is_plural  => q{is_plural: 'volcanoes'};
ok noun(q{switchfoots})->is_plural  => q{is_plural: 'switchfoots'};
ok noun(q{monorchides})->is_plural  => q{is_plural: 'monorchides'};
ok noun(q{veg})->is_plural  => q{is_plural: 'veg'};
ok noun(q{fulcra})->is_plural  => q{is_plural: 'fulcra'};
ok noun(q{Lucchese})->is_plural  => q{is_plural: 'Lucchese'};
ok noun(q{mediums})->is_plural  => q{is_plural: 'mediums'};
ok noun(q{Hunanese})->is_plural  => q{is_plural: 'Hunanese'};
ok noun(q{tomia})->is_plural  => q{is_plural: 'tomia'};
ok noun(q{remiges})->is_plural  => q{is_plural: 'remiges'};
ok noun(q{pyrophori})->is_plural  => q{is_plural: 'pyrophori'};
ok noun(q{bison})->is_plural  => q{is_plural: 'bison'};
ok noun(q{vertebrae})->is_plural  => q{is_plural: 'vertebrae'};
ok noun(q{auroras})->is_plural  => q{is_plural: 'auroras'};
ok noun(q{Torontos})->is_plural  => q{is_plural: 'Torontos'};
ok noun(q{leptospirae})->is_plural  => q{is_plural: 'leptospirae'};
ok noun(q{monies})->is_plural  => q{is_plural: 'monies'};
ok noun(q{lemans})->is_plural  => q{is_plural: 'lemans'};
ok noun(q{logodaedale})->is_plural  => q{is_plural: 'logodaedale'};
ok noun(q{tableaus})->is_plural  => q{is_plural: 'tableaus'};
ok noun(q{protomas})->is_plural  => q{is_plural: 'protomas'};
ok noun(q{cladi})->is_plural  => q{is_plural: 'cladi'};

done_testing();
